/* ---------------------- ---------------------- ---------------------- ---------------------- ---------------------- ----------------------
 deHarry, 2024-02-01
 Programmentwicklung und Debugging erfolgte auf einem Wemos D1 mini. 
	Letzlich wird ein ESP-01 die erfassten und aufsummierten Daten im WLAN zur Verfügung stellen. 

 Hardware:
 Adapter ist entweder für die Wasseruhr ein induktiver Näherungssensor LJ12-A3-4-Z/BX in einem 3D gedruckten Halter...
 (Projekt siehe https://harald-sattler.de/html/adapter_wasseruhr.htm)
 Die Anschlüse sind etwas ungewöhnlich gefärbt:
	Braun: Plus 6..36 V
	Blau: GND
	Schwarz: Signal (vorher messen, was da rauskommt!! (OC oder Spannung)
 Test: Der Sensor funktioniert auch mit 5 V, die Versorgung des ESP01 kann also mittels 
	USB Netzteil und StepDown Wandler erfolgen.

 ...oder für den Gaszähler ein Halleffektensor TLE4913 auf Breakout Board in einem 3D gedruckten Halter.
	Hier muss die passende Stelle im Ausschnitt des Gaszählergehäuses gefunden werden. Kann etwas spannend werden, 
	denn der Zähler gibt seine Impulse auf der zweitletzten Stelle aus. Da muss also einiges Gas durchrauschen,
	bis der nächste Impuls kommt. (Projekt siehe https://harald-sattler.de/html/adapter_gaszahler.htm)
	Hinweis: Der ursprünglich vorgesehene A3144 ist für den Magneten im Gaszähler zu unempfindlich.

  Achtung! Pullup muss beim ESP-01 10 kΩ sein (ist im Layout vorgesehen) oder INPUT_PULLUP verwenden.

 Am ESP ist ein OLED Display per I2C angeflanscht das per Knopfdruck aktiviert werden kann (normalerweise AUS um die Pixel zu schonen).
	Der Code erkennt automatisch den verwendeten Typ Microprozessor und passt die Ausgänge an.

 Software:
 Einlesen der Impulse des Näherungssensors bei Wasser, 1 Imp/Liter
	oder
 Einlesen der Impulse des Halleffektsensors bei Gas, 1 Imp/0,01 m³
	und jeweils die Summe bilden und ausgeben auf dem OLED Display und über ein WEB Interface (Anzeige fürs Auge und Abfragen
	der Werte per Aufrufschnittstelle).

 Der WiFi Teil des Code wurde auf einem Wemos D1 mini lauffähig gemacht. Der Upload auf den ESP läuft beim Wemos doppelt so schnell 
	wie beim ESP-01 und man muss ihn nicht zum Programmieren erst auf einen Programmer umstecken. 
  Außerdem gibt es Debugausgaben auf der seriellen SS.
 Update des Programms kann OTA erfolgen, die Routinen sind eingebaut.
  Das geht auch auf dem ESP-01 vergleichsweise flott, aber der Neuanlauf dauert etwas (~18 s)... nicht ungeduldig werden ;)

 Anleihe bei FipsOK (https://fipsok.de/Projekt/gaszaehler-esp8266-nodemcu)
	- Zählerstand bei Änderung alle 4 Stunden im Flash speichern
	- HTML Seite mit Anzeige und Möglichkeit den aktuellen Zählerstand zu setzen

 Version V1.1, 09.04.2024
	- Bei langem Druck (> 2 s) auf den Button wird der momentane Zählerstand ins Flash geschrieben, mit Rückmeldung auf OLED
 Version V1.2, 10.04.2024
	- Ausgabe im WEB Interface mit konstant 5 Vorkommastellen (Zero padded), so dass der Dezimalpunkt immer auf der roten Linie sitzt
 Version V1.3, 17.04.2024 (nicht veröffentlicht)
	- Hintergrund der Anzeigen im WEb Interface von "Tan" (Hellbraun) auf "Weiß" umgestellt
Version V1.4, 23.05.2024
	- Favicon erstellt und eingebaut. 
		HowTo:
		In WORD mit Fontgröße 72 Buchstaben erstellen, als JPG in 92x92 Pixel speichern.
		Favicon über WEB Tool (https://www.favicon.cc/) aus JPG erzeugen (alle Auflösungen), in HxD Hexeditor einziehen,
		alles selektieren, copy&paste nach NP++, auf 16 HEX Werte Fensterbreite einstellen, dann Ctrl-I 
		(Bearbeiten-Zeilenoperationen-Am Fensterrand teilen).
		Alle Blanks durch ", 0x" ersetzen, letzte 2 Spalten löschen, 1. Spalte 0x davor.
		Hexwerte per copy&paste in favicon Array einfügen.

---------------------- ---------------------- ---------------------- ---------------------- ---------------------- ---------------------- */


// WiFi libs
#include <WiFiServer.h>
#include <ESP8266WiFi.h>
#include <ESP8266WebServer.h>
#include <ArduinoOTA.h>					// https://arduino-esp8266.readthedocs.io/en/latest/ota_updates/readme.html

// LittleFS
#include <LittleFS.h>                   // http://arduino-esp8266.readthedocs.io/en/latest/filesystem.html

// Bibliothek für das OLED Display
#include <U8g2lib.h>

// Sonstige Libs

// Defines für Debug ----------------------------------------------------------------------------------
#if defined (ARDUINO_ESP8266_GENERIC)	// ESP-01
	#undef SERIALDEBUG					// beim ESP-01 darf Serial nicht aktiviert werden
#else
	#define SERIALDEBUG					// jede Menge Serial Ausgaben für Debugzwecke aktivieren
#endif
#ifdef SERIALDEBUG						// wenn aktiviert, Ausgaben auf Serial
	#define debugPrint Serial.print
	#define debugPrintf Serial.printf
	#define debugPrintln Serial.println
#else									// keine Ausgaben auf Serial
	#define debugPrint		//Serial.print
	#define debugPrintf		//Serial.printf
	#define debugPrintln	//Serial.println
#endif
// ----------------------------------------------------------------------------------------------------

// allgemeine Defines
//#define WASSER							// Code und Anzeige für Wasserzähler sonst für Gaszähler
#define USEIRQ							// Sensorabfrage per Interrrupt - muss immer aktiv sein
#define USEFS							// Zählerwert im LittleFS ablegen

#if defined WASSER						// mit Blanks zum "zentrieren" auf dem OLED Display
	#define COUNTERNAME "   Sensus 420"
#else
	#define COUNTERNAME "elster BK-G4M"
#endif

// Credentials für das eigene WLAN
#define OwnSSID "OwnSSID"				// -->> hier die eigenen Credentials eintragen <<--
#define OwnPassword "OwnPassword"		// -->> hier die eigenen Credentials eintragen <<--

// Pin Definitionen
#if defined (ARDUINO_ESP8266_WEMOS_D1MINI)	// Wemos D1 R2
	// I2C Pins am Wemos D1 R2
	#define I2CSDA D2						// beim ESP01 1, beim Wemos 5
	#define I2CSCL D1						// beim ESP01 2, beim Wemos 4
	#define SENSORPIN D3					// beim ESP01 3, beim Wemos 3
	#define TASTER D0						// beim ESP01 0, beim Wemos 0	Achtung! D0 (= GPIO16) generiert keinen IRQ
	#define SIGNALLED D4					// beim ESP01 4, beim Wemos 2
#elif defined (ARDUINO_ESP8266_GENERIC)		// ESP-01
	// I2C Pins am ESP-01
	#define I2CSDA 1						// beim ESP01 1, beim Wemos 5
	#define I2CSCL 2						// beim ESP01 2, beim Wemos 4
	#define SENSORPIN 3						// beim ESP01 3, beim Wemos 3
	#define TASTER 0						// beim ESP01 0, beim Wemos 0	Achtung! D0 (= GPIO16) generiert keinen IRQ
#endif

// OLED Display instantiieren
#define SCREEN_WIDTH 128
#define SCREEN_HEIGHT 64
#define SCREEN_ADDRESS 0x3C

U8G2_SSD1306_128X64_NONAME_F_HW_I2C myDisplay(U8G2_R0, U8X8_PIN_NONE, I2CSCL, I2CSDA);

// globale Variablen
unsigned long DisplayTimer = 0;						// für Timeout des Display, Pixel schonen durch Abschalten
bool DisplayContentEin = true;						// Ausgaben auf dem Display de-/aktivieren (PowerSave funktioniert nicht)
#define DISPLAYPERIOD 25000							// OLED Display nach TASTER==LOW für 25 s einschalten
bool clearOnce = true;								// Display einmalig nach Setup löschen

unsigned long counterValue = 8859060;				// Gaszähler als uLong, muss zur Anzeige durch 1000 geteilt werden
unsigned long oldCounterValue;						// Zählerwert im EEPROM speichern

float value, oldvalue;								// Zählerwerte für Fips' Teil des Code

// WiFiServer instantiieren
ESP8266WebServer server(80);

unsigned long clientDelayTimer = 0;
#define CLIENTDELAY 2000							// Werte alle 2 s abfragen und WEB Oberfläche aktualisieren

// globale Variablen
char buffer[20];									// Puffer für formatierte Ausgabe der Zahlen
uint8_t YOFF = 30;									// initialer vertikaler Offset für die Auflistung der Initialisierungen

unsigned long letzterAufruf = 0;					// Merker für "alle 4 h Zählerwert speichern"

unsigned long activityTimer = 0;					// Aktivitätsanzeige - Programm läuft noch ;)
uint8_t propellerState = 0;
//char propellerString[] = { '|', '/', '-', '\\' };	// langsam drehender Propeller auf dem OLED Display
char propellerString[] = { 'T', '+', 'T', '+' };	// weit genug nach rechts blinkt nur ein Pixel (linke Ecke des T)

// Taster
bool bTasterTrig = false;							// Tastendruckdauer auswerten
bool bTasterLang = false;							// Tastendruckdauer auswerten
unsigned long uTasterLang = 0;
#define LONGKEY 2000								// Zeitdauer für langen Tastendruck in ms
bool bsaved = false;


// Abfrage des Sensors per Interrupt ----------------------------------
#if defined USEIRQ
struct Sensor {
	const uint8_t PIN;
	bool triggered;
};

volatile Sensor SensorTLE = { SENSORPIN, false };	// muss volatile deklariert werden, sonst wird "triggered" nicht aktualisiert

//variables to keep track of the timing of recent interrupts
unsigned long sensor_time = 0;
unsigned long last_sensor_time = 0;

void ICACHE_RAM_ATTR sensorISR() {
	sensor_time = millis();
	if (sensor_time - last_sensor_time > 500)		// Prellen unterdrücken 
	{												// Tritt bei den verwendeten Sensoren nicht auf, schadet aber auch nicht :)
		SensorTLE.triggered = true;
		last_sensor_time = sensor_time;
	}
}
#endif
// \Abfrage des Sensors per Interrupt ----------------------------------


// ---------------------------------------------------------------------------------------------------------------------
void setup() {
#if defined USEIRQ
	pinMode(SensorTLE.PIN, INPUT_PULLUP);
	attachInterrupt(SensorTLE.PIN, sensorISR, FALLING);	// Sensor/Taster ziehen den Eingang auf Null/GND
#else
	pinMode(SENSORPIN, INPUT_PULLUP);				// Eingang für Sensor (Halleffektsensor TLE4913 oder Näherungssensor LJ12-A3-4-Z/BX)
#endif
	pinMode(TASTER, INPUT_PULLUP);					// Taster für Display temporär einschalten

#if defined (ARDUINO_ESP8266_WEMOS_D1MINI)			// LED nur beim Wemos vorhanden
	pinMode(SIGNALLED, OUTPUT);						// signal incoming data on serial
	digitalWrite(SIGNALLED, LOW);
#endif

// ACHTUNG - Wenn Serial.begin() aufgerufen wird, wird der RX-Pin des ESP-01 bedingungslos auf die serielle SS geroutet,
//				es ist dann nicht möglich, den Pin als normalen IO zu verwenden.
//			Siehe "https://www.forward.com.au/pfod/ESP8266/GPIOpins/ESP8266_01_pin_magic.html"

#ifdef SERIALDEBUG									// wenn aktiviert, Ausgaben auf Serial
	// bring up serial port
	Serial.begin(115200);							// Default ist Baudrate + 8N1
#endif

	// init OLED myDisplay, I2C-Adr. 0x3c
	bool result = myDisplay.begin();

#define LUCIDA										// welcher Font. Hier könnten andere Fonts definiert werden
#ifdef LUCIDA										// Lucida ist ein Proportionalfont
	// deutsche Umlaute siehe "https://www.ascii-code.com/de", es muss der ".._f" Font sein (full)
	#define FONT1 u8g2_font_lubB08_tf				// 4 verschiedene Schriftgrößen
	#define FONT2 u8g2_font_lubB10_tf
	#define FONT3 u8g2_font_lubB12_tf
	#define FONT4 u8g2_font_lubB14_tf
#endif

	myDisplay.setFont(FONT1);						// Font und Schreibfarbe (weiß/hell) für OLED definieren
	myDisplay.setDrawColor(1);
	myDisplay.clearDisplay();						// erst mal alles löschen

	// Zählername auf OLED ausgeben
	printName();

	// Starte WiFi für die Anzeige auf der WEB GUI
	WiFi.persistent(false);							// Auskommentieren wenn Netzwerkname und Passwort in den Flash geschrieben werden sollen.
	WiFi.mode(WIFI_STA);
	WiFi.begin(OwnSSID, OwnPassword);				// -->> die eigenen Credentials oben als Define eintragen <<--

	while (WiFi.status() != WL_CONNECTED) 
	{
		delay(500);
		yield();									// für ESP - ruft WiFi Routinen auf. Wird bereits in delay() aufgerufen.
#ifndef ARDUINO_ESP8266_GENERIC						// ESP-01 - nur beim Wemos Serial. verwenden
		Serial.print(".");							// Debug Ausgabe
#endif
	}

	// Status Wifi auf OLED ausgeben
	printWiFi();
	delay(1000);									// 1 s die Werte (URL usw.) anzeigen

	// Starte Server für die Anzeige auf der WEB GUI
	server.begin();
	printServer();

	server.on("/", handleRoot);
	server.on("/favicon.ico", handleIcon);			// Favicon an Browser senden
	server.on("/status", handleStatus);
	delay(1000);									// 1 s die Werte (URL usw.) anzeigen

	// IP addresse auf OLED ausgeben
	printIP();
	// \bring up WiFi Ende
	delay(1000);									// 1 s die Werte (URL usw.) anzeigen

	// Starte FileSystem
	LittleFS.begin();
	printFS();
	delay(1000);									// 1 s die Werte (URL usw.) anzeigen

	// Start OTA Server für Update der Firmware über Wifi
	ArduinoOTA.begin();
	ArduinoOTA.onStart([]() {                       // Zählerstand speichern bevor OTA Update durchgeführt wird
		save();
	});

	// bisherige Auflistung 1 Zeile nach oben "scrollen" und OTA ausgeben
	YOFF -= 11;										// so eine Art Scrollfunktion imitieren

	myDisplay.setDrawColor(0);						// untere 4 Zeilen löschen
	myDisplay.drawBox(0, 20, 127, 44);
	myDisplay.setDrawColor(1);

	//printName();									// nicht notwendig, da nur die Liste gelöscht wird
	printServer();
	printIP();
	printFS();
	printOTA();

	File f = LittleFS.open("/value.txt", "r");      // Zählerstand beim Neustart aus Datei lesen
	String str = f.readStringUntil('\n');
	counterValue = str.toInt();
	oldCounterValue = counterValue;
	f.close();
#ifndef ARDUINO_ESP8266_GENERIC						// ESP-01 - nur beim Wemos Serial. verwenden
	Serial.printf("Ulong vom Flash: %li\n", counterValue);
#endif
	delay(2000);									// 2 s die Werte (URL usw.) anzeigen

	DisplayTimer = millis();						// direkt nach PowerOn Display erst mal für DISPLAYPERIOD aktiviert lassen...
}	// \setup()


// ---------------------------------------------------------------------------------------------------------------------
void loop()
{
	// Taster abfragen. Wenn gedrückt, Display für DISPLAYPERIOD einschalten
	if ((digitalRead(TASTER) == LOW) /*&& (bTasterTrig == false) && (bTasterLang == false)*/)
	{
		bTasterTrig = true;							// Taster wurde gedrückt
		DisplayTimer = millis();		// neue Zeit merken
		DisplayContentEin = true;
#ifndef ARDUINO_ESP8266_GENERIC						// ESP-01 - nur beim Wemos Serial. verwenden
				Serial.println("Tastendruck erkannt");
#endif
		if ((bTasterLang == false) && (bTasterTrig == true))
		{
			uTasterLang = millis();
			bTasterLang = true;
#ifndef ARDUINO_ESP8266_GENERIC						// ESP-01 - nur beim Wemos Serial. verwenden
				Serial.println("Lang gestartet");
#endif
		}
		if ((millis() > (uTasterLang + LONGKEY)) && (bTasterLang == true) && (bsaved == false))
		{
#ifndef ARDUINO_ESP8266_GENERIC						// ESP-01 - nur beim Wemos Serial. verwenden
			Serial.println("Langer Tastendruck erkannt");
#endif
			save();									// Zählerwert ins Flash schreiben
			bsaved = true;							// Wert ist gespeichert

			myDisplay.setFont(FONT2);
			myDisplay.drawStr(20, 28, "gespeichert");	// Hinweis für Nutzer
		}
	}
	else	// Display nach Ablauf von DISPLAYPERIOD "abschalten" um Einbrennen zu minimieren
	{		// Würde man normalerweise mit setPowerSave(0) erledigen, das funktioniert bei meinen Displays aber nicht :(
		if ((millis() - DisplayTimer) > DISPLAYPERIOD)
		{
			myDisplay.clearDisplay();
			DisplayContentEin = false;
		}

		bTasterTrig = false;						// Taster wurde zwischenzeitlich losgelassen
		bTasterLang = false;
		bsaved = false;								// Sichern des Zählerwerts wieder scharf schalten
	}

	// Sensor abfragen. Wenn getriggert, Zähler inkrementieren, SensorTLE.triggered wird im IRQ gesetzt
	if (SensorTLE.triggered == true)
	{
#if defined WASSER
		counterValue += 1;									// in der Anzeige der Wasseruhr werden 4 Nachkommastellen (5 mit Metallplatte,
#else														//  6 mit Zahnrad) angezeigt, aber mit dem Magnet wird die 3. Nachkommastelle (Liter) hochgezählt
		counterValue += 10;									// in der Anzeige des Gaszählers werden 3 Nachkommastellen angezeigt, 
#endif														//	aber mit dem Magnet wird die 2. Nachkommastelle hochgezählt

		//DisplayTimer = millis();							// neue Zeit merken (nur zur Programmentwicklung)
		//DisplayContentEin = true;							// Display bei Sensortrigger nur zur Programmentwicklung aktivieren

		SensorTLE.triggered = false;						// Flag löschen, wird per IRQ erneut gesetzt
	}

#ifndef WASSER												// bei der Wasseruhr muss die 3. Nachkommastelle erhalten bleiben
	counterValue = (counterValue / 10) * 10;				// magic um die 3. Nachkommastelle beim Gaszähler immer auf Null (0) zu setzen
#endif	
	float fCounterVal = (float)counterValue / 1000.0;		// für die formatierte Anzeige in float wandeln
	dtostrf(fCounterVal, 10, 3, buffer);					// Zahl formatieren (12 Stellen, 3 Nachkomma, rechtsbündig)

	// Zählerstand im Flash speichern, wenn er sich geändert hat
	unsigned long aktuelleMillis = millis();
	if (aktuelleMillis - letzterAufruf >= 60000UL * 240 && counterValue != oldCounterValue) {       // alle 4 Stunden speichern
		save();
		oldCounterValue = counterValue;
		letzterAufruf = aktuelleMillis;
	}

// WiFi part of loop ----------------------------------------------------------------------------------------------
	server.handleClient();									// WEB GUI bedienen
	ArduinoOTA.handle();									// Check for OTA calls
// \WiFi part of loop ---------------------------------------------------------------------------------------------

	publishMessage();										// Werte auf OLED anzeigen

	// Aktivitätsanzeige auf dem OLED Display
	if ((millis() - activityTimer) > 300)
	{
		if (DisplayContentEin == true)
		{
			propellerState++;
			propellerState = propellerState % 4;

			myDisplay.setFont(FONT1);
			myDisplay.setCursor(126, 7);
			myDisplay.print(propellerString[propellerState]);	// show text
			myDisplay.updateDisplay();
		}
		activityTimer = millis();
	}
}	// \loop()
// ---------------------------------------------------------------------------------------------------------------------

// --------------------------------------------------------------------------------

// --------------------------------------------------------------------------------
// OLED aktualisieren
void publishMessage()										// Ausgabe der Werte auf dem OLED
{
	if (DisplayContentEin == true)
	{
		// Display einmalig nach Setup löschen
		if (clearOnce == true) { myDisplay.clearDisplay(); clearOnce = false; }

		myDisplay.setFont(FONT3);
		printName();
		myDisplay.setFont(FONT2);
		myDisplay.drawStr(0, 40, "Z\xe4hlerstand [m ]");	// ä = \xe4 \228 -> siehe "https://www.ascii-code.com/de"
		myDisplay.drawStr(116, 40, "\xb3");					// das ³ sitzt zu weit links im Buchstabenfeld, muss explizit platziert werden

		myDisplay.setDrawColor(0);							// Zeile mit Zählerwert löschen (der Font ist transparent -> ansonsten Müll)
		myDisplay.drawBox(0, 44, 127, 17);
		myDisplay.setDrawColor(1);

		float fCounterVal = (float)counterValue / 1000.0;	// für die formatierte Anzeige in float wandeln
		dtostrf(fCounterVal, 10, 3, buffer);				// Zahl formatieren (12 Stellen, 3 Nachkomma, rechtsbündig)

		myDisplay.setFont(FONT4);
		myDisplay.drawStr(0, 60, buffer);					// buffer wird in der loop gesetzt
	}
}	// \OLED aktualisieren

// --------------------------------------------------------------------------------
// aktuellen Zählerstand im Flash speichern
void save() {
	File f = LittleFS.open("/value.txt", "w");
	f.printf("%li\n", counterValue);
	f.close();
#ifndef ARDUINO_ESP8266_GENERIC								// ESP-01 - nur beim Wemos Serial. verwenden
	Serial.printf("save()\n");
#endif
}	// \aktuellen Zählerstand im Flash speichern
// --------------------------------------------------------------------------------

// --------------------------------------------------------------------------------
// Routinen zur Ausgabe von Infos
void printName() {
	myDisplay.setFont(FONT3);
	myDisplay.drawStr(0, 16, COUNTERNAME);
	myDisplay.updateDisplay();
}

void printWiFi() {
	myDisplay.setFont(FONT1);
#ifndef ARDUINO_ESP8266_GENERIC								// ESP-01 - nur beim Wemos Serial. verwenden
	Serial.println("");								// Debug Ausgabe
	Serial.println("WiFi  connected");				// Debug Ausgabe
#endif	
	myDisplay.drawStr(0, YOFF, "WiFi  connected");
	myDisplay.updateDisplay();
}

void printServer() {
	myDisplay.setFont(FONT1);
#ifndef ARDUINO_ESP8266_GENERIC								// ESP-01 - nur beim Wemos Serial. verwenden
	Serial.println("Server started");
#endif	
	myDisplay.drawStr(0, YOFF + 11, "Server  started");
	myDisplay.updateDisplay();
}

void printIP() {
#ifndef ARDUINO_ESP8266_GENERIC								// ESP-01 - nur beim Wemos Serial. verwenden
	Serial.print("Use this URL to connect: ");
	Serial.print("http://");
	Serial.print(WiFi.localIP());
	Serial.println("/");
#endif	
	myDisplay.drawStr(0, YOFF + 22, "IP");
	myDisplay.updateDisplay();
	myDisplay.setCursor(16, YOFF + 22);
	myDisplay.print(WiFi.localIP());
	myDisplay.updateDisplay();
}

void printFS() {
	myDisplay.drawStr(0, YOFF + 33, "LittleFS  l\xe4uft");
	myDisplay.updateDisplay();
}

void printOTA() {
#ifndef ARDUINO_ESP8266_GENERIC								// ESP-01 - nur beim Wemos Serial. verwenden
	Serial.println("OTA Server  started");
#endif	
	myDisplay.drawStr(0, YOFF + 44, "OTA     started");
	myDisplay.updateDisplay();
}
// \// Routinen zur Ausgabe von Infos

// Routinen für die WEB Oberfläche - Die Routinen stammen ursprünglich aus der Feder von Jens Fleischer (https://fipsok.de/)
//	und wurden von mir nur angepasst bzw. um von mir nicht benötigte Funktionen erleichtert.
// --------------------------------------------------------------------------------
void handleStatus() {
	if (server.arg(0).length() > 0 && server.arg(0).length() <= 9) 	// Format ist 12345.123, also maximal 9 Stellig		
	{
		String svalue = server.arg(0);
		value = svalue.toFloat();

#ifndef ARDUINO_ESP8266_GENERIC								// ESP-01 - nur beim Wemos Serial. verwenden
		Serial.printf("server.arg(0).length(): %li\n", server.arg(0).length());

		svalue.toCharArray(buffer, 20);						// für printf in char Array packen..
		Serial.printf("Wert vom Client: %s\n", buffer);		// ..und ausgeben
		svalue.toCharArray(buffer, 20);
		Serial.printf("Zählerstand vom Client: %s\n", buffer);		// als String ausgeben
		Serial.printf("Zählerstand vom Client: %5.3f\n", value);	// als Float ausgeben
#endif	
	counterValue = value * 1000.0;							// 3 Nachkommastellen vor das Komma holen
#ifndef WASSER												// bei der Wasseruhr muss die 3. Nachkommastelle erhalten bleiben
	counterValue = (counterValue / 10) * 10;				// magic um die letzte Stelle immer auf Null (0) zu setzen
#endif	
	save();													// neu eingebenen Zählerstand ins Flash speichern
	}

	char buf[42];
	char tmpbuf[20];
	float fCounterVal = (float)counterValue / 1000.0;		// für die formatierte Anzeige in float wandeln
	dtostrf(fCounterVal, 12, 3, buffer);					// Zahl formatieren (12 Stellen, 3 Nachkomma, rechtsbündig, keine führenden Nullen!)

	String buffi;											// Magic um die Zahl im WEB Interface passend auszurichten (Dezimalpunkt auf der roten Linie)
	for (uint8_t i = 3; i < sizeof(buffer); i++)			// maximal 5 Vorkommastellen, der String hat 12 Stellen insgesamt, also ab 3. Stelle lesen
		if (buffer[i] == ' ') buffi += "0"; 
		else buffi += buffer[i];

	buffi.toCharArray(buffer, sizeof(buffer));

#ifndef ARDUINO_ESP8266_GENERIC								// ESP-01 - nur beim Wemos Serial. verwenden
		Serial.printf("newstring: %ls\n", buffer);
#endif

		snprintf(buf, sizeof(buf), "[\"%s m³\"]", buffer);
	server.send(200, "application/json", buf);				// Zählerstand an Html Seite senden
}	// \handleStatus()


// --------------------------------------------------------------------------------
// Hier habe ich den "Fließtext" von Jens etwas entzerrt um den Überblick für meine Änderungen zu bekommen:
//	-> Keine LEDs auf dem benutzten ESP-01, keine Verwendung von Thingspeak, Zählereingabe 9-stellig (mit Punkt)
// Leider wird das schön formatierte HTML wieder linksbündig in die temp Variable gestopft, aber was solls...

// Html Webseite, der Zählerstand wird alle 5 Sekunden mittels fetch.api aktualisiert
void handleRoot() { 
	String temp = "	<!DOCTYPE HTML>";
	temp += "<html lang='de'>";
	temp += "<head>";
	temp += "<meta charset='UTF-8'>";
	temp += "<meta name='viewport' content='width=device-width, initial-scale=1'>";
#if defined WASSER
	temp += "<title>Wasserzähler</title>";
#else
	temp += "<title>Gaszähler</title>";
#endif
	temp += "<script>";
	temp += "addEventListener('load', () => {";
	temp += "let i = document.querySelector('input'),";
	temp += "n = document.querySelector('#note');";
	temp += "document.querySelector('#grey').addEventListener('click', () => t());";
	temp += "i.addEventListener('blur',";
	temp += "() => {";
	temp += "!i.checkValidity() ? (n.innerHTML = i.validationMessage, n.classList.add('note')) : s('status', i.value)";
	temp += "});";
	temp += "";
	temp += "function t() {";
	temp += "let x = document.getElementById('no');";
	temp += "getComputedStyle(x).display === 'none' ? x.style.display = 'flex' : x.style.display = 'none';";
	temp += "n.innerHTML = '';";
	temp += "n.classList.remove('note');";
	temp += "i.value = ''";
	temp += "}";
	temp += "async function s(p = 'status', v) {";
	temp += "if (Number.isInteger(parseInt(v))) t();";
	temp += "let r = await fetch(p, {";
	temp += "method: 'POST',";
	temp += "body: v";
	temp += "});";
	temp += "let j = await r.json();";
	temp += "document.querySelector('span').innerHTML = j[0];";
	temp += "}";
	temp += "s(), setInterval(s, 5000)";
	temp += "});";
	temp += "</script>";
	temp += "<style>";
	temp += "body {";
	temp += "background-color: white;";
	temp += "font-size: 1.1em";
	temp += "}";
	temp += "";
	temp += "body,";
	temp += "#grey,";
	temp += "#no,";
	temp += "#black {";
	temp += "display: flex;";
	temp += "flex-flow: column;";
	temp += "align-items: center";
	temp += "}";
	temp += "";
	temp += "#grey {";
	temp += "background-color: #c5c3c3;";
	temp += "width: 340px;";
	temp += "height: 150px;";
	temp += "border: .3em solid #aeaeab;";
	temp += "border-radius: .5em;";
	temp += "box-shadow: 5px 10px 5px #4e4d4d";
	temp += "}";
	temp += "";
	temp += "#no {";
	temp += "background-color: #c5c3c3;";
	temp += "width: 340px;";
	temp += "height: 65px;";
	temp += "border: .3em solid #aeaeab;";
	temp += "border-radius: .5em;";
	temp += "box-shadow: 5px 10px 5px #4e4d4d";
	temp += "}";
	temp += "";
	temp += "#grey {";
	temp += "cursor: pointer";
	temp += "}";
	temp += "";
	temp += "#black {";
	temp += "background-color: black;";
	temp += "width: 14em;";
	temp += "border-radius: .2em";
	temp += "}";
	temp += "";
	temp += "#red {";
	temp += "border: .28em solid red;";
	temp += "position: relative;";
	temp += "width: 3.8em;";
	temp += "height: 1.5em;";
	temp += "left: 1.5em";
	temp += "}";
	temp += "";
	temp += "span {";
	temp += "color: white;";
	temp += "position: relative;";
	temp += "left: .1em;";
	temp += "letter-spacing: .2em;";
	temp += "font-size: 1.6em;";
	temp += "font-weight: bold;";
	temp += "top: 4.55em;";
	temp += "pointer-events: none;";
	temp += "z-index: 1";
	temp += "}";
	temp += "";
	temp += "#no {";
	temp += "display: none";
	temp += "}";
	temp += "";
	temp += ".note {";
	temp += "background-color: #fecdee;";
	temp += "padding:";
	temp += ".3em;";
	temp += "border-radius: .5em;";
	temp += "position: relative;";
	temp += "top: -5.5em";
	temp += "}";
	temp += "";
	temp += "input,";
	temp += "#err {";
	temp += "height: 30px;";
	temp += "margin-top: 1em";
	temp += "}";
	temp += "";
	temp += ".button {";
	temp += "background-color: #75a27e;";
	temp += "height: 40px;";
	temp += "width: 120px;";
	temp += "font-size: 16px;";
	temp += "box-shadow: 5px 5px 5px #4e4d4d";
	temp += "}";
	temp += "";
	temp += ".off {";
	temp += "background-color: #cf848c";
	temp += "}";
	temp += "</style>";
	temp += "</head>";
	temp += "<body>";
	temp += "<span></span>";
	temp += "<div id='grey'>";
	temp += "<h1>Zählerstand ";
#if defined WASSER
	temp += "Wasser";
#else
	temp += "Gas";
#endif
	temp += "</h1>";
		temp += "<div id='black'>";
	temp += "<div id='red'></div>";
	temp += "</div>";
	temp += "</div>";
	temp += "<div id='no'>";
	temp += "<input placeholder=' Zählerstand eingeben' pattern='[0-9]{1,5}[.]\\d{0,3}' title='Nur Ziffern, 1..5 vor dem Punkt und 0..3 nach dem Punkt sowie Punkt sind erlaubt' required>";
	temp += "<div id='note'></div>";
	temp += "</body>";
	temp += "</html>";

server.send(200, "text/html", temp);
}    // \handleRoot()

void handleIcon() {
	const static uint8_t favicon[] PROGMEM = {
#if defined WASSER
// blaues "W"
0xFF, 0xD8, 0xFF, 0xE0, 0x00, 0x10, 0x4A, 0x46, 0x49, 0x46, 0x00, 0x01, 0x01, 0x01, 0x00, 0x60, 0x00, 0x60,
0x00, 0x00, 0xFF, 0xDB, 0x00, 0x43, 0x00, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0xFF,
0xDB, 0x00, 0x43, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0xFF, 0xC0, 0x00, 0x11,
0x08, 0x00, 0x5C, 0x00, 0x5C, 0x03, 0x01, 0x11, 0x00, 0x02, 0x11, 0x01, 0x03, 0x11, 0x01, 0xFF, 0xC4, 0x00,
0x1E, 0x00, 0x00, 0x02, 0x01, 0x05, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x0A, 0x09, 0x02, 0x03, 0x05, 0x07, 0x08, 0x04, 0x06, 0x01, 0xFF, 0xC4, 0x00, 0x3C, 0x10, 0x00, 0x02,
0x02, 0x01, 0x03, 0x02, 0x04, 0x04, 0x02, 0x07, 0x05, 0x09, 0x00, 0x00, 0x00, 0x00, 0x01, 0x02, 0x03, 0x04,
0x05, 0x06, 0x07, 0x11, 0x00, 0x12, 0x08, 0x09, 0x13, 0x21, 0x14, 0x22, 0x31, 0x41, 0x15, 0x71, 0x16, 0x23,
0x51, 0x61, 0x81, 0xE1, 0xF0, 0x91, 0xA1, 0xB1, 0xC1, 0xD1, 0x17, 0x24, 0x25, 0x32, 0x33, 0x42, 0x43, 0x72,
0xA2, 0xFF, 0xC4, 0x00, 0x1D, 0x01, 0x01, 0x01, 0x00, 0x02, 0x03, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x08, 0x0A, 0x04, 0x06, 0x07, 0x05, 0x03, 0x02, 0xFF, 0xC4, 0x00, 0x32,
0x11, 0x00, 0x02, 0x02, 0x02, 0x01, 0x04, 0x01, 0x03, 0x04, 0x02, 0x01, 0x03, 0x05, 0x01, 0x00, 0x00, 0x02,
0x03, 0x01, 0x04, 0x05, 0x06, 0x00, 0x07, 0x11, 0x12, 0x13, 0x08, 0x14, 0x21, 0x22, 0x09, 0x15, 0x16, 0x23,
0x31, 0x32, 0x41, 0x33, 0x42, 0x51, 0x17, 0x18, 0x19, 0x34, 0x52, 0x35, 0xFF, 0xDA, 0x00, 0x0C, 0x03, 0x01,
0x00, 0x02, 0x11, 0x03, 0x11, 0x00, 0x3F, 0x00, 0x7F, 0x8E, 0x9C, 0x70, 0xE9, 0xC7, 0x0E, 0x9C, 0x70, 0xE9,
0xC7, 0x0E, 0x9C, 0x70, 0xE9, 0xC7, 0x0E, 0x9C, 0x70, 0xE9, 0xC7, 0x0E, 0x9C, 0x70, 0xE9, 0xC7, 0x0E, 0x9C,
0x70, 0xE9, 0xC7, 0x2D, 0xCB, 0x2C, 0x70, 0xA1, 0x92, 0x46, 0x08, 0x8B, 0xEE, 0x59, 0x88, 0x00, 0x7E, 0x64,
0x90, 0x07, 0xF1, 0x3D, 0x38, 0xE6, 0x25, 0x75, 0x0E, 0x19, 0xA4, 0xF4, 0x97, 0x21, 0x50, 0xC9, 0xCF, 0x1D,
0xA2, 0xC4, 0x1D, 0xDC, 0xFD, 0x38, 0xE3, 0xD4, 0xE7, 0x9F, 0x71, 0xED, 0xC7, 0xE7, 0xD3, 0x8E, 0x66, 0x11,
0xD5, 0xD4, 0x3A, 0x30, 0x65, 0x23, 0x90, 0x41, 0x04, 0x1F, 0xE2, 0x3A, 0x71, 0xCA, 0xBA, 0x71, 0xC3, 0xA7,
0x1C, 0xC5, 0xDA, 0xCD, 0x62, 0xE9, 0x37, 0x65, 0xAB, 0xB5, 0xE1, 0x60, 0x78, 0xE2, 0x49, 0xA2, 0x43, 0xFF,
0x00, 0xD3, 0x8E, 0x9C, 0x73, 0xD1, 0x53, 0x21, 0x4E, 0xF2, 0xF7, 0x54, 0xB3, 0x0C, 0xE3, 0xF6, 0xC7, 0x22,
0x3F, 0xDB, 0x9F, 0xFB, 0x19, 0xBE, 0xDD, 0x38, 0xE7, 0xB3, 0xA7, 0x1C, 0x3A, 0x71, 0xCB, 0x52, 0xCD, 0x14,
0x08, 0x64, 0x95, 0xD6, 0x34, 0x5F, 0x72, 0xCE, 0xC1, 0x40, 0xFA, 0xFD, 0xD8, 0x81, 0xF6, 0x3F, 0x53, 0xF6,
0xE9, 0xC7, 0x31, 0x91, 0xE7, 0xF0, 0xF2, 0xCA, 0x21, 0x8E, 0xFD, 0x57, 0x90, 0x9E, 0x02, 0x2C, 0xF0, 0x96,
0xE7, 0xF2, 0x12, 0x13, 0xFD, 0xDD, 0x38, 0xE6, 0x5C, 0x10, 0x40, 0x20, 0x82, 0x0F, 0xD0, 0x8F, 0xA7, 0x4E,
0x39, 0xC6, 0x1E, 0x60, 0xFA, 0x57, 0x33, 0xAC, 0xFC, 0x21, 0xEF, 0x4E, 0x13, 0x05, 0x2C, 0xF1, 0xDD, 0x8B,
0x4D, 0x41, 0xA8, 0x18, 0x57, 0x95, 0xA2, 0x96, 0x6A, 0x7A, 0x43, 0x2F, 0x8F, 0xD5, 0xD9, 0x1A, 0x8A, 0x54,
0x16, 0x7F, 0x8C, 0xA1, 0x83, 0xB3, 0x50, 0xC0, 0x3D, 0xEC, 0xAC, 0xC6, 0xBF, 0xFE, 0x5E, 0xBD, 0x77, 0xA0,
0xD9, 0x9A, 0x78, 0x1E, 0xAF, 0xE8, 0x79, 0x0B, 0xE2, 0xB2, 0xAC, 0x59, 0x99, 0xC6, 0x94, 0xB4, 0x20, 0xC1,
0x6C, 0xCD, 0xD3, 0xB5, 0x85, 0xAE, 0xF2, 0x89, 0xED, 0x03, 0x15, 0xEC, 0xE4, 0x14, 0xF8, 0x64, 0xFD, 0x93,
0x2B, 0x86, 0xFF, 0x00, 0xD9, 0xCC, 0x73, 0xF9, 0x6F, 0xAC, 0xE4, 0xB6, 0xDF, 0x8E, 0x1D, 0x5A, 0xC3, 0xE2,
0x58, 0xD0, 0xBC, 0x1A, 0xD0, 0xE6, 0xC2, 0x12, 0xC9, 0x5B, 0x5C, 0x8D, 0x5B, 0x27, 0x8F, 0xD9, 0xEE, 0xD5,
0x09, 0x8F, 0xB9, 0xCD, 0xCA, 0x58, 0x7B, 0x15, 0x3D, 0x31, 0xF7, 0xB1, 0x0E, 0x94, 0x47, 0xFD, 0x4E, 0x29,
0xA6, 0xD2, 0xEB, 0xBC, 0x96, 0xDA, 0x6E, 0x46, 0x8D, 0xD6, 0xD8, 0xBB, 0x76, 0xA9, 0xCD, 0x80, 0xD4, 0x18,
0xDB, 0xB6, 0x1A, 0xAC, 0xEF, 0x5D, 0xE6, 0xC7, 0xAD, 0x94, 0x4C, 0x8D, 0x56, 0x74, 0x20, 0x34, 0x76, 0x68,
0xBD, 0x88, 0x1D, 0x1C, 0x34, 0x6C, 0xB2, 0x10, 0xEA, 0xC3, 0x91, 0xD5, 0x5B, 0xEA, 0x56, 0xB0, 0x1B, 0x96,
0x87, 0xB5, 0xEB, 0x92, 0xA5, 0x31, 0xF9, 0x2C, 0x1E, 0x41, 0x54, 0x25, 0xAA, 0x86, 0xC2, 0xB2, 0x43, 0x5C,
0xDB, 0x8E, 0x70, 0x8C, 0xC4, 0x94, 0x12, 0xAE, 0x02, 0x0E, 0x08, 0x3B, 0x32, 0x3B, 0x4F, 0x84, 0xC4, 0xF6,
0xE6, 0xBE, 0xDD, 0x11, 0xDE, 0xDB, 0xD3, 0x5E, 0xAC, 0xF4, 0xFF, 0x00, 0x75, 0x17, 0xBD, 0x35, 0x30, 0x7B,
0x56, 0x1E, 0xC6, 0x58, 0x6B, 0xBC, 0x90, 0x56, 0x30, 0x87, 0x71, 0x48, 0xCC, 0xD5, 0x22, 0x89, 0x81, 0x90,
0xB1, 0x8C, 0x6D, 0xA5, 0x48, 0xB3, 0xC9, 0x53, 0xE5, 0x1E, 0x63, 0x23, 0xDE, 0x38, 0xE7, 0xDB, 0x2D, 0xAB,
0x4E, 0xAF, 0xD1, 0x18, 0x8C, 0x94, 0x92, 0xFA, 0xB3, 0x4B, 0x52, 0x27, 0x91, 0xBB, 0xBB, 0x8F, 0x73, 0x7A,
0x87, 0xDC, 0xFE, 0x43, 0xF9, 0x71, 0xD4, 0x47, 0xE6, 0xD2, 0xBC, 0xDB, 0xBD, 0x38, 0xE6, 0x13, 0x52, 0xE6,
0xA8, 0xE9, 0xCD, 0x3F, 0x9A, 0xCF, 0xE4, 0xEC, 0xC7, 0x4F, 0x1B, 0x86, 0xC5, 0xDF, 0xCA, 0x5F, 0xB7, 0x2F,
0x77, 0xA7, 0x56, 0x95, 0x0A, 0x93, 0x5B, 0xB5, 0x62, 0x4E, 0xC0, 0xCE, 0x52, 0x18, 0x21, 0x92, 0x46, 0x08,
0xAC, 0xDD, 0xAA, 0x7B, 0x54, 0x9E, 0x07, 0x5C, 0x8A, 0x95, 0x6C, 0x5E, 0xB5, 0x5A, 0x95, 0x45, 0x13, 0xED,
0x5C, 0xB0, 0x9A, 0xB5, 0x92, 0x1D, 0xBC, 0xDD, 0x62, 0xC3, 0x05, 0x49, 0x50, 0xF9, 0x4C, 0x0F, 0x93, 0x18,
0x62, 0x03, 0xDE, 0x62, 0x3B, 0xCC, 0x77, 0x98, 0x8F, 0xBF, 0x38, 0x79, 0x0B, 0xF4, 0xF1, 0x54, 0x2F, 0x65,
0x32, 0x0F, 0x0A, 0xB4, 0x31, 0xB4, 0xEC, 0xDF, 0xBD, 0x65, 0x90, 0x52, 0xBA, 0xF4, 0xE9, 0xA4, 0xEC, 0x59,
0x79, 0xC0, 0x09, 0x14, 0x82, 0x52, 0xB3, 0x61, 0x40, 0x89, 0x17, 0x88, 0xCF, 0x88, 0xCC, 0xF6, 0x8E, 0x23,
0xA6, 0xE6, 0xEB, 0xCC, 0xD6, 0xE7, 0xEE, 0x0E, 0xB2, 0xDC, 0x0D, 0x41, 0x72, 0xC5, 0xDC, 0xA6, 0xAE, 0xD4,
0x99, 0x9C, 0xF4, 0xF2, 0x58, 0x72, 0xE6, 0x15, 0xCA, 0x64, 0x6C, 0xDD, 0x8A, 0x9C, 0x29, 0xC9, 0x48, 0x2A,
0xD3, 0x8E, 0x65, 0xAD, 0x56, 0xAC, 0x21, 0x60, 0xAD, 0x04, 0x69, 0x0C, 0x28, 0x91, 0xA2, 0xA8, 0xB9, 0x1A,
0xAE, 0xBD, 0x4B, 0x54, 0xD7, 0x30, 0x9A, 0xEE, 0x3D, 0x2A, 0x45, 0x6C, 0x3E, 0x32, 0x95, 0x01, 0x85, 0x0C,
0x44, 0x30, 0xEA, 0xD6, 0x52, 0x18, 0xF3, 0x2E, 0xD0, 0x4D, 0x73, 0xCD, 0x72, 0xD6, 0xB9, 0x9D, 0xD8, 0xD3,
0x22, 0x33, 0x99, 0x29, 0x99, 0xE6, 0xAA, 0x5B, 0xF6, 0xE1, 0x94, 0xDF, 0xF7, 0x4D, 0xA3, 0x73, 0xCC, 0x59,
0x7D, 0x9B, 0xDB, 0x26, 0x77, 0x29, 0x97, 0x61, 0x3C, 0xE4, 0xA5, 0x21, 0x7E, 0xEB, 0xED, 0x2A, 0xAA, 0x87,
0xBC, 0x82, 0x6B, 0xD5, 0x5B, 0x45, 0x15, 0xEB, 0xAA, 0x05, 0x28, 0x50, 0x0A, 0x94, 0x22, 0x03, 0x11, 0x13,
0xA7, 0xE5, 0x39, 0xBD, 0xF9, 0x4C, 0xBE, 0x94, 0xB5, 0xB7, 0x39, 0x9C, 0xAD, 0x8B, 0x8D, 0xA5, 0x72, 0x56,
0xA0, 0xC7, 0xC7, 0x6A, 0x56, 0x96, 0x48, 0x71, 0x19, 0x15, 0x97, 0x25, 0x55, 0x3D, 0x49, 0x09, 0x77, 0x44,
0xBB, 0x2E, 0x46, 0x28, 0x43, 0x31, 0x30, 0xC3, 0x0C, 0x70, 0xA7, 0x6C, 0x51, 0xC4, 0xAB, 0x35, 0xBE, 0x5C,
0xEA, 0x4A, 0xD7, 0xFA, 0x98, 0xAC, 0xCD, 0x4A, 0xCB, 0xAF, 0x4B, 0x6B, 0xC3, 0xD5, 0xBD, 0x3E, 0xA8, 0x80,
0x54, 0xE4, 0xF1, 0xF3, 0xFB, 0x6D, 0xF1, 0x15, 0x0C, 0x08, 0x2C, 0xA6, 0xBA, 0x71, 0xF6, 0x1B, 0xE1, 0x1D,
0x98, 0xDB, 0x46, 0xD2, 0x99, 0x61, 0xB2, 0x66, 0xDF, 0x7E, 0x9D, 0x3D, 0x44, 0x7E, 0xE1, 0xD0, 0xDB, 0x3A,
0xCE, 0x46, 0xF3, 0x6E, 0x65, 0x3A, 0x7D, 0xB2, 0x5E, 0xC5, 0x04, 0x58, 0x22, 0x6D, 0x81, 0xC1, 0x66, 0x62,
0x33, 0x78, 0x93, 0x63, 0xCC, 0x88, 0xDA, 0x11, 0x72, 0xC6, 0x66, 0x9D, 0x78, 0x61, 0x4C, 0xA5, 0x14, 0x57,
0x5C, 0x22, 0x10, 0xA4, 0x8C, 0x4E, 0x90, 0x21, 0x80, 0x23, 0xE8, 0x47, 0x23, 0xAC, 0x58, 0xE6, 0x7D, 0xF3,
0xF7, 0xA7, 0x1C, 0x85, 0x7F, 0x39, 0x9D, 0xD4, 0xB3, 0x81, 0xDB, 0x2D, 0xB8, 0xDA, 0xBC, 0x75, 0xD9, 0x2B,
0x59, 0xD7, 0x1A, 0x9E, 0xEE, 0xA0, 0xCA, 0xAD, 0x5B, 0x6F, 0x14, 0x92, 0x60, 0xF4, 0x95, 0x16, 0xAC, 0x69,
0xDB, 0x82, 0x27, 0x56, 0x7A, 0x97, 0xB2, 0x9A, 0x82, 0x85, 0x85, 0xF5, 0x81, 0x8A, 0x49, 0x71, 0x0C, 0xAA,
0xAE, 0xD1, 0xBF, 0xA7, 0x99, 0x7F, 0x0C, 0xB5, 0x55, 0xE4, 0xB7, 0x0D, 0x93, 0x68, 0xB2, 0x81, 0x6A, 0x75,
0xEC, 0x3A, 0x28, 0xD5, 0x96, 0xA4, 0x4C, 0x07, 0x23, 0x99, 0xB3, 0x26, 0x2F, 0x51, 0x98, 0xCC, 0x0B, 0xAB,
0xD3, 0xC6, 0xDA, 0x5C, 0xF8, 0x76, 0x31, 0x1B, 0x63, 0x33, 0x23, 0x05, 0x10, 0x53, 0x3B, 0xF5, 0x34, 0xDF,
0x9B, 0x84, 0xE9, 0xBE, 0x91, 0xA1, 0xD2, 0xB4, 0x68, 0xB3, 0xB8, 0xEC, 0x96, 0xF2, 0xD9, 0x08, 0x45, 0x82,
0x5B, 0x0F, 0x0D, 0xAC, 0xD2, 0x85, 0x1D, 0x5B, 0x0A, 0x59, 0x09, 0x15, 0x6B, 0x99, 0x2C, 0xE5, 0x07, 0x0F,
0xB6, 0x25, 0x66, 0xCC, 0x69, 0x40, 0xC1, 0x10, 0x14, 0x84, 0x5D, 0x79, 0x76, 0x54, 0xD4, 0x07, 0xC4, 0x05,
0x2C, 0xAE, 0x16, 0xCD, 0xEA, 0xD0, 0xE3, 0x31, 0x36, 0x63, 0xBC, 0x2B, 0x49, 0x24, 0x75, 0xED, 0x1C, 0x8C,
0x91, 0xD6, 0x82, 0xAD, 0xC5, 0x53, 0xE9, 0xCA, 0x9E, 0x97, 0xC5, 0xDA, 0x85, 0x25, 0x56, 0xE2, 0x6A, 0xCB,
0x22, 0x76, 0xB2, 0x77, 0x0F, 0x67, 0xF9, 0x95, 0x9D, 0xA7, 0x47, 0xA7, 0xB8, 0x7C, 0x19, 0xAA, 0xB3, 0x72,
0x19, 0xEC, 0xFA, 0xCE, 0xB4, 0xB6, 0x02, 0x6C, 0x57, 0xA5, 0x89, 0x49, 0x58, 0xBD, 0x66, 0xAF, 0x71, 0x93,
0x19, 0xF7, 0xBB, 0x1D, 0x55, 0xC4, 0x12, 0x31, 0xEA, 0xB5, 0x20, 0x73, 0x3E, 0x70, 0x33, 0x8C, 0x9F, 0xA6,
0x8E, 0xA7, 0x92, 0xCB, 0x75, 0x93, 0x64, 0xDA, 0x96, 0xEB, 0xC8, 0xC3, 0xEA, 0x5A, 0x83, 0xD7, 0x76, 0x2B,
0xCB, 0x46, 0x9D, 0xCC, 0x9E, 0xC1, 0x64, 0x29, 0x62, 0xA8, 0xDF, 0xF1, 0x21, 0x51, 0x8C, 0xD4, 0xAD, 0x99,
0xBF, 0x5D, 0x6C, 0x83, 0x2F, 0x7E, 0x3C, 0x58, 0xB1, 0x8F, 0x59, 0x10, 0xB6, 0xEE, 0x2B, 0xD4, 0x38, 0xEA,
0x9E, 0xA9, 0x26, 0x4F, 0x48, 0x77, 0xF3, 0xF5, 0xE7, 0xB9, 0xBE, 0xBE, 0xC3, 0xFC, 0x3A, 0x99, 0xBC, 0xB9,
0x9C, 0xF2, 0xEA, 0x3C, 0x5D, 0x5C, 0xD6, 0x0F, 0x29, 0x8A, 0xBD, 0x5A, 0x0B, 0x94, 0xEF, 0xD0, 0xB7, 0x52,
0xD5, 0x4B, 0x51, 0x24, 0xF5, 0xEC, 0xD7, 0xB3, 0x5E, 0x58, 0x27, 0x82, 0x78, 0x25, 0x56, 0x8E, 0x68, 0x66,
0x8A, 0x46, 0x8E, 0x58, 0xA4, 0x46, 0x49, 0x11, 0x99, 0x5D, 0x4A, 0x92, 0x3A, 0xFD, 0x14, 0xD6, 0xD7, 0x6A,
0x9E, 0x86, 0xB1, 0x2F, 0x4B, 0x01, 0xA9, 0x72, 0x8C, 0x96, 0xD5, 0x35, 0x65, 0x06, 0xB6, 0xA9, 0x81, 0x22,
0x6B, 0x62, 0xCC, 0x60, 0xC0, 0xC2, 0x60, 0x84, 0xA2, 0x08, 0x66, 0x26, 0x22, 0x79, 0xF8, 0xD8, 0xAF, 0x5E,
0xDD, 0x77, 0xD4, 0xB6, 0x84, 0xDA, 0xAB, 0x69, 0x2D, 0xAF, 0x66, 0xB5, 0x85, 0x03, 0xAB, 0xD8, 0xAE, 0xE0,
0x25, 0xB9, 0x0F, 0x4B, 0x04, 0x96, 0xD4, 0xB9, 0x64, 0x4B, 0x6A, 0x98, 0x24, 0x0C, 0x02, 0x20, 0x31, 0x91,
0x99, 0x89, 0x48, 0x0D, 0xDF, 0xD0, 0x76, 0x76, 0xBF, 0x74, 0xF7, 0x0B, 0x6F, 0x2D, 0x72, 0x64, 0xD1, 0xDA,
0xC3, 0x3F, 0x80, 0x8E, 0x42, 0x18, 0x0B, 0x15, 0x31, 0xF9, 0x19, 0xE1, 0xA1, 0x6D, 0x43, 0xAA, 0xBF, 0x65,
0xBA, 0x22, 0xBD, 0xA8, 0xCB, 0x28, 0x25, 0x26, 0x53, 0xF7, 0xEA, 0xE1, 0x68, 0xDB, 0x1A, 0xF6, 0xED, 0x3B,
0x59, 0xD9, 0x97, 0xF6, 0xFD, 0xEF, 0x09, 0x8F, 0xBE, 0xD1, 0xFC, 0x67, 0xD5, 0x65, 0xD5, 0xC2, 0x6D, 0xA6,
0x7C, 0x26, 0x47, 0xC9, 0x16, 0xA1, 0xC9, 0x2E, 0xD3, 0xDA, 0x08, 0x26, 0x3E, 0xDF, 0xE3, 0x9A, 0xAD, 0xF5,
0x53, 0x4B, 0x77, 0x4E, 0xFA, 0x93, 0xBC, 0xE8, 0xCE, 0xEF, 0x33, 0xAB, 0xED, 0x19, 0x9C, 0x3A, 0x19, 0x30,
0x71, 0xEF, 0xA5, 0x56, 0xEB, 0x47, 0x1F, 0x68, 0x60, 0xE0, 0x4F, 0xC2, 0xD5, 0x19, 0xAF, 0x64, 0x24, 0xA2,
0x26, 0x41, 0xA3, 0x3F, 0x7E, 0xFD, 0xE5, 0x97, 0x3C, 0xB3, 0xB7, 0x30, 0x6B, 0x2D, 0x94, 0xD3, 0x55, 0xA6,
0x99, 0x5E, 0xDE, 0x3B, 0x1F, 0x0E, 0x22, 0xC2, 0x99, 0x3B, 0xDF, 0xD7, 0xC3, 0x89, 0xE8, 0x4A, 0xEE, 0x09,
0xEE, 0x57, 0x97, 0xE1, 0x85, 0x8E, 0xD6, 0x1C, 0x85, 0x99, 0x48, 0x25, 0x0A, 0xB1, 0x91, 0x5D, 0x6A, 0xD6,
0xA7, 0x52, 0xEA, 0x9E, 0xEB, 0x86, 0x10, 0x20, 0xAF, 0x19, 0xAB, 0x19, 0x1A, 0x50, 0x41, 0x01, 0x1F, 0x43,
0x99, 0x80, 0xCB, 0x55, 0x15, 0xF6, 0x88, 0x12, 0x04, 0xA6, 0xE8, 0xD7, 0xF2, 0x1F, 0xB4, 0x92, 0x4A, 0x26,
0x04, 0xA0, 0x84, 0x76, 0x2F, 0xF8, 0xBF, 0xBC, 0x47, 0x50, 0xFA, 0x05, 0xD2, 0xFD, 0x94, 0x98, 0x0C, 0xB7,
0x3A, 0xC5, 0x4C, 0x2E, 0x4E, 0x45, 0x9E, 0xC2, 0xFD, 0xD3, 0x59, 0x26, 0x6B, 0xB7, 0xD8, 0xD8, 0x99, 0x93,
0x5B, 0x2C, 0xD8, 0xC6, 0x1D, 0xCF, 0x59, 0xFD, 0xE0, 0x2C, 0x81, 0x44, 0x98, 0x10, 0x19, 0x49, 0xEF, 0x5E,
0x5D, 0xCF, 0x7B, 0xE7, 0x0C, 0x79, 0x8D, 0xEE, 0x63, 0x6D, 0x97, 0x84, 0x9D, 0xD3, 0xB9, 0x5A, 0xDA, 0x55,
0xCA, 0xEA, 0xAC, 0x6C, 0x1A, 0x0B, 0x12, 0xA5, 0x0B, 0xC9, 0x66, 0x5D, 0x65, 0x61, 0x70, 0xD9, 0x48, 0xA0,
0x3D, 0xAC, 0xB1, 0xCD, 0x0E, 0x9C, 0x9F, 0x37, 0x79, 0x26, 0x73, 0x1F, 0xA5, 0xF0, 0x65, 0xE1, 0x7F, 0x89,
0x10, 0xAB, 0x7B, 0x57, 0xC7, 0x9D, 0x67, 0xF9, 0x4F, 0x57, 0xB4, 0xFA, 0x8C, 0x4C, 0xBA, 0xA6, 0x32, 0xF1,
0xEC, 0x17, 0x67, 0xCA, 0x20, 0x14, 0xAC, 0x1A, 0x4F, 0x21, 0x58, 0x99, 0x1D, 0xE2, 0x4D, 0x6C, 0xC9, 0x2A,
0x8D, 0x62, 0x5C, 0x41, 0x41, 0xFB, 0xE0, 0x4C, 0x7D, 0x52, 0xC2, 0x8C, 0x5F, 0xF9, 0x95, 0xBC, 0xFF, 0x00,
0x02, 0xF8, 0xE3, 0xD4, 0x9B, 0xE9, 0xB2, 0x35, 0xF2, 0x39, 0xDC, 0x52, 0xF4, 0xEC, 0x64, 0x48, 0x49, 0x1B,
0xDD, 0xB5, 0x58, 0x5E, 0x22, 0xFA, 0xD3, 0x3E, 0x32, 0x2B, 0x72, 0x70, 0x6F, 0xCB, 0x5D, 0x06, 0x94, 0x84,
0xAF, 0xE9, 0x24, 0xD4, 0x7E, 0xF8, 0x50, 0x92, 0x86, 0xC7, 0x5E, 0x69, 0xA2, 0xB1, 0x34, 0x71, 0xB3, 0x45,
0x56, 0x34, 0x92, 0xC3, 0x80, 0x4A, 0xC4, 0x92, 0x4D, 0x1C, 0x08, 0x58, 0x8F, 0x60, 0x1A, 0x59, 0x51, 0x07,
0x3C, 0x72, 0x4F, 0x1F, 0x5E, 0x07, 0x55, 0xE6, 0xCE, 0x46, 0x9D, 0x4B, 0x58, 0xEA, 0x56, 0x1C, 0x0B, 0xB3,
0x95, 0x7B, 0xEB, 0xD1, 0x54, 0xCC, 0x41, 0xBD, 0xB5, 0xAA, 0x3E, 0xF3, 0xE0, 0x22, 0x66, 0x26, 0x7D, 0x75,
0xAB, 0xB5, 0x85, 0xDB, 0xBC, 0xC4, 0x44, 0x4F, 0x6E, 0xDD, 0xE6, 0x35, 0xCA, 0xA5, 0x86, 0xC9, 0x64, 0x28,
0xE6, 0x32, 0x55, 0x2A, 0xB1, 0xD4, 0xB0, 0x15, 0x6A, 0xDC, 0xCA, 0xD8, 0x11, 0x99, 0x5D, 0x44, 0x5D, 0xC8,
0xD4, 0xC5, 0x55, 0x26, 0x14, 0x44, 0xC0, 0xFB, 0xAE, 0xDD, 0x42, 0x43, 0xCB, 0xB4, 0x49, 0x14, 0xC7, 0x7E,
0xFD, 0xA2, 0x7B, 0xAB, 0xCB, 0xC7, 0x70, 0x9B, 0x44, 0xEF, 0xD5, 0x4C, 0x74, 0x96, 0x24, 0x8A, 0xAE, 0xA8,
0xC7, 0x49, 0x51, 0x63, 0x52, 0xA2, 0x39, 0x32, 0x18, 0xF9, 0x05, 0xBA, 0xED, 0x20, 0x66, 0x5E, 0x3B, 0x28,
0xB6, 0x4C, 0x2B, 0x2F, 0x71, 0xEE, 0x70, 0x0A, 0xF6, 0x92, 0xC9, 0x89, 0xDF, 0x32, 0x75, 0x8F, 0xDC, 0xFA,
0x7D, 0x88, 0xD9, 0x52, 0xA5, 0x95, 0x8D, 0x5F, 0x38, 0xB0, 0x7B, 0x4A, 0x26, 0x0D, 0x78, 0xBC, 0xE0, 0x45,
0x37, 0xC0, 0x4C, 0x44, 0xC4, 0xF9, 0x64, 0x93, 0x88, 0x89, 0x12, 0xF1, 0x8E, 0xDD, 0xCA, 0x0E, 0x08, 0x60,
0x19, 0x42, 0x7F, 0x4D, 0x2D, 0xEF, 0xF6, 0x1E, 0xB0, 0xEC, 0x5A, 0x3D, 0x87, 0xB4, 0x2A, 0x6F, 0xBA, 0xAB,
0x99, 0x52, 0xB8, 0xC8, 0xCA, 0x9D, 0x9E, 0xD5, 0x5A, 0x59, 0x3A, 0x84, 0xC1, 0x22, 0x19, 0x8F, 0x5E, 0x12,
0xC6, 0xC7, 0x22, 0x6B, 0x83, 0x3F, 0x2F, 0x10, 0x25, 0xC8, 0x11, 0x31, 0x4D, 0xB9, 0x87, 0xB6, 0x97, 0x71,
0xD5, 0x6C, 0xA1, 0x0C, 0xB2, 0x44, 0x18, 0x30, 0xF7, 0x07, 0x92, 0x7F, 0xD3, 0xFA, 0xFA, 0x09, 0x9B, 0xCB,
0x99, 0xCC, 0x93, 0x1E, 0x01, 0x3F, 0xB0, 0x13, 0xFD, 0x83, 0x9E, 0x9C, 0x71, 0x52, 0xFC, 0xD6, 0xF7, 0x27,
0xF4, 0xEB, 0xC5, 0x7E, 0x63, 0x01, 0x5E, 0xC4, 0x33, 0xE3, 0xF6, 0xCF, 0x4C, 0xE0, 0xF4, 0x84, 0x5F, 0x0D,
0x21, 0x96, 0x23, 0x91, 0xB4, 0x93, 0xEA, 0x8C, 0xAB, 0xC8, 0xC1, 0xDE, 0x3F, 0x8B, 0x86, 0x6C, 0xF4, 0x58,
0xCB, 0x6B, 0x17, 0x6F, 0xA2, 0xF8, 0xC5, 0xAF, 0x32, 0x2D, 0x98, 0x66, 0x1D, 0x55, 0x1F, 0x89, 0x3A, 0xD7,
0xEC, 0x9D, 0x27, 0x46, 0x51, 0xAB, 0x60, 0x59, 0xDA, 0xB3, 0x19, 0x1C, 0xBC, 0xCB, 0x47, 0xC0, 0xFE, 0x92,
0xB1, 0x8E, 0x22, 0x98, 0x88, 0xF6, 0x12, 0xF4, 0x98, 0xE3, 0xDB, 0x6D, 0x24, 0x7D, 0xE5, 0x83, 0x6E, 0x5A,
0x05, 0x2A, 0x35, 0xCF, 0x20, 0x27, 0xEA, 0x23, 0xBB, 0xC6, 0xD3, 0xF2, 0x12, 0xDE, 0x05, 0x0E, 0x53, 0x69,
0x68, 0x3A, 0xDE, 0x17, 0x5C, 0x1F, 0x43, 0x3D, 0x8A, 0x9C, 0x85, 0xC5, 0x33, 0x63, 0xC9, 0x19, 0x94, 0x19,
0x87, 0xD5, 0x2C, 0xF3, 0x28, 0xC7, 0x59, 0x15, 0xF8, 0xFA, 0x8F, 0x1C, 0x28, 0x68, 0x0D, 0x84, 0xBB, 0x9D,
0x29, 0xE5, 0x45, 0xB5, 0xED, 0x63, 0xF1, 0x0D, 0x63, 0x66, 0xB9, 0xE7, 0x27, 0x90, 0x9C, 0x43, 0x23, 0x76,
0x90, 0xD4, 0xA8, 0x44, 0xD5, 0xE0, 0xF6, 0xE3, 0x94, 0xE2, 0xDA, 0xDE, 0x6F, 0x98, 0xF2, 0xCA, 0xCA, 0xC1,
0x7B, 0x48, 0x27, 0x16, 0xFE, 0x5F, 0x6D, 0x51, 0x9A, 0xEA, 0x62, 0x30, 0x09, 0x6C, 0x1D, 0x6D, 0x47, 0x0F,
0x5A, 0xA3, 0x02, 0x04, 0xA2, 0x03, 0x27, 0x95, 0x81, 0xC9, 0xDC, 0x98, 0x39, 0xFC, 0x4F, 0xBD, 0x36, 0xE2,
0xD6, 0x5E, 0x1F, 0x60, 0x62, 0x4C, 0x0A, 0x7C, 0xC4, 0xC4, 0x73, 0xDB, 0xF4, 0xE1, 0xD0, 0x67, 0x58, 0xE8,
0x6D, 0xCD, 0xBE, 0xCA, 0x25, 0x57, 0xBA, 0x89, 0xB2, 0xDE, 0xC8, 0x25, 0xB2, 0x61, 0x32, 0xCC, 0x16, 0xBF,
0x27, 0x82, 0xC6, 0x8C, 0xAC, 0x7F, 0x35, 0xF8, 0xE4, 0xD1, 0x9F, 0x70, 0x43, 0x66, 0x09, 0x8A, 0xB0, 0xB6,
0x80, 0xC2, 0x8D, 0x66, 0x6C, 0x3D, 0x1A, 0x04, 0x45, 0x41, 0xF4, 0x51, 0xC7, 0x58, 0xA5, 0xCA, 0x0B, 0xCA,
0x98, 0x77, 0x2B, 0x0F, 0xDA, 0x08, 0xFE, 0xD1, 0xC7, 0x4E, 0x38, 0xAD, 0x9E, 0x6D, 0xBB, 0x61, 0x2E, 0x8D,
0xF1, 0x27, 0x5B, 0x5B, 0xC3, 0x04, 0xCB, 0x8D, 0xDC, 0xFD, 0x2F, 0x4B, 0x20, 0xF6, 0x5A, 0x12, 0x90, 0x3E,
0x77, 0x4C, 0x91, 0xA7, 0xF2, 0x35, 0x62, 0x97, 0x92, 0xB2, 0x3C, 0x18, 0x88, 0x74, 0xE4, 0xF2, 0xAF, 0xCA,
0xF1, 0xFC, 0x62, 0xF7, 0x2F, 0x6B, 0x23, 0x35, 0x3A, 0xF8, 0x77, 0xB4, 0x0E, 0x5B, 0xA7, 0x17, 0xB5, 0xB6,
0x30, 0x26, 0xCE, 0xA7, 0x9A, 0xB0, 0x00, 0xA8, 0x3F, 0x23, 0x1C, 0x6E, 0x6E, 0x4F, 0x25, 0x59, 0xA4, 0x1F,
0xE4, 0x05, 0x99, 0x09, 0xCB, 0x80, 0xCF, 0xDC, 0x4B, 0xD2, 0x53, 0x13, 0xE5, 0x05, 0x11, 0x09, 0xFF, 0x00,
0x52, 0x6D, 0x0D, 0x9A, 0xF7, 0x5B, 0x31, 0x5B, 0xAA, 0x92, 0xD8, 0xA3, 0xD4, 0x2D, 0x5E, 0x9B, 0x5B, 0x60,
0x95, 0x22, 0x93, 0xCD, 0xEA, 0xE2, 0xAC, 0x1D, 0xEA, 0xEB, 0x6F, 0x79, 0x16, 0x12, 0x70, 0xE3, 0xAE, 0xB5,
0x83, 0xF6, 0x30, 0xFA, 0x91, 0x82, 0x8F, 0x12, 0x09, 0x9D, 0xA1, 0xE5, 0x2D, 0xB9, 0x3F, 0x86, 0xE7, 0xB5,
0x3E, 0x88, 0xB1, 0x3A, 0x46, 0x91, 0xDD, 0x87, 0x33, 0x55, 0x19, 0xF8, 0x77, 0x8F, 0x23, 0x55, 0xEA, 0x4E,
0xAA, 0x85, 0x87, 0x74, 0x70, 0x4D, 0x42, 0x36, 0x66, 0x55, 0xF9, 0x1E, 0xDA, 0x87, 0x6F, 0xD6, 0x46, 0x07,
0x8D, 0x7C, 0xD2, 0xD6, 0xBE, 0x93, 0x69, 0xD5, 0x36, 0xB5, 0x2D, 0x9E, 0xBC, 0xD6, 0x1E, 0xCE, 0x22, 0xD1,
0x88, 0xCC, 0xA8, 0x6D, 0xE1, 0x6C, 0x8B, 0xD2, 0x66, 0x70, 0x3F, 0x83, 0xAC, 0x55, 0xCA, 0x0A, 0xC0, 0x48,
0xA3, 0xD8, 0xBA, 0x25, 0x2B, 0x1E, 0xEA, 0x71, 0x73, 0x25, 0xFF, 0x00, 0x4C, 0x3D, 0xE3, 0xF7, 0x1D, 0x0B,
0xA8, 0x3D, 0x3E, 0xB0, 0xE5, 0x7B, 0xB5, 0x8D, 0x8E, 0x8E, 0xC7, 0x41, 0x64, 0x71, 0x16, 0x0F, 0x1F, 0xB3,
0xD2, 0x2A, 0x96, 0x56, 0xA5, 0xC9, 0xF7, 0x65, 0x6A, 0x77, 0xF0, 0x12, 0xE6, 0x98, 0x2F, 0xFA, 0x5D, 0x95,
0x01, 0x73, 0x3B, 0x3E, 0xB8, 0xC3, 0x20, 0xC6, 0xE1, 0xD1, 0x5C, 0x7B, 0x86, 0x1C, 0xF5, 0x85, 0x5C, 0xA8,
0x3C, 0x81, 0xDF, 0x3A, 0x8D, 0xCD, 0x29, 0x8E, 0xDA, 0x1D, 0xA0, 0xA9, 0x68, 0xFF, 0x00, 0xBE, 0x5F, 0xCA,
0xEE, 0x0E, 0x6E, 0xAA, 0xA2, 0x8E, 0xD4, 0xC5, 0xC3, 0x36, 0x9E, 0xD3, 0xB2, 0x3C, 0xBC, 0x7A, 0x85, 0x66,
0x93, 0x29, 0xA9, 0x41, 0x85, 0x58, 0x46, 0x5E, 0xA2, 0x49, 0x32, 0x97, 0x8E, 0xB9, 0x4C, 0xE9, 0xF8, 0x53,
0xAC, 0x7B, 0x72, 0x5B, 0x96, 0xE2, 0xE5, 0x47, 0x6A, 0x94, 0xE9, 0xEB, 0x94, 0x5B, 0x25, 0x33, 0xDD, 0x97,
0x5D, 0x19, 0x1C, 0x90, 0x88, 0x7F, 0xAC, 0x12, 0xC2, 0x96, 0x33, 0xFB, 0x26, 0x3C, 0xE0, 0x5E, 0x40, 0x13,
0xE2, 0x6D, 0x89, 0x94, 0x1F, 0xAA, 0x16, 0xF5, 0xE9, 0xC2, 0xF4, 0xD3, 0xA6, 0xB5, 0xEC, 0x4F, 0x96, 0x43,
0x25, 0x92, 0xDD, 0x72, 0xD5, 0xE0, 0x06, 0x26, 0x15, 0x8C, 0xAE, 0x58, 0x4C, 0x19, 0x9B, 0x66, 0x3C, 0xE4,
0x1C, 0xDC, 0x9E, 0x7B, 0xFA, 0x44, 0xBD, 0x64, 0x75, 0x45, 0x8D, 0x19, 0x35, 0xA0, 0x86, 0x3A, 0x7C, 0x2D,
0x6C, 0x25, 0xCD, 0xDC, 0xDB, 0xAD, 0xE4, 0x92, 0xB5, 0x39, 0x2C, 0xDD, 0x9F, 0x4F, 0x64, 0x6A, 0x60, 0x56,
0x28, 0xCC, 0x93, 0xCB, 0x97, 0xC0, 0xE3, 0x65, 0xCE, 0xD1, 0x86, 0x25, 0xE3, 0xE6, 0x5B, 0x59, 0x4F, 0xC3,
0xE0, 0x60, 0xA7, 0xBA, 0x43, 0x1B, 0x28, 0xE1, 0x94, 0x1E, 0xBB, 0x9F, 0xC8, 0x0E, 0xA5, 0xC6, 0xAD, 0xD6,
0x7E, 0x90, 0x57, 0x1B, 0x30, 0xBA, 0xBA, 0xD3, 0xE7, 0x35, 0x99, 0xF2, 0x3F, 0x04, 0x05, 0x4D, 0x8E, 0xCF,
0xEC, 0x96, 0x49, 0xA5, 0x1D, 0xFB, 0x36, 0xBE, 0x1E, 0xBE, 0x41, 0x81, 0x25, 0x13, 0x0B, 0x5D, 0xB8, 0x2F,
0xBC, 0x30, 0xA3, 0x9E, 0x67, 0xF0, 0xFF, 0x00, 0xA1, 0xC5, 0xBF, 0x7C, 0x65, 0xF9, 0x21, 0x70, 0xE9, 0x4B,
0xF2, 0x1B, 0xBD, 0x41, 0xD6, 0x75, 0x9F, 0x05, 0xFB, 0x2D, 0xB3, 0x23, 0xA5, 0x51, 0xFE, 0x53, 0x44, 0x10,
0x33, 0x1D, 0xE6, 0xBD, 0xDD, 0x8E, 0xEE, 0x19, 0x2C, 0x80, 0x2F, 0x27, 0x37, 0x1D, 0x21, 0xF8, 0x92, 0x42,
0x79, 0xC9, 0xDB, 0x77, 0xA9, 0xE5, 0xD1, 0x5A, 0xF3, 0x49, 0x6A, 0x98, 0xD9, 0xE3, 0x38, 0x2D, 0x41, 0x8D,
0xBD, 0x3F, 0x63, 0x98, 0x9D, 0xAA, 0xC5, 0x6A, 0x31, 0x7A, 0x1E, 0xF1, 0xEE, 0x82, 0x6A, 0x6D, 0x3C, 0x2D,
0xC8, 0x23, 0xB5, 0xC8, 0x65, 0x65, 0x25, 0x4E, 0x4F, 0xF5, 0x1F, 0x5A, 0x1D, 0xC7, 0x43, 0xDB, 0x35, 0xAF,
0x11, 0x36, 0x65, 0xF0, 0x77, 0x91, 0x53, 0xC9, 0x70, 0xE1, 0x1B, 0xE0, 0x99, 0x7E, 0x35, 0xB0, 0xBF, 0xB7,
0x9C, 0xA6, 0xFA, 0xAB, 0x38, 0x20, 0x66, 0x0B, 0xC8, 0x22, 0x40, 0x84, 0xA2, 0x26, 0x30, 0x47, 0xA2, 0xDB,
0xB9, 0xF4, 0xDB, 0xAB, 0x5D, 0x3D, 0xDD, 0xE4, 0xD8, 0xB4, 0xEB, 0xBB, 0x5E, 0x26, 0xDE, 0x46, 0x01, 0xD3,
0x5C, 0xD9, 0x88, 0x3B, 0x23, 0x53, 0x35, 0x5E, 0x5B, 0x11, 0x3E, 0xB1, 0xB3, 0x89, 0xB1, 0x76, 0xB3, 0x24,
0x84, 0x82, 0x41, 0xA4, 0x2C, 0x03, 0x09, 0x21, 0x97, 0x47, 0xD8, 0xCD, 0x4B, 0x1E, 0xA5, 0xD0, 0x38, 0x5B,
0x8B, 0x20, 0x76, 0x6A, 0x50, 0x96, 0x3C, 0xF3, 0xC1, 0x63, 0x21, 0xE3, 0xFB, 0xBF, 0x90, 0xEA, 0x22, 0x73,
0x69, 0x9E, 0x6C, 0xDD, 0x43, 0x97, 0xA5, 0x80, 0xC1, 0x65, 0xF3, 0x79, 0x2B, 0x31, 0xD3, 0xC7, 0x62, 0x71,
0xB7, 0xB2, 0x37, 0xED, 0xCA, 0x48, 0x8A, 0xB5, 0x3A, 0x35, 0x65, 0xB5, 0x66, 0xC4, 0x84, 0x02, 0x42, 0x43,
0x04, 0x4F, 0x23, 0x90, 0x09, 0xED, 0x53, 0xC0, 0x27, 0x8E, 0xBF, 0x7A, 0xD5, 0x9F, 0x72, 0xCD, 0x7A, 0x95,
0x54, 0x4E, 0xB3, 0x69, 0xEA, 0xAD, 0x5D, 0x21, 0x1D, 0xCD, 0xAF, 0x7B, 0x05, 0x4A, 0x50, 0x44, 0xCC, 0x44,
0x93, 0x18, 0x42, 0x03, 0x13, 0x31, 0xF7, 0x98, 0xFB, 0xF3, 0x8B, 0x7A, 0xED, 0x5C, 0x6D, 0x2B, 0x99, 0x1B,
0xEF, 0x0A, 0xB4, 0x68, 0x55, 0xB1, 0x76, 0xE5, 0x96, 0xCC, 0xC2, 0xEB, 0xD5, 0xAA, 0xA3, 0x7D, 0x87, 0xB2,
0x62, 0x26, 0x60, 0x14, 0x95, 0x9B, 0x0E, 0x62, 0x26, 0x60, 0x46, 0x7B, 0x44, 0xF1, 0x1D, 0xB7, 0x33, 0x59,
0x64, 0x37, 0x47, 0x73, 0xB5, 0xC6, 0xBA, 0xB6, 0x0C, 0x99, 0x0D, 0x75, 0xAC, 0xB3, 0xDA, 0x84, 0xC4, 0xAB,
0xDA, 0x11, 0xF3, 0x99, 0x6B, 0x36, 0xEB, 0xD5, 0x8D, 0x09, 0x25, 0x23, 0x82, 0x3B, 0x11, 0x56, 0x85, 0x09,
0x25, 0x23, 0x8D, 0x14, 0x92, 0x47, 0x26, 0xE1, 0x6B, 0x38, 0x8A, 0x7A, 0x6E, 0x9F, 0x84, 0xC2, 0xF9, 0x42,
0xA9, 0xEB, 0x78, 0x0A, 0x54, 0xDA, 0xD2, 0x9F, 0x28, 0x80, 0xC6, 0xD1, 0x00, 0xB1, 0x60, 0xCA, 0x3F, 0xDA,
0x4C, 0x94, 0xC7, 0x30, 0xA2, 0x3E, 0xE4, 0x45, 0x31, 0x11, 0x13, 0x11, 0xCD, 0x56, 0xB7, 0x8D, 0x8B, 0x25,
0xD4, 0xBE, 0xA3, 0xED, 0x1B, 0x3C, 0xAC, 0x9F, 0x92, 0xDD, 0xB6, 0xEC, 0xA6, 0x4D, 0x15, 0xC0, 0x7C, 0x66,
0x5B, 0x9B, 0xCA, 0xB5, 0x94, 0xE9, 0xA8, 0x66, 0x7F, 0x11, 0x58, 0xBD, 0x35, 0x52, 0x25, 0x3D, 0xC4, 0x00,
0x04, 0x8A, 0x66, 0x26, 0x78, 0xD3, 0x3E, 0x00, 0xF6, 0xC6, 0x1D, 0x0D, 0xB5, 0x38, 0x18, 0x8C, 0x28, 0x92,
0xC7, 0x8C, 0xA0, 0x8E, 0xE8, 0x9D, 0xA2, 0x59, 0x96, 0xAB, 0xA5, 0x89, 0xBD, 0xC2, 0x92, 0x6C, 0x4F, 0xEA,
0x4C, 0xCC, 0xCA, 0x19, 0x99, 0xCB, 0x30, 0xE4, 0xFB, 0x45, 0xAD, 0xC7, 0x61, 0x7E, 0xDB, 0xB5, 0xEC, 0x5B,
0x35, 0x89, 0x67, 0xB3, 0x39, 0x99, 0xC8, 0x64, 0x84, 0x1A, 0x50, 0x46, 0x94, 0xDA, 0xB2, 0xC6, 0x56, 0xAD,
0x33, 0x12, 0x43, 0x03, 0x56, 0xBC, 0xAA, 0xB0, 0x08, 0xCC, 0x88, 0x02, 0x84, 0x46, 0x7C, 0x62, 0x39, 0xB3,
0xCF, 0x4D, 0xB4, 0xDA, 0xBD, 0x3C, 0xE9, 0xFE, 0x99, 0xA3, 0x53, 0x84, 0x7A, 0xB5, 0x4D, 0x6B, 0x0F, 0x84,
0x36, 0x57, 0x19, 0x05, 0x5A, 0xB5, 0x42, 0x8A, 0x53, 0x76, 0xF4, 0x41, 0x08, 0x94, 0x9D, 0xFB, 0xA3, 0x62,
0xEB, 0x4C, 0xC4, 0x4D, 0x8D, 0xB0, 0x6C, 0x38, 0x83, 0x22, 0xE4, 0x84, 0x75, 0xD6, 0xF9, 0xDD, 0xB8, 0x74,
0xE3, 0x91, 0x09, 0xE7, 0x09, 0xB5, 0x87, 0x54, 0xEC, 0x36, 0x17, 0x71, 0x69, 0xD6, 0x32, 0xDF, 0xDB, 0x5D,
0x53, 0x46, 0xC5, 0xA9, 0x95, 0xE3, 0x06, 0x1D, 0x3D, 0xA9, 0x8B, 0x61, 0x32, 0x2B, 0xE9, 0xB7, 0xCF, 0x21,
0x6C, 0xBC, 0x9A, 0x76, 0x56, 0xF4, 0x89, 0x68, 0xE2, 0x82, 0x59, 0x59, 0x0C, 0x48, 0xEF, 0x1E, 0x56, 0xFC,
0x41, 0xDA, 0xA3, 0x0B, 0xD4, 0xC7, 0xE0, 0x1C, 0xD8, 0x0A, 0xDB, 0x76, 0x1E, 0xCD, 0x45, 0x84, 0x89, 0x4C,
0x1E, 0x4F, 0x15, 0x05, 0x93, 0xA7, 0x32, 0x71, 0xF8, 0x87, 0x6A, 0x6A, 0xCA, 0x2C, 0x7C, 0xFE, 0xC6, 0xC7,
0x00, 0x0C, 0xF9, 0x90, 0x09, 0x4F, 0xAF, 0xD4, 0x7B, 0x41, 0x9D, 0x9F, 0xA1, 0xB4, 0xF6, 0xFA, 0xC8, 0x96,
0xDE, 0xE9, 0xDE, 0xCB, 0x4B, 0x20, 0xE6, 0xC1, 0x84, 0x4A, 0xF0, 0x5B, 0x04, 0x86, 0x0B, 0x24, 0x30, 0xB2,
0xFC, 0xD9, 0xE5, 0x93, 0x7E, 0x01, 0xC7, 0x0A, 0x99, 0x25, 0xAA, 0xBB, 0x1A, 0x63, 0x2A, 0x06, 0x18, 0x42,
0x3F, 0x82, 0xDD, 0x76, 0xFA, 0x13, 0x7F, 0xF4, 0x8D, 0x83, 0x3A, 0xC1, 0x57, 0x3A, 0x67, 0xC0, 0x59, 0x67,
0x24, 0x2F, 0x75, 0x9F, 0x4E, 0xD5, 0x30, 0x08, 0x3E, 0xD2, 0x49, 0x76, 0x9D, 0x7A, 0xE8, 0x48, 0x23, 0xF5,
0xEC, 0xA7, 0x80, 0xDD, 0xC3, 0x2B, 0xFE, 0x57, 0x6B, 0x3F, 0xBF, 0xF4, 0x93, 0x21, 0x79, 0x4A, 0x36, 0xDB,
0xD5, 0xB2, 0x58, 0xFC, 0xF2, 0x61, 0x7D, 0xBC, 0xBE, 0x9E, 0x18, 0x58, 0xDC, 0x87, 0x94, 0x4C, 0x7D, 0xD2,
0xAA, 0x79, 0x06, 0xDB, 0x6C, 0x44, 0xC4, 0xC7, 0xD2, 0x89, 0xF7, 0x9F, 0x0F, 0x12, 0x9F, 0x5F, 0xA7, 0xDE,
0xF3, 0x1A, 0x87, 0xC8, 0xAC, 0x36, 0x29, 0xF6, 0x14, 0x8C, 0x7E, 0xFB, 0x84, 0xCC, 0x6A, 0x56, 0x65, 0xDD,
0xFC, 0x3E, 0xAE, 0x52, 0x19, 0xCC, 0x47, 0x84, 0xC4, 0xC7, 0x8D, 0x97, 0xE4, 0xF0, 0xD5, 0xF1, 0xE8, 0x29,
0x82, 0x89, 0xFA, 0xF3, 0x57, 0x68, 0x96, 0x41, 0x83, 0x88, 0x69, 0x8C, 0x9A, 0x64, 0xF0, 0x34, 0x6F, 0x2B,
0x86, 0x59, 0x2B, 0x07, 0x2C, 0x0F, 0x3F, 0x77, 0xFB, 0xFE, 0x43, 0xFA, 0xFB, 0x4A, 0x3E, 0x6C, 0x15, 0xC5,
0x3F, 0xF3, 0x33, 0xDC, 0x8F, 0xF6, 0x89, 0xE2, 0xE7, 0x5F, 0xC3, 0x5E, 0xE3, 0x5C, 0xC5, 0xE8, 0x2A, 0xD8,
0x9D, 0x01, 0x8D, 0x3F, 0x44, 0x85, 0xF0, 0xF0, 0x3D, 0xFC, 0xDD, 0x74, 0x51, 0xC7, 0xBC, 0x1A, 0x9B, 0x2D,
0x9A, 0x81, 0xD8, 0xF2, 0xCE, 0xD1, 0x7B, 0x1F, 0x4C, 0x46, 0x05, 0x68, 0xF8, 0xB9, 0xAD, 0x4E, 0xBD, 0xD1,
0xFC, 0x1B, 0x9A, 0x98, 0x4D, 0xAD, 0x8E, 0xD5, 0xFD, 0x8A, 0xCF, 0xFC, 0x91, 0x85, 0xB7, 0x45, 0x5C, 0x7B,
0x0A, 0x7F, 0xF0, 0xCC, 0x5D, 0x2A, 0x2D, 0x11, 0x8F, 0xB0, 0xC3, 0x3F, 0xC7, 0x94, 0x94, 0xCE, 0xBC, 0x5F,
0x3D, 0x37, 0x78, 0xDC, 0xBE, 0x48, 0x6D, 0x75, 0x91, 0x66, 0x6C, 0xE3, 0xF4, 0xAA, 0x38, 0x8D, 0x32, 0x97,
0xFC, 0x02, 0x99, 0x8E, 0xAD, 0x37, 0xF3, 0x09, 0x11, 0xFF, 0x00, 0xF4, 0x9C, 0xFE, 0x53, 0x2A, 0x83, 0x29,
0xFC, 0x88, 0x95, 0xFE, 0x7C, 0x20, 0x22, 0x25, 0x67, 0xCB, 0x27, 0x6C, 0x46, 0x23, 0x69, 0x68, 0x5D, 0xB3,
0x5D, 0x04, 0xF9, 0x4A, 0x0F, 0x91, 0x91, 0x84, 0x7D, 0xAC, 0xCD, 0x98, 0x82, 0xC5, 0xC5, 0x12, 0x92, 0xAA,
0xCD, 0x24, 0x51, 0x4F, 0x1D, 0x76, 0x27, 0x9E, 0x04, 0x41, 0x15, 0x9A, 0x34, 0x5E, 0xA7, 0x97, 0x5D, 0xB6,
0x48, 0xDA, 0xBA, 0xB5, 0xBB, 0xE4, 0xC1, 0x8C, 0x65, 0x64, 0x66, 0x19, 0x87, 0xA7, 0xE6, 0x5E, 0x41, 0x15,
0xB0, 0x4B, 0x5E, 0x1C, 0x49, 0x11, 0x04, 0x42, 0x08, 0xB0, 0xCA, 0x4C, 0xB6, 0x10, 0x3E, 0x32, 0x53, 0x60,
0x9A, 0xC1, 0x16, 0xB1, 0x9C, 0xB2, 0x7F, 0x13, 0x74, 0x99, 0xD0, 0x7E, 0x3C, 0x74, 0xB7, 0x06, 0xD4, 0xA5,
0x37, 0x6D, 0xEB, 0x89, 0xD9, 0x72, 0x3E, 0xB5, 0xF8, 0x34, 0xAE, 0xED, 0x8E, 0x76, 0xC8, 0x4B, 0xB6, 0x44,
0x00, 0x6C, 0xB7, 0x4D, 0x39, 0x34, 0x63, 0x9A, 0x47, 0xE7, 0xEB, 0x8A, 0x41, 0x5D, 0x4C, 0x3A, 0xE9, 0x4C,
0xF2, 0x0A, 0x7C, 0x54, 0xED, 0xAB, 0xED, 0x17, 0x88, 0x7D, 0xDA, 0xD0, 0x42, 0xBB, 0x56, 0xA5, 0x89, 0xD6,
0x39, 0x2B, 0x78, 0x68, 0x99, 0x92, 0x4E, 0x34, 0xFE, 0x75, 0x97, 0x3D, 0x81, 0x02, 0x48, 0xFE, 0x49, 0x0A,
0x62, 0x72, 0x54, 0xE2, 0x90, 0xAF, 0x05, 0x26, 0x8E, 0x48, 0xA4, 0x54, 0x9A, 0x39, 0x23, 0x5A, 0x95, 0xD1,
0xDD, 0xA6, 0x37, 0x2E, 0x99, 0x69, 0xB9, 0xF9, 0x68, 0xB6, 0xCD, 0x8C, 0x32, 0x2A, 0x64, 0x0A, 0x22, 0x42,
0x7F, 0x73, 0xC5, 0x49, 0xE2, 0xF2, 0x33, 0x20, 0x5D, 0xC8, 0x3C, 0xEE, 0x53, 0x73, 0x06, 0x27, 0xEC, 0x4B,
0x30, 0x60, 0x49, 0x2C, 0xC0, 0xA6, 0x08, 0x7C, 0x92, 0xD0, 0x8B, 0xA6, 0x9D, 0x73, 0xEA, 0x5E, 0xA0, 0x28,
0x2A, 0xF4, 0xA9, 0xEC, 0xD6, 0xF2, 0x18, 0x85, 0x91, 0x0B, 0x22, 0x30, 0x79, 0xF1, 0x5E, 0x7B, 0x0B, 0x02,
0xC0, 0x88, 0x06, 0x7A, 0xF1, 0x99, 0x2A, 0xC9, 0x67, 0x6E, 0xC4, 0xB7, 0x2D, 0x89, 0x68, 0x83, 0x96, 0xC0,
0x16, 0x1A, 0xF2, 0xCA, 0xDC, 0xDF, 0xD3, 0x0D, 0x94, 0xD3, 0x95, 0x27, 0xB0, 0x8F, 0x6B, 0x19, 0x46, 0x2C,
0x3D, 0x84, 0x12, 0x77, 0x32, 0xCB, 0x87, 0x16, 0x28, 0x33, 0x48, 0xA5, 0x8B, 0x24, 0x93, 0x25, 0x74, 0xB2,
0xCA, 0x78, 0xE5, 0x66, 0x57, 0x50, 0x11, 0x90, 0xF5, 0x2B, 0xFA, 0xDF, 0xAC, 0xCE, 0xA5, 0xD5, 0x5D, 0xD7,
0x10, 0x20, 0x61, 0x5C, 0xB3, 0x0E, 0xCA, 0x52, 0xF3, 0x1F, 0x11, 0x9A, 0x79, 0xA0, 0x0C, 0xB2, 0x05, 0x53,
0x11, 0x02, 0x6B, 0x40, 0xDC, 0x9A, 0xD0, 0x43, 0xDF, 0xB1, 0x20, 0xC0, 0xBB, 0x30, 0x0E, 0x22, 0xFC, 0xFC,
0x58, 0xDE, 0x23, 0xA8, 0x7F, 0x1F, 0xFA, 0x5F, 0xB1, 0x1B, 0x54, 0xDB, 0x81, 0xAD, 0x56, 0xC0, 0xE4, 0xFD,
0x6C, 0x93, 0x38, 0xC9, 0x6A, 0xEC, 0x6E, 0xBB, 0x68, 0xEC, 0x09, 0x11, 0x1A, 0x9F, 0x68, 0xB1, 0x83, 0x78,
0x80, 0xFB, 0x4C, 0x85, 0xA5, 0xB5, 0x71, 0x29, 0x62, 0x88, 0xB7, 0x2F, 0x98, 0xA6, 0xE6, 0x1D, 0xB1, 0xF0,
0x97, 0xBA, 0xB7, 0xEB, 0xDA, 0x8E, 0xB6, 0x53, 0x53, 0x62, 0x23, 0xD0, 0x98, 0x90, 0xCA, 0x5A, 0x49, 0xE7,
0xD6, 0x73, 0x0C, 0x1D, 0xF4, 0xAF, 0xC0, 0xE1, 0x27, 0xAF, 0x82, 0xB3, 0x97, 0xBF, 0x1C, 0xAC, 0x53, 0xD2,
0x34, 0xCC, 0x88, 0x5A, 0x55, 0x8D, 0x1B, 0xE9, 0x7C, 0x7C, 0xD6, 0x7F, 0x95, 0x75, 0x77, 0x4E, 0xA6, 0xC4,
0x93, 0x6A, 0x63, 0xF2, 0x13, 0x9F, 0xBB, 0x31, 0x31, 0x02, 0xB4, 0xE0, 0xD4, 0x79, 0x14, 0x4B, 0x7F, 0xE4,
0x96, 0xDB, 0xE8, 0xA7, 0x58, 0x82, 0x22, 0x7C, 0xFD, 0xF0, 0x25, 0xD8, 0x24, 0x88, 0x7E, 0x27, 0xCC, 0x5D,
0xE7, 0xF8, 0x0F, 0xC7, 0x3E, 0xA5, 0x64, 0x93, 0x60, 0x11, 0x90, 0xCC, 0xE1, 0xC7, 0x50, 0xC6, 0x41, 0x0C,
0x91, 0xBA, 0xC6, 0xD6, 0xF5, 0xE1, 0x6D, 0x8A, 0x3B, 0x47, 0x60, 0x7D, 0x7C, 0x45, 0xAC, 0x9D, 0xE0, 0x61,
0x48, 0xFA, 0xFE, 0x92, 0x4C, 0x26, 0x58, 0x20, 0x04, 0xAD, 0x3E, 0x1E, 0xB4, 0x84, 0x9A, 0xDB, 0x78, 0x34,
0x4E, 0x1D, 0x63, 0x69, 0x21, 0x87, 0x2F, 0x5F, 0x29, 0x6B, 0xB6, 0x33, 0x20, 0x58, 0x71, 0x92, 0x25, 0x98,
0xFD, 0x41, 0xF4, 0x11, 0xC9, 0x6D, 0x6B, 0x40, 0xCC, 0xC4, 0x28, 0xF5, 0x40, 0xF7, 0x24, 0x29, 0xA3, 0x3F,
0x23, 0x36, 0x8F, 0xE2, 0xBD, 0x21, 0xDB, 0x1E, 0xB3, 0x80, 0xB7, 0x99, 0xAC, 0xBD, 0x6E, 0x9C, 0x4B, 0x3D,
0x64, 0x67, 0x9B, 0x3F, 0xA4, 0xB7, 0xEB, 0x9F, 0xF6, 0x96, 0x2B, 0x17, 0x39, 0x0B, 0x02, 0x21, 0x12, 0x53,
0x28, 0xFB, 0xF8, 0x8C, 0x11, 0x8C, 0x5A, 0xF8, 0x5B, 0xA1, 0xFF, 0x00, 0x3E, 0xF9, 0x1B, 0xD3, 0xDA, 0x8E,
0x51, 0x33, 0x1F, 0xAD, 0x5E, 0x6E, 0xEF, 0x93, 0x21, 0x4C, 0xB8, 0x14, 0xAD, 0x59, 0x7F, 0xB8, 0xE3, 0xBD,
0xC3, 0xFE, 0x82, 0x9B, 0x19, 0xE1, 0xC3, 0xD2, 0x61, 0xB2, 0x60, 0x22, 0x2D, 0x44, 0x44, 0x19, 0xC8, 0x29,
0x8E, 0x4F, 0xB4, 0x5A, 0x7A, 0x2D, 0x39, 0xA2, 0xB0, 0xF4, 0x12, 0x30, 0x86, 0x3A, 0x91, 0x29, 0x00, 0x71,
0xEE, 0xA6, 0x41, 0xFE, 0x07, 0xE9, 0xED, 0xFE, 0x42, 0x3F, 0xF3, 0x64, 0x0E, 0x6D, 0x0E, 0x9C, 0x70, 0xE9,
0xC7, 0x34, 0xD7, 0x88, 0x1D, 0xB8, 0xA9, 0xBB, 0x3B, 0x3B, 0xB8, 0x9B, 0x7F, 0x71, 0x60, 0x2B, 0xAA, 0x74,
0x96, 0x77, 0x11, 0x5E, 0x4B, 0x28, 0x5E, 0x2A, 0xB7, 0xAD, 0xE3, 0x6D, 0x47, 0x8E, 0xBE, 0x42, 0xAB, 0xB0,
0x7C, 0x76, 0x40, 0xD6, 0xBD, 0x13, 0xA2, 0x33, 0xC7, 0x2D, 0x74, 0x74, 0x52, 0xCA, 0x3A, 0xEC, 0x9A, 0x76,
0xC2, 0xFD, 0x4B, 0x6B, 0xD7, 0x76, 0x6A, 0xF2, 0xCF, 0x66, 0x0F, 0x33, 0x8F, 0xC9, 0x10, 0x28, 0xA0, 0x4D,
0xC9, 0xAB, 0x65, 0x6C, 0xB3, 0x5A, 0x26, 0x64, 0x46, 0x46, 0xD5, 0x78, 0x6D, 0x63, 0x12, 0x98, 0x13, 0x06,
0x90, 0x94, 0xF8, 0xCC, 0xF3, 0xA4, 0xF5, 0x27, 0x4D, 0xAB, 0xD4, 0x3E, 0x9F, 0xEE, 0x7A, 0x35, 0xC8, 0x47,
0xAB, 0x6B, 0xD6, 0xB3, 0x18, 0x40, 0x65, 0x81, 0x93, 0x55, 0x5B, 0x57, 0xE8, 0xB9, 0x34, 0xAF, 0x4C, 0x08,
0x91, 0x41, 0xD0, 0xBA, 0x55, 0xEE, 0xA8, 0xC0, 0x48, 0xD6, 0xDA, 0xE0, 0xC0, 0x89, 0x31, 0x1E, 0x25, 0x26,
0x2E, 0xEE, 0x4B, 0x47, 0x6A, 0x9A, 0x19, 0x05, 0x47, 0xAB, 0x97, 0xD3, 0x19, 0xDA, 0xF6, 0x8C, 0x6C, 0x14,
0xBC, 0x17, 0xF0, 0xF7, 0xD2, 0x46, 0x89, 0xD5, 0x81, 0x42, 0x52, 0x7A, 0xE6, 0x37, 0x56, 0x05, 0x5B, 0x82,
0xAC, 0x0A, 0x92, 0x3A, 0xB5, 0xB9, 0xCC, 0x65, 0x0D, 0xBB, 0x57, 0xCA, 0xE2, 0x1B, 0x22, 0xFC, 0x76, 0xC9,
0x83, 0xB9, 0x46, 0x4F, 0xB9, 0x08, 0x9D, 0x5C, 0xAD, 0x26, 0x28, 0x5A, 0x24, 0x3D, 0x8C, 0x27, 0xC1, 0xC2,
0xC0, 0x31, 0xEC, 0xC0, 0x28, 0x12, 0x19, 0x82, 0x88, 0xED, 0xAB, 0xDE, 0xAD, 0x9D, 0xCB, 0x74, 0xEF, 0x7B,
0xC0, 0x6C, 0x55, 0xC4, 0xEA, 0xE6, 0xB4, 0xAD, 0xA7, 0x1B, 0x95, 0x15, 0x48, 0xAC, 0x8D, 0x57, 0xF0, 0x19,
0x45, 0x59, 0x34, 0x18, 0x1F, 0x92, 0x99, 0x1E, 0xEA, 0xA4, 0x96, 0xAD, 0x90, 0x4A, 0x60, 0xC9, 0x03, 0x20,
0x80, 0x8A, 0x25, 0xC1, 0x36, 0x47, 0x76, 0x30, 0xD3, 0x6C, 0x09, 0xD7, 0x77, 0x2E, 0x1F, 0xC1, 0xF0, 0xFA,
0x3A, 0xC6, 0xA4, 0xB9, 0x64, 0x0E, 0xE7, 0x5C, 0x65, 0x3C, 0x55, 0xBC, 0xB4, 0xF3, 0x88, 0xD9, 0x94, 0x96,
0x15, 0x21, 0x69, 0x02, 0x31, 0x52, 0x4F, 0x00, 0x91, 0xF5, 0x11, 0x14, 0x70, 0x79, 0x13, 0xCF, 0x0E, 0xB7,
0xE9, 0x88, 0xCB, 0x16, 0x5E, 0x30, 0x7F, 0x4F, 0x25, 0xF6, 0x8C, 0x8C, 0xDC, 0x8A, 0x1E, 0x99, 0x28, 0x89,
0x8E, 0xD1, 0x66, 0x7C, 0x24, 0xA2, 0x27, 0xFF, 0x00, 0x31, 0x13, 0xCD, 0xA5, 0xD9, 0xB5, 0x61, 0x57, 0xA9,
0x1E, 0xEF, 0xF5, 0x32, 0x5A, 0xE8, 0x6B, 0x85, 0xB5, 0x7D, 0x60, 0x87, 0xDC, 0xB0, 0xA3, 0x8C, 0x9C, 0xBF,
0xD4, 0x88, 0x14, 0x8C, 0xF7, 0x9A, 0x31, 0xED, 0x80, 0x99, 0x8F, 0xF8, 0x89, 0x98, 0xFF, 0x00, 0x3C, 0x51,
0xCB, 0x17, 0x32, 0xDB, 0xAF, 0xBA, 0x56, 0x72, 0x59, 0x19, 0x5E, 0x7C, 0xCE, 0xE2, 0x6B, 0x9B, 0x39, 0x1C,
0x84, 0xF2, 0xB3, 0x48, 0xED, 0x7B, 0x53, 0xE7, 0x24, 0xB7, 0x76, 0x69, 0x18, 0x02, 0xCC, 0x16, 0x4B, 0x92,
0xC8, 0xE5, 0x54, 0x9E, 0xD5, 0x3D, 0xAB, 0xF4, 0x1D, 0x59, 0xFC, 0xC5, 0xAA, 0x5D, 0x38, 0xE9, 0xBD, 0xFB,
0x35, 0xC2, 0x02, 0x9E, 0x99, 0xA8, 0x36, 0x29, 0xA9, 0x62, 0x31, 0xE5, 0x18, 0x6C, 0x57, 0xAA, 0x9A, 0x16,
0x25, 0x30, 0x3E, 0x4E, 0x62, 0x12, 0xA0, 0x83, 0x98, 0x1F, 0x23, 0x8F, 0x39, 0x88, 0xEF, 0x3C, 0xD6, 0x43,
0x5B, 0xA1, 0x93, 0xEB, 0x5F, 0x5A, 0xF1, 0x14, 0x6E, 0x30, 0x99, 0x93, 0xEA, 0x6F, 0x51, 0x91, 0x39, 0x1B,
0x0D, 0x23, 0x29, 0x03, 0xD9, 0xF6, 0x08, 0x7E, 0x4E, 0xD3, 0x8C, 0x20, 0x8F, 0xC2, 0xBA, 0xAD, 0x58, 0xB0,
0xD2, 0x01, 0x92, 0x85, 0xA8, 0xA4, 0x06, 0x66, 0x20, 0x78, 0xE0, 0x3E, 0x16, 0x74, 0x84, 0x3A, 0x63, 0x6C,
0xF0, 0x95, 0xD2, 0x04, 0x80, 0x1A, 0x15, 0x87, 0x62, 0x20, 0x45, 0x50, 0xA9, 0x2C, 0x6A, 0xAA, 0xAB, 0xDA,
0x15, 0x55, 0x40, 0x0A, 0xA0, 0x00, 0x00, 0xE0, 0x01, 0xC7, 0xB4, 0x4C, 0x63, 0x18, 0xE6, 0x1B, 0x5A, 0x66,
0xD6, 0xB4, 0xC9, 0x8C, 0x63, 0x08, 0x8D, 0x8C, 0x61, 0x94, 0x91, 0x99, 0x99, 0x4C, 0x91, 0x99, 0x94, 0xC9,
0x11, 0x14, 0xC9, 0x11, 0x4C, 0xCC, 0xCC, 0xCC, 0xF3, 0x68, 0xE4, 0xA5, 0x35, 0xD2, 0xAA, 0xF5, 0xD4, 0xB4,
0x57, 0x42, 0xC1, 0x28, 0x42, 0x56, 0x2A, 0x4A, 0x52, 0xA1, 0x80, 0x52, 0x94, 0xA0, 0x81, 0x05, 0xAD, 0x60,
0x22, 0x00, 0xB0, 0x18, 0x10, 0x18, 0x81, 0x18, 0x88, 0x88, 0x8E, 0x42, 0x3F, 0x9C, 0x76, 0xD8, 0x0D, 0x3B,
0xBC, 0x7A, 0x13, 0x72, 0xE9, 0xD4, 0x8E, 0x2A, 0x7A, 0xE7, 0x4B, 0xDA, 0xC2, 0x64, 0xA6, 0x8B, 0xEB, 0x2E,
0x6F, 0x4A, 0xDF, 0x79, 0x12, 0x7B, 0x23, 0x8F, 0x69, 0xAC, 0x62, 0x33, 0x34, 0x6A, 0xC2, 0xC0, 0xFC, 0xF0,
0xE2, 0x8A, 0xF6, 0xA9, 0x88, 0x97, 0xA3, 0x3F, 0x0B, 0xB6, 0x8F, 0xAC, 0xD5, 0xB6, 0x8D, 0x49, 0xEE, 0x22,
0x6E, 0x0F, 0x2C, 0x8C, 0xB5, 0x35, 0x9F, 0xFD, 0x94, 0x73, 0x28, 0x95, 0x35, 0x69, 0x9F, 0xFF, 0x00, 0x0A,
0xBB, 0x8F, 0x6B, 0x98, 0x3D, 0xBF, 0x16, 0x5E, 0xF2, 0xEF, 0x3E, 0x7D, 0x86, 0x2C, 0xFE, 0xA7, 0x3A, 0x1F,
0xED, 0x9B, 0xFE, 0x87, 0xD4, 0x3A, 0xB5, 0x81, 0x75, 0xF6, 0xAD, 0x7A, 0xD6, 0xBF, 0x92, 0x6A, 0xFF, 0x00,
0xCB, 0x32, 0xDA, 0xCD, 0xA8, 0x7A, 0x1D, 0x66, 0x3F, 0xE1, 0xB6, 0x31, 0x79, 0x8A, 0xD5, 0x92, 0x51, 0x3F,
0x9A, 0x71, 0x52, 0x3E, 0x23, 0x2A, 0xEE, 0x75, 0xF9, 0x4D, 0xEE, 0x5F, 0xE1, 0x1A, 0xA7, 0x53, 0x68, 0x7B,
0x36, 0x15, 0x23, 0x7B, 0x30, 0x67, 0x29, 0xC4, 0x49, 0x0E, 0xEB, 0x72, 0xB1, 0xA3, 0x73, 0xB4, 0xF3, 0xC1,
0x48, 0x64, 0xA9, 0x51, 0x88, 0x3C, 0x15, 0x7B, 0x25, 0x87, 0x77, 0x71, 0xEC, 0xE8, 0x3F, 0x35, 0x35, 0x8F,
0xA6, 0xCF, 0xEA, 0x3B, 0x7A, 0x54, 0x5E, 0xBC, 0xA6, 0x36, 0xD6, 0x0E, 0xEB, 0x22, 0x7F, 0x01, 0xB3, 0x8A,
0x7F, 0xD5, 0xD3, 0x93, 0x8F, 0xF8, 0x63, 0xEB, 0xE4, 0x2C, 0x08, 0xCC, 0x77, 0x82, 0x0A, 0x5D, 0xA6, 0x06,
0x43, 0xB9, 0x7A, 0xEF, 0xE9, 0x83, 0xBD, 0x45, 0xDD, 0x47, 0xA8, 0xBD, 0x39, 0xB2, 0xF0, 0xF6, 0xE0, 0x73,
0x74, 0x36, 0xBC, 0x5A, 0x4A, 0x3F, 0xB4, 0xE9, 0x67, 0xEA, 0xCE, 0x3B, 0x25, 0x0B, 0x9F, 0xF1, 0x28, 0xA9,
0x73, 0x0D, 0x49, 0x86, 0x33, 0x11, 0x20, 0xDC, 0xA7, 0x78, 0x92, 0x86, 0x76, 0x0D, 0xD1, 0xE7, 0x47, 0xBA,
0x24, 0xE3, 0x36, 0x7B, 0x68, 0xE9, 0xDA, 0x05, 0x2F, 0x5D, 0xCB, 0x6E, 0x16, 0x6E, 0xAA, 0xA2, 0x86, 0x0B,
0x8C, 0x8A, 0x5D, 0x3D, 0xA6, 0xE4, 0x69, 0x78, 0xEF, 0x31, 0xCC, 0xF9, 0x4D, 0x4D, 0xCC, 0x2A, 0xDD, 0x8D,
0x25, 0x48, 0xA5, 0x95, 0x4B, 0xC5, 0x01, 0x4E, 0x67, 0xC2, 0x9D, 0x62, 0x1B, 0x91, 0xDC, 0xF7, 0x17, 0x2B,
0xFF, 0x00, 0xA9, 0x52, 0x96, 0xB9, 0x41, 0xB2, 0x53, 0x31, 0x27, 0x75, 0xB1, 0x91, 0xC9, 0x8C, 0x07, 0xFA,
0xC1, 0xAC, 0x29, 0x62, 0xFB, 0x32, 0x63, 0xCA, 0x01, 0xE6, 0x01, 0x30, 0x26, 0xC8, 0x9F, 0x99, 0xFA, 0xA1,
0x6F, 0x52, 0x9C, 0x37, 0x4C, 0xFA, 0x6B, 0x5A, 0xC7, 0xFF, 0x00, 0xD0, 0xC8, 0xE4, 0xF7, 0x5C, 0xBD, 0x78,
0x08, 0x82, 0x85, 0xE3, 0x2B, 0xCE, 0x13, 0x02, 0x64, 0xDE, 0xDE, 0x72, 0xB7, 0x33, 0x27, 0xB0, 0x77, 0x48,
0x97, 0x81, 0x32, 0xAA, 0xD8, 0xC1, 0x93, 0x5A, 0x24, 0x79, 0x33, 0xCB, 0x23, 0x6D, 0x5F, 0x52, 0xEE, 0x46,
0x4F, 0x54, 0x4F, 0x5D, 0x9E, 0x0A, 0x5E, 0x8E, 0x2A, 0xB4, 0x84, 0x02, 0x9D, 0xE9, 0xE9, 0xE4, 0x2F, 0x2F,
0xB8, 0xE4, 0x91, 0xFF, 0x00, 0x0F, 0x20, 0x82, 0x00, 0xF9, 0x87, 0x0C, 0x7F, 0xE4, 0xFD, 0xBE, 0x6B, 0x6D,
0x10, 0x76, 0xB4, 0xDD, 0x31, 0x2D, 0x09, 0x84, 0x2A, 0xE6, 0xCB, 0x90, 0x54, 0x77, 0x92, 0x83, 0x79, 0x16,
0x37, 0x14, 0x53, 0x30, 0x5E, 0x23, 0xD8, 0x15, 0x96, 0x99, 0x19, 0x19, 0x29, 0x86, 0x01, 0x44, 0x88, 0xCF,
0xE7, 0xC6, 0xFD, 0x2F, 0xB4, 0x29, 0x5D, 0x1E, 0xA5, 0xF5, 0x36, 0xCA, 0x19, 0x13, 0x66, 0xC6, 0x3B, 0x48,
0xC3, 0xD8, 0x9F, 0x18, 0x02, 0x5D, 0x60, 0x0C, 0xE6, 0xC0, 0x11, 0x12, 0x3E, 0x67, 0xE4, 0xC7, 0xEB, 0xBE,
0x26, 0x27, 0x0B, 0x82, 0x53, 0x42, 0x60, 0xCE, 0x3F, 0xAD, 0xA4, 0xE8, 0xD7, 0x4A, 0xB5, 0x20, 0x81, 0x14,
0x28, 0x8D, 0x02, 0xF0, 0x3F, 0x71, 0x3D, 0x60, 0x7F, 0x2B, 0x4F, 0x3D, 0x7D, 0x38, 0xE1, 0xD3, 0x8E, 0x59,
0xB1, 0x18, 0x96, 0x09, 0x63, 0x61, 0xC8, 0x78, 0xDD, 0x48, 0xFF, 0x00, 0xD9, 0x48, 0xFF, 0x00, 0x3E, 0x9C,
0x71, 0x3B, 0x3C, 0x7D, 0x6D, 0xA1, 0xDA, 0xEF, 0x15, 0x9B, 0xAF, 0x8A, 0x86, 0x17, 0x8B, 0x19, 0xA8, 0xF3,
0x47, 0x5D, 0x62, 0x19, 0xA0, 0x30, 0x47, 0x2D, 0x6D, 0x5C, 0x1B, 0x29, 0x7F, 0xE1, 0xD4, 0x72, 0x8D, 0x5E,
0xAE, 0x79, 0xF3, 0x18, 0xF8, 0xDE, 0x22, 0x50, 0xFC, 0x19, 0x04, 0x46, 0xEA, 0xF1, 0x47, 0x60, 0x3E, 0x39,
0xED, 0x1F, 0xCA, 0xBA, 0x43, 0xA9, 0xBD, 0x87, 0x07, 0x6F, 0x0D, 0x59, 0x9A, 0xDD, 0xC8, 0x86, 0x7B, 0x08,
0x0F, 0x08, 0x7F, 0x49, 0x53, 0xD9, 0x3F, 0xED, 0x0C, 0x6E, 0x2E, 0x31, 0xF6, 0x08, 0x4E, 0x20, 0xA2, 0x5F,
0xF6, 0xF2, 0x19, 0x13, 0x2D, 0x6F, 0xFE, 0x69, 0x68, 0x7F, 0xC0, 0x7E, 0x46, 0xF5, 0x0A, 0xA2, 0x54, 0x4B,
0xC7, 0xEC, 0xB7, 0x95, 0xBB, 0xE3, 0x08, 0x93, 0x29, 0x06, 0xAB, 0x69, 0x5F, 0xEE, 0x39, 0x1F, 0x48, 0xFF,
0x00, 0xA1, 0x26, 0xBE, 0x78, 0xB3, 0x14, 0x96, 0x6B, 0x99, 0x09, 0x8A, 0xB3, 0x13, 0x00, 0x70, 0x6A, 0x5F,
0x4C, 0xE9, 0x0F, 0x11, 0x93, 0xE0, 0xFC, 0xBC, 0xB5, 0xD6, 0x9D, 0x8B, 0x23, 0x66, 0x3C, 0xED, 0xF1, 0x5B,
0x6A, 0xAB, 0x76, 0xB8, 0x0D, 0xF0, 0xF9, 0x5B, 0x2F, 0x5E, 0xF5, 0x6E, 0xFE, 0xF0, 0xCB, 0x5D, 0xF4, 0x43,
0xDC, 0x88, 0x90, 0xA5, 0xBB, 0x88, 0x84, 0x28, 0x43, 0xEA, 0xAE, 0x36, 0x7F, 0xE9, 0xA4, 0x47, 0xCC, 0x0F,
0x44, 0xD6, 0x4C, 0xE2, 0xA6, 0xCC, 0xF5, 0x22, 0x06, 0x62, 0x62, 0x24, 0x3E, 0x92, 0x6C, 0xC3, 0xA1, 0x7E,
0x3E, 0x32, 0xC8, 0xDB, 0xBE, 0xDD, 0xBC, 0xBC, 0x24, 0x63, 0xDB, 0x33, 0xE5, 0xDD, 0x3C, 0xCD, 0xB9, 0xEB,
0x8C, 0xCF, 0xE9, 0xBD, 0x36, 0x46, 0xF5, 0x98, 0xD8, 0x22, 0x98, 0xF4, 0x4E, 0x4F, 0xC8, 0x64, 0xA1, 0x91,
0x90, 0x8A, 0x53, 0x56, 0x5B, 0xE7, 0xE7, 0x0A, 0x2E, 0x9C, 0xFE, 0x5D, 0xFC, 0x3D, 0x90, 0x45, 0x09, 0x81,
0xF0, 0xED, 0x63, 0x9C, 0x93, 0xE0, 0xD3, 0x45, 0xB6, 0xB3, 0xDF, 0x4D, 0x37, 0x19, 0x89, 0x65, 0x87, 0x0A,
0x93, 0x65, 0xA4, 0x0E, 0x9D, 0xEA, 0x64, 0xEF, 0x8A, 0x94, 0x00, 0x0E, 0x18, 0x07, 0x56, 0xB8, 0xD3, 0xA3,
0x1E, 0x3B, 0x4C, 0x1D, 0xCA, 0x43, 0x85, 0x3D, 0x7B, 0x0F, 0xCB, 0x9D, 0x92, 0x70, 0xBD, 0x29, 0x66, 0x29,
0x46, 0xC0, 0xB1, 0xB4, 0xE6, 0xB1, 0xD8, 0xAF, 0xEB, 0x3F, 0x02, 0x8A, 0x95, 0x64, 0xF2, 0xF6, 0xC8, 0xA6,
0x26, 0x0A, 0x54, 0x53, 0x41, 0x15, 0x9A, 0x11, 0xDE, 0x0C, 0x6C, 0xF8, 0x9C, 0x4A, 0xE4, 0xE2, 0x71, 0xBB,
0xF4, 0xEA, 0xD2, 0x47, 0x67, 0xF9, 0x04, 0x9C, 0xFB, 0xD4, 0xA6, 0x54, 0xD0, 0xB5, 0x8C, 0xCE, 0xC1, 0xFD,
0xCB, 0x86, 0x84, 0xE4, 0x6F, 0x8A, 0xB5, 0xDC, 0x78, 0x04, 0x48, 0x90, 0x8D, 0x85, 0xC6, 0x5E, 0xD5, 0xE4,
0x30, 0xBB, 0x4A, 0xCA, 0x8C, 0xB1, 0x73, 0x0D, 0x15, 0xCC, 0x38, 0x66, 0x8B, 0xC5, 0x26, 0x1F, 0x4E, 0xE3,
0x68, 0xA2, 0x84, 0x11, 0x57, 0x45, 0xE0, 0x0E, 0x3D, 0xC1, 0x6F, 0xB7, 0xF1, 0xEA, 0x58, 0xF2, 0xFB, 0x72,
0x39, 0xFC, 0xD9, 0x36, 0xC9, 0x75, 0xB7, 0x85, 0xFC, 0x9E, 0xA5, 0xAF, 0x02, 0x3E, 0x4B, 0x6E, 0x35, 0x06,
0x0F, 0x56, 0x40, 0xE2, 0x0F, 0x52, 0xC3, 0x51, 0x69, 0xAC, 0x60, 0x72, 0xF0, 0x24, 0xC3, 0xE7, 0x86, 0x05,
0xA3, 0x9A, 0x7C, 0x95, 0x91, 0xF3, 0x45, 0x27, 0xE1, 0x91, 0x19, 0x17, 0xBA, 0x38, 0xA4, 0x8B, 0x24, 0xBE,
0x29, 0xEC, 0xF3, 0xAF, 0xF5, 0x73, 0x19, 0x45, 0x86, 0x43, 0x53, 0x68, 0xC7, 0xE4, 0x30, 0x0E, 0x8F, 0x67,
0x8A, 0xE1, 0xE4, 0xB1, 0xC9, 0x51, 0x61, 0x04, 0xFE, 0x26, 0xC9, 0xB7, 0x8F, 0x5D, 0x55, 0x4C, 0x76, 0x31,
0xFA, 0xB3, 0x81, 0x2F, 0x12, 0x30, 0x3C, 0x24, 0xFD, 0x40, 0xB4, 0x51, 0xDC, 0x3E, 0x3A, 0xE7, 0x32, 0xAA,
0x50, 0x1E, 0x43, 0x42, 0xCC, 0xE1, 0xF6, 0xDA, 0xB3, 0x09, 0xF3, 0x79, 0x55, 0x17, 0x9E, 0x0F, 0x2A, 0x90,
0x68, 0xFE, 0x6A, 0x48, 0xE3, 0xF3, 0x2E, 0xC8, 0x58, 0x89, 0xF2, 0x53, 0x3F, 0x6E, 0x54, 0xB0, 0x7C, 0x96,
0xA6, 0x2A, 0x00, 0x3C, 0x1E, 0xEB, 0xD9, 0x36, 0xFF, 0x00, 0x7E, 0xB4, 0x75, 0xFF, 0x00, 0x88, 0xF8, 0x7A,
0x99, 0x89, 0xA5, 0xC0, 0x5D, 0x6E, 0x01, 0x0C, 0xB7, 0xBB, 0x25, 0xA6, 0xBE, 0xE0, 0x95, 0x2F, 0x92, 0xAD,
0x4A, 0x30, 0xEA, 0x54, 0xAA, 0xBB, 0x02, 0xDD, 0x8C, 0xE0, 0xE6, 0x9F, 0xCA, 0x5D, 0x5E, 0x36, 0x3E, 0x91,
0x66, 0x6C, 0xAD, 0x3E, 0xDB, 0x9A, 0xC5, 0xBA, 0x5B, 0x1D, 0x5E, 0xD3, 0x22, 0x42, 0xBA, 0xCC, 0x2A, 0x79,
0x12, 0xEF, 0x13, 0x10, 0x40, 0x18, 0xBB, 0xD7, 0x1E, 0x40, 0x7D, 0xC0, 0xA5, 0x20, 0x5D, 0xBD, 0x80, 0xB2,
0x19, 0x83, 0xF0, 0x23, 0x7C, 0x9D, 0x2B, 0xE4, 0x6E, 0xB3, 0x49, 0xD6, 0x3E, 0x9F, 0x1B, 0xBD, 0x63, 0xF2,
0x9A, 0x5D, 0xEF, 0x21, 0x12, 0x03, 0x75, 0xE4, 0x86, 0x4B, 0x0A, 0x1D, 0x88, 0x66, 0x45, 0x8D, 0xCF, 0xE2,
0xF1, 0x95, 0x41, 0x8B, 0x91, 0x60, 0xC5, 0x93, 0x09, 0x2F, 0x4B, 0x1C, 0x07, 0xF6, 0xFE, 0x60, 0x5B, 0xA8,
0xDB, 0xAD, 0xE2, 0x67, 0x57, 0x5D, 0x8A, 0xCC, 0xD6, 0x31, 0x9A, 0x42, 0x86, 0x23, 0x43, 0x62, 0xBD, 0x52,
0x38, 0x85, 0x30, 0xB0, 0x3D, 0xAC, 0xB4, 0x71, 0x28, 0x77, 0x55, 0x8B, 0xF4, 0x93, 0x25, 0x9B, 0x64, 0x3C,
0x83, 0x22, 0xB0, 0x91, 0x95, 0x0B, 0x76, 0x2F, 0x27, 0xE3, 0x0E, 0xB5, 0xFC, 0x73, 0xA3, 0xFA, 0xF9, 0xB1,
0x6B, 0x5D, 0xAD, 0x85, 0xB7, 0x36, 0x4B, 0x32, 0x1D, 0xE6, 0x58, 0x39, 0x06, 0xC2, 0xA8, 0x19, 0x94, 0xC4,
0x4C, 0x94, 0xE2, 0x6A, 0xD0, 0xEF, 0x1D, 0xBB, 0x0C, 0xF7, 0x11, 0x92, 0x88, 0xF2, 0x2E, 0x1F, 0xCE, 0xDD,
0xE3, 0xF9, 0xAF, 0xC9, 0x0D, 0xC5, 0x49, 0x7B, 0x5D, 0x8F, 0xD3, 0x51, 0x8D, 0xD2, 0x68, 0xC3, 0x66, 0x22,
0x12, 0x78, 0x74, 0x13, 0xF3, 0x0A, 0x58, 0x89, 0x14, 0x08, 0x0E, 0xC3, 0x7F, 0x2F, 0x03, 0x3D, 0xFC, 0x8E,
0x3B, 0x19, 0x88, 0x49, 0x78, 0x0C, 0xBF, 0xF9, 0x5C, 0xED, 0x6F, 0xE8, 0xEE, 0xDC, 0x63, 0x33, 0x36, 0x2B,
0xA0, 0xB5, 0x94, 0x88, 0x65, 0xE5, 0x90, 0x06, 0x25, 0x9B, 0x2D, 0x13, 0xD9, 0x8C, 0x31, 0x60, 0x0F, 0x7C,
0x35, 0x9A, 0xBD, 0x67, 0x08, 0x3B, 0x7B, 0xA0, 0x3D, 0xAC, 0xE3, 0xE7, 0x33, 0xCB, 0xAF, 0x7B, 0x54, 0xED,
0xFD, 0x58, 0xDC, 0x32, 0x20, 0xC3, 0x3A, 0x74, 0x72, 0x25, 0x81, 0xC7, 0xC1, 0xC0, 0xC4, 0x0D, 0x4C, 0x1C,
0x46, 0x36, 0x4D, 0x5E, 0x3D, 0xE7, 0xD3, 0x6A, 0xD2, 0x2D, 0x5E, 0x5C, 0x9C, 0xFB, 0x24, 0x6D, 0x7E, 0x70,
0x13, 0xFD, 0x61, 0x64, 0xFE, 0x22, 0xE8, 0x11, 0xD3, 0x9F, 0x8F, 0x5D, 0x37, 0xC3, 0x35, 0x4A, 0x5E, 0x4B,
0x2B, 0x85, 0x0D, 0xB7, 0x30, 0x4B, 0x96, 0x49, 0x1D, 0xFD, 0xAC, 0xA7, 0x36, 0x2B, 0x7F, 0xB2, 0x23, 0xB5,
0x9A, 0x18, 0xFB, 0x74, 0x71, 0x4E, 0x85, 0xC4, 0x2A, 0x0E, 0x87, 0xF5, 0x93, 0x47, 0xFB, 0x99, 0x31, 0x7D,
0x78, 0xF7, 0x32, 0x4B, 0x87, 0x4E, 0x38, 0x74, 0xE3, 0x87, 0x4E, 0x38, 0xBF, 0x9E, 0x74, 0x3B, 0x5D, 0xE9,
0x5D, 0xDA, 0x9D, 0xDF, 0xA5, 0x56, 0x4E, 0xD7, 0x19, 0x3D, 0x01, 0x9D, 0xB4, 0x0A, 0x98, 0x87, 0xA8, 0xD6,
0x35, 0x0E, 0x9A, 0x88, 0xA8, 0xE2, 0x45, 0x62, 0xD1, 0xEA, 0x96, 0x67, 0x25, 0xE3, 0x6E, 0xE8, 0xD3, 0xF5,
0x4E, 0x14, 0x4D, 0x9E, 0x5F, 0x0A, 0x76, 0x9F, 0x17, 0xEE, 0x5A, 0x5B, 0x9A, 0x31, 0x0D, 0x5D, 0x3D, 0x9B,
0x1C, 0x99, 0xEF, 0x05, 0x26, 0xA2, 0x1C, 0x66, 0x5C, 0xE2, 0x7E, 0xE2, 0x5D, 0xC5, 0x98, 0x68, 0x81, 0x8F,
0x12, 0x18, 0x03, 0x2E, 0xC6, 0x33, 0x32, 0xB9, 0x29, 0xFA, 0xA1, 0x68, 0x5E, 0x75, 0x7A, 0x67, 0xD4, 0xEA,
0xD5, 0xCE, 0x65, 0x0E, 0xC9, 0x68, 0xD9, 0x9B, 0x31, 0x23, 0x21, 0x0B, 0x78, 0xB3, 0x3B, 0xAE, 0xAE, 0x47,
0xEC, 0x61, 0x22, 0x6A, 0xD9, 0xA4, 0x8E, 0x7C, 0xD6, 0x52, 0xC5, 0x8F, 0x75, 0x1C, 0x0C, 0x3A, 0x0F, 0x97,
0x50, 0xE4, 0xD7, 0x4D, 0xC9, 0xA5, 0x05, 0x99, 0x46, 0x1A, 0x5C, 0xDC, 0x5A, 0x81, 0xA9, 0xFA, 0x8D, 0xE8,
0x9C, 0x94, 0x34, 0x66, 0xC7, 0x2D, 0x83, 0x17, 0x3D, 0x86, 0x41, 0x56, 0x66, 0x8F, 0xBF, 0x8E, 0xEE, 0xDF,
0x97, 0xE9, 0xC7, 0x59, 0xBB, 0x3A, 0xCE, 0x32, 0x76, 0xB1, 0xDC, 0x7D, 0x0B, 0xFD, 0xE0, 0x75, 0xE3, 0xD6,
0xA6, 0xC7, 0xAC, 0x7D, 0xB3, 0x8D, 0x2C, 0x90, 0x65, 0x05, 0x3E, 0xDF, 0xF6, 0xF5, 0x8D, 0xA8, 0x23, 0xF5,
0xFF, 0x00, 0xAF, 0x91, 0x49, 0x7F, 0x9E, 0xFD, 0xE5, 0x9C, 0x6F, 0x19, 0xD8, 0xE9, 0xF9, 0xF4, 0xDB, 0xEA,
0xDD, 0xFC, 0x68, 0xB7, 0x15, 0xEE, 0xF1, 0x4B, 0xDC, 0x7F, 0x4F, 0x19, 0xC0, 0xC2, 0xB3, 0x04, 0x56, 0xBD,
0x1F, 0xF4, 0xFD, 0xC7, 0x40, 0x81, 0x52, 0xDF, 0xF7, 0xF0, 0x5C, 0x04, 0xFD, 0xA2, 0x39, 0x2C, 0xFE, 0x55,
0x5B, 0x72, 0x32, 0xFA, 0x97, 0x37, 0xAB, 0x26, 0x88, 0x37, 0x7D, 0xE5, 0xC7, 0x42, 0xCD, 0x1F, 0x25, 0x22,
0xC7, 0x56, 0x16, 0x19, 0x95, 0xCF, 0xB0, 0x59, 0x26, 0xB8, 0xEA, 0xCA, 0x38, 0xE4, 0xD7, 0x05, 0xB9, 0xE1,
0x7B, 0x67, 0xF7, 0xCD, 0x0D, 0x92, 0x6E, 0xEE, 0x3A, 0xCE, 0xAE, 0xB3, 0x29, 0x4E, 0x0B, 0x08, 0xDC, 0x93,
0xC6, 0x0F, 0xF0, 0xFA, 0xDC, 0xDD, 0x99, 0x0F, 0x12, 0x08, 0xFF, 0x00, 0x26, 0xAA, 0x78, 0xCA, 0xC6, 0x24,
0x5D, 0xE6, 0x06, 0xD1, 0x40, 0xC0, 0xC4, 0x9C, 0x95, 0x81, 0xFD, 0x31, 0xB4, 0x91, 0xC6, 0x74, 0xDB, 0x7A,
0xDF, 0x1C, 0xB0, 0x8B, 0x3B, 0x5E, 0xD3, 0x5F, 0x07, 0x54, 0x89, 0x7F, 0xD9, 0x18, 0xCD, 0x5A, 0x8C, 0x37,
0xD8, 0xB6, 0xCF, 0xDE, 0x15, 0x63, 0x23, 0x9D, 0xBA, 0xA6, 0x2C, 0x3B, 0x41, 0x1D, 0x00, 0x26, 0x49, 0x48,
0xAE, 0x01, 0x96, 0x21, 0x8C, 0x45, 0x12, 0x46, 0x3D, 0x82, 0x2F, 0x03, 0xFA, 0xFE, 0xBF, 0x87, 0x58, 0x63,
0xCA, 0x6D, 0xCF, 0x80, 0xDD, 0x9D, 0x1D, 0x4B, 0x70, 0x36, 0xE3, 0x5B, 0x68, 0xAC, 0x89, 0x65, 0xA3, 0xAA,
0xB4, 0xBE, 0x7F, 0x4E, 0xDB, 0x74, 0x45, 0x91, 0xE3, 0xAB, 0x9A, 0xC4, 0x5D, 0xC6, 0x4E, 0xE8, 0x8C, 0x42,
0xB3, 0xA4, 0x56, 0x9D, 0x95, 0x58, 0x85, 0x66, 0x00, 0x37, 0xB1, 0xE4, 0x7D, 0x4C, 0x1E, 0x5A, 0xC6, 0x07,
0x37, 0x87, 0xCE, 0xD4, 0x88, 0x2B, 0x58, 0x5C, 0xA6, 0x3F, 0x2D, 0x5A, 0x0A, 0x64, 0x46, 0x6C, 0x63, 0xAD,
0xA6, 0xE2, 0x62, 0x48, 0x7F, 0x21, 0x89, 0x62, 0x46, 0x26, 0x47, 0xEF, 0x11, 0xF7, 0x8F, 0xBF, 0x3E, 0x06,
0xD7, 0xAF, 0x53, 0xDB, 0xB5, 0x7D, 0x93, 0x54, 0xC8, 0x11, 0x0D, 0x0D, 0x9F, 0x01, 0x98, 0xD7, 0xAF, 0x10,
0x08, 0x99, 0x8D, 0x3C, 0xD6, 0x3A, 0xCE, 0x36, 0xC9, 0x08, 0x97, 0xE2, 0x45, 0x09, 0xB2, 0x72, 0x22, 0x5F,
0x8C, 0xCC, 0x44, 0x4F, 0xDA, 0x78, 0x91, 0x17, 0xA9, 0x66, 0xF4, 0x16, 0xB0, 0xB9, 0x8E, 0xB9, 0x14, 0xD8,
0xED, 0x45, 0xA3, 0x35, 0x25, 0x9A, 0x56, 0xE1, 0x75, 0x92, 0xBD, 0x8A, 0x39, 0xAD, 0x3B, 0x94, 0x7A, 0xF6,
0x22, 0x74, 0x91, 0x52, 0x58, 0x66, 0xAD, 0x7A, 0x9B, 0xA3, 0x2B, 0xA2, 0xC9, 0x1B, 0xA1, 0x0C, 0xA1, 0x81,
0x1D, 0x5B, 0xB6, 0x86, 0x2F, 0x74, 0xD5, 0x4C, 0x22, 0x57, 0x6B, 0x0D, 0xB5, 0xE0, 0x26, 0x04, 0xBB, 0x03,
0xD5, 0x63, 0x1B, 0x9C, 0xC7, 0x7E, 0x27, 0x1D, 0x8A, 0x56, 0xD0, 0x65, 0x6B, 0x30, 0x51, 0xD8, 0xBC, 0x4E,
0x26, 0x26, 0x0B, 0xB4, 0xC4, 0xF3, 0x56, 0x64, 0x33, 0x3D, 0xD3, 0x2D, 0xF9, 0x4D, 0x91, 0x7E, 0x3F, 0x66,
0xE9, 0xFE, 0xDE, 0x24, 0x4B, 0x99, 0x6D, 0x5B, 0x14, 0xF3, 0x9A, 0xB6, 0x67, 0xF3, 0x59, 0x77, 0x11, 0x72,
0x1A, 0x8B, 0xD4, 0x64, 0x0A, 0x08, 0x61, 0x8B, 0x21, 0x98, 0x21, 0xF2, 0x89, 0x8E, 0x64, 0xB0, 0x34, 0xB2,
0x1B, 0x8B, 0xB8, 0x58, 0xDA, 0x96, 0xE5, 0x9A, 0xC6, 0x43, 0x58, 0x6A, 0x98, 0x9B, 0x21, 0x65, 0xBB, 0xE7,
0x99, 0xE4, 0xCB, 0x64, 0x7D, 0x7C, 0x8D, 0xA7, 0xE5, 0x83, 0xCA, 0xCA, 0x92, 0xD8, 0x9D, 0xCB, 0x3A, 0x96,
0xED, 0x25, 0x9D, 0x7D, 0xD8, 0x75, 0xFD, 0xAB, 0x27, 0x4F, 0xA6, 0x9D, 0x33, 0xCB, 0xDF, 0xA6, 0xB5, 0xAE,
0xB6, 0xA1, 0xAA, 0x1A, 0x71, 0x68, 0x8F, 0x0A, 0xEA, 0x96, 0xE3, 0xE8, 0x0D, 0x2C, 0x45, 0x51, 0xFB, 0x10,
0x28, 0x5B, 0x64, 0x6A, 0xD7, 0x18, 0x10, 0x67, 0x8F, 0x9C, 0x40, 0x2D, 0x93, 0x10, 0x05, 0xDC, 0x34, 0x0C,
0x1E, 0x4B, 0xAE, 0x1D, 0x71, 0xD7, 0x71, 0x19, 0x27, 0x3D, 0xD7, 0xBA, 0x8D, 0xD4, 0x15, 0x59, 0xCF, 0x5B,
0x98, 0x65, 0xB7, 0x8A, 0x33, 0x19, 0x73, 0xC9, 0xEC, 0x57, 0xCB, 0xB9, 0x03, 0x2C, 0x1D, 0x7A, 0x27, 0x90,
0xB8, 0x72, 0x6C, 0x57, 0xB3, 0xD5, 0x32, 0xC6, 0xAA, 0x24, 0x98, 0x2E, 0x2D, 0xE1, 0x87, 0x47, 0x45, 0xA4,
0xF6, 0xE3, 0x0B, 0x5D, 0x21, 0x58, 0x49, 0xA3, 0x59, 0x7B, 0x15, 0x02, 0x2A, 0x84, 0x59, 0x10, 0x28, 0x03,
0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xC0, 0x1C, 0x7D, 0x22, 0x91, 0x99, 0xB0, 0xCD, 0x8C, 0x32, 0x63,
0x18, 0x44, 0x66, 0x66, 0x52, 0x46, 0x66, 0x53, 0x24, 0x46, 0x64, 0x53, 0x24, 0x44, 0x45, 0x33, 0x24, 0x53,
0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x3C, 0xDA, 0x15, 0x4A, 0x5A, 0x56, 0xB4, 0xA5, 0x60, 0xA4, 0xA8, 0x01,
0x4A, 0x52, 0x80, 0x56, 0xB5, 0x2D, 0x63, 0x02, 0x0B, 0x58, 0x0C, 0x40, 0x80, 0x00, 0xC4, 0x08, 0x00, 0xC4,
0x08, 0x8C, 0x44, 0x44, 0x44, 0x44, 0x47, 0x3A, 0x4F, 0xAF, 0xE7, 0x9F, 0xDF, 0x0E, 0x9C, 0x70, 0xE9, 0xC7,
0x0E, 0x9C, 0x73, 0x92, 0xFC, 0x69, 0x78, 0x7F, 0x7F, 0x12, 0x1B, 0x17, 0xA9, 0x76, 0xF2, 0x95, 0x8A, 0x94,
0x33, 0xB3, 0x4D, 0x8C, 0xCB, 0xE9, 0xCC, 0xA5, 0xE8, 0xE6, 0x92, 0xB6, 0x3F, 0x33, 0x87, 0xB8, 0xB6, 0xE1,
0x92, 0x55, 0xAE, 0xC2, 0x51, 0x15, 0xCA, 0xBF, 0x19, 0x8B, 0x9E, 0x45, 0x49, 0x9A, 0x1A, 0xF9, 0x09, 0x66,
0x48, 0x26, 0x92, 0x24, 0x43, 0xE9, 0x3D, 0x24, 0xDF, 0xCB, 0xA6, 0x7B, 0xDE, 0x1F, 0x6C, 0x2A, 0xEF, 0xB9,
0x4E, 0xAC, 0x5B, 0xAB, 0x93, 0xA3, 0x5C, 0xD6, 0xB7, 0x5C, 0xC7, 0xDD, 0xAC, 0xC4, 0x35, 0x60, 0x4D, 0x89,
0x0F, 0x34, 0xB4, 0x93, 0x71, 0x42, 0x44, 0xB8, 0x36, 0xD6, 0x58, 0x13, 0x16, 0x04, 0x45, 0x1E, 0x23, 0xF2,
0x27, 0xA4, 0x01, 0xD7, 0x3E, 0x93, 0x6C, 0x9D, 0x3D, 0x0B, 0x75, 0x71, 0xB9, 0x3B, 0xE5, 0x8F, 0xBF, 0x82,
0xCA, 0xDD, 0x5B, 0xDD, 0x5B, 0x1B, 0x98, 0xC5, 0xDE, 0x45, 0xB4, 0x39, 0xAB, 0xAE, 0x50, 0xDF, 0x55, 0x9A,
0xE1, 0x6B, 0x1A, 0xF3, 0x11, 0x71, 0x2A, 0xBD, 0xE7, 0x38, 0x10, 0xD6, 0x2C, 0x02, 0x57, 0x7A, 0xEF, 0x96,
0x67, 0x89, 0x1A, 0x57, 0x5E, 0xA3, 0x1D, 0x15, 0x32, 0xA4, 0xA5, 0x3D, 0x78, 0x32, 0xB9, 0xC6, 0x46, 0x5E,
0x78, 0x0E, 0x15, 0xF4, 0xDC, 0x64, 0x12, 0x08, 0x25, 0x49, 0xE0, 0x1E, 0x47, 0x71, 0xE3, 0x93, 0x9D, 0x5F,
0xFB, 0xD1, 0xE9, 0x97, 0xAF, 0xBF, 0xF1, 0xED, 0xEF, 0xDB, 0xE1, 0xDF, 0xC3, 0xF6, 0xED, 0x7F, 0xD7, 0xE7,
0xDB, 0xEE, 0x3E, 0xCF, 0xE4, 0xBE, 0x5E, 0x1E, 0x5F, 0x6F, 0x3F, 0x57, 0x7E, 0xDF, 0x7F, 0x5C, 0x4F, 0xE3,
0xC9, 0x41, 0xFF, 0x00, 0xC6, 0x37, 0x5D, 0x3D, 0xBD, 0xA7, 0x71, 0xE9, 0x37, 0xA3, 0xCE, 0x63, 0xD9, 0xFB,
0xCE, 0xE1, 0x2D, 0xF5, 0xF9, 0x7D, 0x8F, 0xD3, 0xFC, 0x1E, 0x03, 0xCF, 0xC7, 0xEF, 0x2B, 0xF7, 0xF8, 0xC1,
0x7E, 0x3E, 0xD9, 0x8F, 0xCB, 0x93, 0x7D, 0xE0, 0x43, 0xC3, 0x6E, 0x4F, 0x63, 0x74, 0x3D, 0x0C, 0x66, 0x6F,
0xD1, 0x97, 0x27, 0x1C, 0x6F, 0x2D, 0xCB, 0x11, 0x27, 0x64, 0x72, 0xDB, 0xB6, 0xD3, 0xD8, 0xB4, 0x63, 0x0D,
0xFA, 0xCF, 0x4D, 0x65, 0x9C, 0xC7, 0x13, 0x48, 0x3B, 0xDA, 0x34, 0x42, 0xCA, 0x87, 0xE4, 0x5C, 0x07, 0xEA,
0x6E, 0xEA, 0x7D, 0x43, 0xDE, 0xB6, 0x1D, 0xBC, 0xAB, 0xB2, 0x9A, 0xF2, 0xF6, 0x94, 0x55, 0x6A, 0x35, 0xB0,
0xE6, 0x56, 0xA5, 0x52, 0xAA, 0x28, 0xD2, 0x51, 0x98, 0xC0, 0x87, 0xB2, 0x2B, 0x56, 0x51, 0x36, 0x17, 0x1E,
0x10, 0xD2, 0x38, 0x19, 0x28, 0xFC, 0x8A, 0xB9, 0xF4, 0x2F, 0xA6, 0x0B, 0xE8, 0xD7, 0x4A, 0x34, 0xEE, 0x9C,
0x0D, 0xD4, 0xE4, 0x9D, 0xAE, 0xD0, 0x78, 0xDF, 0xC8, 0xD7, 0xAF, 0x35, 0x93, 0x7B, 0x29, 0x92, 0xBF, 0x6F,
0x2D, 0x92, 0xB0, 0xA5, 0x19, 0x1B, 0x21, 0x33, 0x76, 0xF3, 0xD6, 0x82, 0x69, 0x7B, 0x4A, 0xBA, 0xD5, 0x26,
0x20, 0x5F, 0xD6, 0x32, 0x2F, 0xD7, 0x44, 0xE7, 0xAD, 0x72, 0x89, 0x50, 0x49, 0x1B, 0xC6, 0x40, 0x21, 0xD1,
0x97, 0x83, 0xFB, 0xC1, 0x1F, 0xE7, 0xD3, 0x8E, 0x2E, 0xAF, 0x8C, 0x4F, 0x2D, 0x8D, 0xD1, 0xD4, 0xDB, 0xD9,
0xAE, 0xB7, 0x17, 0x6D, 0x2F, 0xE9, 0x89, 0xF4, 0xEE, 0xB7, 0xCC, 0xCB, 0xA8, 0xA4, 0xC5, 0xE5, 0xEC, 0xE4,
0xE9, 0x64, 0x71, 0xD9, 0x6C, 0x82, 0xA3, 0xE6, 0x94, 0x35, 0x2C, 0x46, 0x42, 0xB5, 0xAA, 0xF6, 0xF2, 0x9F,
0x13, 0x90, 0x86, 0x42, 0xD5, 0xE4, 0x8D, 0x2D, 0x9A, 0xF2, 0x24, 0x8D, 0x5C, 0xD8, 0x9F, 0x3B, 0x7A, 0x4F,
0xF2, 0xBF, 0x58, 0xD4, 0x74, 0x6C, 0x16, 0xAD, 0xB6, 0x61, 0x36, 0x4B, 0x37, 0xB0, 0x35, 0x27, 0x1C, 0x9B,
0xB8, 0x44, 0x63, 0x2D, 0xD7, 0xB3, 0x45, 0x0D, 0x38, 0xA1, 0x06, 0xBB, 0xF9, 0x5C, 0x73, 0x10, 0xD4, 0x53,
0x95, 0x55, 0x60, 0x8F, 0xB8, 0x0E, 0x51, 0x0D, 0x19, 0x18, 0x6F, 0xA9, 0x52, 0x6B, 0xE4, 0x27, 0xE9, 0xF3,
0xBD, 0xF5, 0x13, 0xAA, 0xBB, 0x66, 0xFB, 0xD3, 0xDD, 0xA3, 0x48, 0xA3, 0x89, 0xDB, 0x72, 0x11, 0x9A, 0xB3,
0x8B, 0xDA, 0x2D, 0x67, 0x71, 0xF7, 0x29, 0x65, 0x6D, 0xA1, 0x73, 0x97, 0x95, 0xB7, 0x13, 0xAF, 0xE6, 0x91,
0x69, 0x16, 0xF2, 0x22, 0xFB, 0xEA, 0x32, 0xFA, 0x66, 0x2E, 0x2D, 0x92, 0x18, 0x2C, 0x24, 0x7B, 0xDF, 0xF3,
0x7E, 0x17, 0x7C, 0xBC, 0xF7, 0x4F, 0x4B, 0x6E, 0x76, 0x27, 0x54, 0xEB, 0xC5, 0xC3, 0x9A, 0x98, 0x95, 0x95,
0xE9, 0x56, 0xC5, 0x58, 0xB9, 0x64, 0xFC, 0x5C, 0xC5, 0x21, 0x69, 0xE7, 0x92, 0xEE, 0x3A, 0x88, 0x11, 0xA5,
0x47, 0xB1, 0x1A, 0xC7, 0x1A, 0x33, 0x34, 0x92, 0x86, 0x32, 0x22, 0xC4, 0x56, 0x5E, 0xB5, 0xD7, 0x6F, 0x92,
0xF8, 0x3E, 0xA4, 0x69, 0xF3, 0xA8, 0x6A, 0x98, 0x8C, 0xE5, 0x14, 0x5E, 0xC8, 0x53, 0xB3, 0x96, 0xB7, 0x9C,
0x5D, 0x0A, 0xE4, 0xCA, 0x94, 0x0F, 0xEA, 0x93, 0x52, 0xBD, 0x7A, 0x19, 0x0C, 0x84, 0x49, 0x1D, 0xF0, 0xAA,
0xF3, 0x73, 0x5C, 0x22, 0x01, 0x5B, 0xC0, 0x54, 0x44, 0xE8, 0x34, 0xF7, 0x8F, 0x89, 0xFF, 0x00, 0x07, 0x36,
0xBE, 0x89, 0xF5, 0x24, 0x7A, 0x8D, 0xD4, 0x0D, 0x8F, 0x55, 0xCA, 0xDA, 0xC5, 0x62, 0x32, 0x74, 0xB5, 0xEC,
0x76, 0xAA, 0xFC, 0xB5, 0xC0, 0x4E, 0x47, 0x2C, 0xAF, 0xA0, 0xB3, 0x90, 0xBB, 0x6F, 0x2F, 0x86, 0xC3, 0x90,
0xAD, 0x58, 0x87, 0x5F, 0xAA, 0xBA, 0xE8, 0xAE, 0x64, 0xC6, 0xDE, 0x86, 0x93, 0xD6, 0x15, 0xA5, 0x56, 0x58,
0xD3, 0x4E, 0x62, 0xA3, 0xC3, 0x61, 0xE9, 0x63, 0xE3, 0x50, 0xAB, 0x04, 0x2A, 0x9C, 0x01, 0xC7, 0x1C, 0x13,
0xFE, 0xBD, 0x61, 0xBF, 0x29, 0x6F, 0x33, 0xBD, 0x38, 0xE1, 0xD3, 0x8E, 0x1D, 0x38, 0xE1, 0xD3, 0x8E, 0x04,
0x02, 0x38, 0x3E, 0xE0, 0xF4, 0xE3, 0x9E, 0x76, 0xA9, 0x59, 0x8F, 0x73, 0x42, 0x84, 0xFD, 0x79, 0x23, 0xF9,
0xF4, 0xE3, 0x97, 0x52, 0x34, 0x41, 0xC2, 0x28, 0x51, 0xFB, 0xBA, 0x71, 0xCA, 0xFA, 0x71, 0xC3, 0xA7, 0x1C,
0xB7, 0x24, 0x31, 0x4B, 0xFF, 0x00, 0x51, 0x15, 0xFF, 0x00, 0x31, 0xD3, 0x8E, 0x52, 0x95, 0xA0, 0x8C, 0xF2,
0x91, 0x2A, 0x9F, 0xDC, 0x3F, 0x9F, 0x4E, 0x39, 0x7B, 0xA7, 0x1C, 0x3A, 0x71, 0xC3, 0xA7, 0x1C, 0x3A, 0x71,
0xC3, 0xA7, 0x1C, 0x3A, 0x71, 0xC3, 0xA7, 0x1C, 0x3A, 0x71, 0xC3, 0xA7, 0x1C, 0x3A, 0x71, 0xC3, 0xA7, 0x1C,
0x3A, 0x71, 0xC3, 0xA7, 0x1C, 0x3A, 0x71, 0xC3, 0xA7, 0x1C, 0xFF, 0xD9

#else // defined GAS
// rotes "G"
0xFF, 0xD8, 0xFF, 0xE0, 0x00, 0x10, 0x4A, 0x46, 0x49, 0x46, 0x00, 0x01, 0x01, 0x01, 0x00, 0x60,
0x00, 0x60, 0x00, 0x00, 0xFF, 0xDB, 0x00, 0x43, 0x00, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0xFF, 0xDB, 0x00, 0x43, 0x01, 0x01, 0x01,
0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0xFF, 0xC0,
0x00, 0x11, 0x08, 0x00, 0x5C, 0x00, 0x5C, 0x03, 0x01, 0x11, 0x00, 0x02, 0x11, 0x01, 0x03, 0x11,
0x01, 0xFF, 0xC4, 0x00, 0x1E, 0x00, 0x01, 0x00, 0x02, 0x02, 0x03, 0x01, 0x01, 0x01, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x0A, 0x08, 0x0B, 0x03, 0x04, 0x06, 0x07, 0x05,
0x02, 0xFF, 0xC4, 0x00, 0x49, 0x10, 0x00, 0x01, 0x04, 0x01, 0x02, 0x04, 0x02, 0x04, 0x05, 0x0C,
0x13, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x01, 0x03, 0x04, 0x05, 0x06, 0x00, 0x07, 0x08, 0x09,
0x11, 0x12, 0x13, 0x14, 0x0A, 0x15, 0x21, 0x41, 0x22, 0x31, 0x32, 0x42, 0x51, 0x16, 0x1A, 0x23,
0x33, 0x36, 0x72, 0x74, 0x91, 0xA1, 0xB1, 0xB3, 0xC1, 0x24, 0x25, 0x35, 0x38, 0x39, 0x56, 0x61,
0x71, 0x73, 0x75, 0x77, 0x96, 0xB2, 0xB5, 0xC2, 0xD2, 0xD7, 0xE1, 0xF0, 0xFF, 0xC4, 0x00, 0x1E,
0x01, 0x01, 0x00, 0x02, 0x03, 0x01, 0x00, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x08, 0x09, 0x06, 0x07, 0x0A, 0x05, 0x01, 0x03, 0x04, 0x02, 0xFF, 0xC4, 0x00, 0x44,
0x11, 0x00, 0x01, 0x04, 0x02, 0x01, 0x03, 0x02, 0x03, 0x03, 0x03, 0x10, 0x0B, 0x00, 0x00, 0x00,
0x00, 0x02, 0x01, 0x03, 0x04, 0x05, 0x00, 0x06, 0x07, 0x08, 0x11, 0x12, 0x13, 0x21, 0x09, 0x14,
0x31, 0x15, 0x22, 0x32, 0x19, 0x23, 0x41, 0x16, 0x17, 0x18, 0x37, 0x38, 0x42, 0x55, 0x56, 0x75,
0x76, 0x94, 0x96, 0xB4, 0xB5, 0xD5, 0xD7, 0x24, 0x25, 0x51, 0x58, 0x62, 0x77, 0x91, 0x92, 0xB2,
0xB3, 0xD3, 0xFF, 0xDA, 0x00, 0x0C, 0x03, 0x01, 0x00, 0x02, 0x11, 0x03, 0x11, 0x00, 0x3F, 0x00,
0xBF, 0xC6, 0x98, 0xC6, 0x98, 0xC6, 0x98, 0xC6, 0x98, 0xC6, 0x98, 0xC6, 0x98, 0xC6, 0x98, 0xC6,
0x98, 0xC6, 0x98, 0xC6, 0x98, 0xC6, 0x98, 0xC6, 0x98, 0xC6, 0x98, 0xC6, 0x98, 0xC6, 0x98, 0xC6,
0x98, 0xCE, 0x85, 0x85, 0x9D, 0x7D, 0x54, 0x59, 0x13, 0x6C, 0x65, 0xC7, 0x85, 0x12, 0x23, 0x2E,
0xC9, 0x95, 0x26, 0x4B, 0xA0, 0xCC, 0x78, 0xF1, 0xD8, 0x05, 0x75, 0xE7, 0xDF, 0x79, 0xC5, 0x16,
0xDA, 0x65, 0xA6, 0xC4, 0x8D, 0xC7, 0x1C, 0x21, 0x00, 0x01, 0x22, 0x25, 0x41, 0x45, 0x54, 0xF8,
0x22, 0x10, 0x12, 0x33, 0x24, 0x11, 0x14, 0x52, 0x22, 0x25, 0x41, 0x11, 0x11, 0x4E, 0xEA, 0x44,
0xAB, 0xD9, 0x11, 0x11, 0x11, 0x55, 0x55, 0x55, 0x11, 0x11, 0x3B, 0xAE, 0x7D, 0x8C, 0xB2, 0xF4,
0x87, 0x9A, 0x8F, 0x1D, 0xA7, 0x1F, 0x7D, 0xF7, 0x01, 0x96, 0x18, 0x64, 0x09, 0xD7, 0x9E, 0x79,
0xD2, 0x40, 0x6D, 0xA6, 0x9B, 0x04, 0x23, 0x71, 0xC7, 0x0C, 0x84, 0x00, 0x00, 0x54, 0x8C, 0x95,
0x04, 0x51, 0x55, 0x51, 0x32, 0x3F, 0x77, 0x37, 0x9A, 0xE7, 0x2F, 0xDD, 0xA6, 0x9F, 0x2E, 0xAF,
0x2B, 0xE2, 0x7B, 0x6D, 0x1E, 0xB1, 0x82, 0x46, 0x13, 0x21, 0x62, 0x73, 0xEC, 0xB7, 0x02, 0x44,
0x67, 0x5A, 0x15, 0x27, 0x23, 0xBE, 0xD6, 0x03, 0x57, 0x93, 0x13, 0x32, 0x9B, 0xED, 0x50, 0x38,
0xA7, 0xD2, 0x40, 0x3B, 0xF6, 0x12, 0x69, 0x1D, 0x54, 0x0D, 0x60, 0x96, 0x5C, 0x9F, 0xA0, 0x54,
0xB8, 0x6D, 0x4D, 0xDA, 0xAA, 0xBD, 0x46, 0xFB, 0xA1, 0xB7, 0x11, 0xD3, 0xB1, 0x30, 0x54, 0x45,
0x55, 0x12, 0x1A, 0xE6, 0xE5, 0x28, 0x9A, 0x76, 0xEC, 0xA0, 0xA8, 0x86, 0x8B, 0xF7, 0x7B, 0x79,
0x7B, 0x64, 0xAC, 0xD2, 0xBA, 0x17, 0xEA, 0xEB, 0x90, 0x62, 0xC7, 0x9D, 0xAD, 0x70, 0x1E, 0xFC,
0xB0, 0xA5, 0x88, 0x1C, 0x59, 0x7B, 0x04, 0x08, 0xBA, 0x6C, 0x79, 0x0D, 0xB8, 0x48, 0x2D, 0xBC,
0xCB, 0xDB, 0x94, 0xCA, 0x16, 0xDD, 0x8E, 0x7D, 0xD0, 0x86, 0x40, 0x12, 0xB0, 0x4D, 0xFE, 0x75,
0x1C, 0x56, 0x91, 0x4F, 0x3E, 0x35, 0x5F, 0xCF, 0x2F, 0x96, 0xA5, 0x94, 0xB1, 0x89, 0x1F, 0x88,
0x86, 0x5B, 0x32, 0xF6, 0xA3, 0x93, 0xF6, 0xCF, 0x79, 0xAA, 0xA3, 0x74, 0xEE, 0x41, 0xF8, 0x52,
0xED, 0x36, 0xDE, 0x1C, 0x50, 0x5E, 0xA4, 0x8B, 0xDA, 0x6F, 0x09, 0x76, 0xF7, 0x12, 0x27, 0x68,
0x1A, 0x8F, 0x92, 0xD7, 0x35, 0x71, 0x93, 0xC6, 0x80, 0x1B, 0x43, 0x68, 0xAB, 0xFA, 0x5D, 0xAB,
0xBC, 0x60, 0x3E, 0xA8, 0x9E, 0xEE, 0x3D, 0x58, 0xDB, 0x69, 0xF5, 0xFD, 0x24, 0x9E, 0xDD, 0xD7,
0xE8, 0x8B, 0xDB, 0x61, 0x4E, 0xF8, 0x63, 0xF5, 0xC9, 0x5F, 0x1C, 0xA4, 0xC8, 0xE0, 0x99, 0x8E,
0x36, 0x2B, 0xD9, 0x46, 0x0E, 0xF9, 0xC5, 0xB6, 0x72, 0x15, 0x7C, 0x48, 0xBE, 0xEC, 0x4A, 0xDD,
0xE2, 0x5C, 0xA2, 0x4E, 0xC2, 0xA9, 0xDC, 0x59, 0x54, 0xF2, 0x51, 0x1E, 0xFE, 0x44, 0x28, 0xB9,
0xA9, 0xB3, 0xDC, 0x67, 0x70, 0xC9, 0xBF, 0x8D, 0x36, 0x7B, 0x49, 0xBD, 0x5B, 0x73, 0x9D, 0xBA,
0x60, 0x6E, 0x1D, 0x7E, 0x3B, 0x94, 0xD6, 0xCF, 0xB9, 0x8A, 0x2D, 0xAF, 0xD9, 0x12, 0xC2, 0x8C,
0x5D, 0x1B, 0x9A, 0xD3, 0x11, 0xE8, 0xE2, 0xB7, 0x3E, 0x0C, 0x67, 0x3C, 0x23, 0x6D, 0xEE, 0xDF,
0x09, 0xD6, 0xCC, 0xB3, 0x6A, 0x8D, 0x9B, 0x5E, 0xBF, 0x1F, 0x2A, 0x5B, 0xBA, 0xCB, 0x3F, 0x65,
0x52, 0x6E, 0x1C, 0xD6, 0x1E, 0x78, 0x11, 0x3E, 0xBE, 0xAC, 0x71, 0x3F, 0x5D, 0xA5, 0x4F, 0x65,
0xEC, 0xEB, 0x60, 0xBE, 0x2A, 0x85, 0xDB, 0xC5, 0x51, 0x56, 0x30, 0x72, 0x2F, 0x07, 0xF3, 0x1F,
0x11, 0xBE, 0x4C, 0x72, 0x6F, 0x18, 0x6F, 0x3A, 0x3A, 0x21, 0x83, 0x6D, 0xCB, 0xD8, 0xF5, 0xAB,
0x5A, 0xEA, 0xC9, 0x24, 0xE7, 0xE0, 0x58, 0x36, 0xEF, 0x46, 0x4A, 0xBB, 0x00, 0x22, 0x42, 0x04,
0x72, 0x0C, 0xC9, 0x0D, 0xFA, 0xA0, 0xE3, 0x5E, 0x5E, 0xA3, 0x6E, 0x00, 0xE4, 0xD4, 0x79, 0x4C,
0x4A, 0x04, 0x71, 0x87, 0x45, 0xC1, 0x54, 0x45, 0x45, 0x15, 0xEA, 0x9D, 0x17, 0xDB, 0xEF, 0x44,
0xF7, 0x6B, 0xDC, 0xCD, 0x59, 0x9D, 0x8D, 0x31, 0x8D, 0x31, 0x8D, 0x31, 0x8D, 0x31, 0x8D, 0x31,
0x8D, 0x31, 0x91, 0xFD, 0xCC, 0x0F, 0x98, 0x5E, 0xD0, 0x70, 0x05, 0xB5, 0xE3, 0x96, 0x66, 0xCE,
0x26, 0x49, 0x9F, 0x64, 0x49, 0x22, 0x26, 0xDC, 0xED, 0x7D, 0x64, 0xE6, 0x63, 0x5F, 0xE5, 0xD6,
0x2C, 0x78, 0x69, 0x22, 0x53, 0xAE, 0x1B, 0x72, 0x3D, 0x4F, 0x8C, 0xD5, 0x23, 0xCD, 0xBB, 0x75,
0x90, 0x49, 0x8E, 0xE3, 0x31, 0xBB, 0xD9, 0x85, 0x11, 0x99, 0xB6, 0xB2, 0xE1, 0x41, 0x91, 0x82,
0xEF, 0xBB, 0xFD, 0x3E, 0x85, 0x57, 0xF3, 0xB3, 0xD7, 0xE6, 0x27, 0x48, 0xF2, 0x0A, 0xDA, 0xB6,
0x8C, 0x46, 0x4C, 0xD7, 0x47, 0xB7, 0x91, 0x2A, 0xAA, 0x17, 0xA3, 0x15, 0x9E, 0xE8, 0xB2, 0x24,
0x90, 0xA8, 0x82, 0x28, 0x80, 0x0B, 0x8F, 0x38, 0xDB, 0x67, 0x2B, 0x3A, 0x4C, 0xE9, 0x1B, 0x91,
0xFA, 0xB5, 0xDF, 0x17, 0x59, 0xD4, 0x9B, 0xFB, 0x1B, 0x57, 0xA7, 0xF4, 0x64, 0xEE, 0xBB, 0xE4,
0xF8, 0xAE, 0xBD, 0x4D, 0xAC, 0xC1, 0x75, 0x49, 0x59, 0x64, 0x40, 0x09, 0xAF, 0xB4, 0xAF, 0x2C,
0x3D, 0x33, 0x6E, 0xAA, 0x99, 0x87, 0x9B, 0x7A, 0x42, 0x83, 0xB2, 0x64, 0x3B, 0x16, 0xBE, 0x34,
0xB9, 0x8C, 0x51, 0x4F, 0x8B, 0xCE, 0x62, 0x5C, 0x53, 0xF1, 0xB5, 0x92, 0x4D, 0x7F, 0x74, 0x73,
0xCB, 0x38, 0x78, 0x6C, 0xA9, 0xC4, 0x54, 0x7B, 0x45, 0x87, 0x48, 0x9B, 0x4F, 0xB7, 0xF5, 0x2C,
0x93, 0xC8, 0xB0, 0xA3, 0xAD, 0x24, 0x77, 0xC9, 0xCC, 0x8E, 0xC5, 0x9F, 0x80, 0x23, 0x6F, 0x91,
0xBB, 0x6B, 0x66, 0x6E, 0xA9, 0xF9, 0x67, 0x62, 0xB0, 0x61, 0x15, 0xB8, 0x3B, 0xB7, 0x72, 0x2E,
0xD7, 0xBB, 0xC9, 0x34, 0xB2, 0x9C, 0xE8, 0x42, 0x71, 0xCE, 0xD1, 0xE9, 0xA0, 0x93, 0x8D, 0x57,
0xB6, 0x8A, 0x5F, 0x9B, 0x05, 0x60, 0x49, 0x4A, 0x53, 0xA8, 0xBD, 0x91, 0x1E, 0x92, 0xAF, 0x3A,
0xA4, 0xAB, 0xE0, 0xA0, 0x2A, 0x80, 0x9D, 0x4D, 0x74, 0xEF, 0xD1, 0xA7, 0x00, 0xF4, 0xBB, 0x4B,
0x1C, 0xB4, 0xAD, 0x5A, 0x04, 0xAD, 0x9E, 0x2C, 0x3E, 0xF7, 0x1C, 0x97, 0xB4, 0xB5, 0x0E, 0xC3,
0x6E, 0x9A, 0x40, 0xCA, 0xFC, 0xE4, 0x84, 0xB5, 0x7D, 0x90, 0x6A, 0x82, 0x01, 0x8A, 0x19, 0x1D,
0x75, 0x23, 0x75, 0xD0, 0x05, 0xA1, 0x15, 0x90, 0x12, 0x1D, 0x03, 0x90, 0x6D, 0xA1, 0xE5, 0xB9,
0xC5, 0xFE, 0xF4, 0xD7, 0xC5, 0xB8, 0xC6, 0x76, 0xB6, 0x55, 0x35, 0x3C, 0xE1, 0x13, 0x89, 0x61,
0x98, 0xCD, 0x8F, 0x8E, 0xAB, 0xED, 0x9B, 0x62, 0xE8, 0x3A, 0x35, 0x4F, 0x78, 0xD7, 0xE2, 0xCB,
0x80, 0x6D, 0xAB, 0x4F, 0xB9, 0x52, 0x0C, 0xBD, 0xDE, 0x8A, 0xD3, 0x86, 0x22, 0xE2, 0x87, 0xB1,
0x47, 0xC3, 0x1C, 0x83, 0x7A, 0xC3, 0x72, 0x9B, 0xA7, 0x1A, 0xD8, 0xCE, 0xA2, 0x13, 0x6F, 0x5C,
0x48, 0x08, 0x24, 0x62, 0xA2, 0x84, 0x85, 0xF2, 0xAA, 0x8E, 0x4E, 0x11, 0x24, 0x54, 0x51, 0x33,
0x8A, 0x22, 0x5D, 0xFB, 0x89, 0x2A, 0x21, 0x2A, 0x6B, 0x8E, 0x54, 0xF8, 0x99, 0x74, 0x81, 0xC5,
0x36, 0xB2, 0xE8, 0x66, 0xF2, 0x2B, 0xDB, 0xA5, 0xDC, 0x07, 0x09, 0xA9, 0xB0, 0x38, 0xE6, 0xA2,
0x56, 0xD4, 0xC4, 0x77, 0x41, 0xD2, 0x65, 0xC6, 0x56, 0xFD, 0xB2, 0x89, 0xAB, 0x3A, 0xFB, 0x46,
0x0E, 0x23, 0xD1, 0xE3, 0xDE, 0xBC, 0xFB, 0x0A, 0xDA, 0x8B, 0xED, 0xB6, 0x64, 0xD8, 0x9E, 0x4C,
0xD9, 0x72, 0x3B, 0xE3, 0x86, 0x0D, 0x79, 0x4F, 0x8B, 0x0B, 0x6D, 0x2E, 0x8D, 0x3A, 0xAA, 0x40,
0xAC, 0xC9, 0x72, 0x36, 0xA6, 0x1A, 0x78, 0x66, 0x68, 0xA2, 0x57, 0x18, 0x65, 0x4C, 0x14, 0x45,
0x21, 0x16, 0x93, 0xBE, 0x68, 0x2F, 0x7B, 0x80, 0xAA, 0x88, 0xDA, 0x38, 0xE3, 0x79, 0x3B, 0xFD,
0x3A, 0x6F, 0x8C, 0xB6, 0xA6, 0xDC, 0xDD, 0x6A, 0x51, 0x27, 0xD1, 0x96, 0x2C, 0x27, 0x8B, 0x85,
0xEC, 0xAB, 0xEC, 0xB2, 0xAA, 0x63, 0x35, 0xF5, 0x44, 0x1F, 0xBC, 0xEA, 0x7B, 0x92, 0x7E, 0xF7,
0xBA, 0xA6, 0x8D, 0xA9, 0xF8, 0xCD, 0xF4, 0x9F, 0x63, 0x30, 0x23, 0x4C, 0xD6, 0xB9, 0xB6, 0x85,
0x82, 0x44, 0x52, 0xB1, 0xB6, 0xD4, 0x75, 0x27, 0xA1, 0xB7, 0xDD, 0xC0, 0x05, 0x43, 0x0A, 0x3D,
0xFE, 0xE6, 0xC1, 0x55, 0x04, 0xC9, 0xD5, 0xF4, 0xE0, 0xB8, 0x9E, 0x9B, 0x46, 0x88, 0xAA, 0xEA,
0xB6, 0xDB, 0x98, 0x37, 0xBB, 0x7C, 0x29, 0xF1, 0x4B, 0xC2, 0xED, 0x93, 0x56, 0xFB, 0x8D, 0xB6,
0x59, 0xD6, 0x02, 0xB5, 0x92, 0x9A, 0x72, 0x0E, 0x69, 0x56, 0x8E, 0x4A, 0xA4, 0x8D, 0x29, 0x7B,
0x16, 0x3B, 0xD1, 0x33, 0x1C, 0x6A, 0x4C, 0xBA, 0xD8, 0x52, 0x8F, 0xC4, 0x1F, 0x09, 0xB3, 0xB0,
0x8B, 0x38, 0x0D, 0x49, 0xA2, 0x65, 0xB7, 0x81, 0xC6, 0xC7, 0x5C, 0x5E, 0xE8, 0xFB, 0xA6, 0x9A,
0xEA, 0x49, 0xB4, 0xA8, 0xB0, 0xAE, 0x16, 0x4D, 0x15, 0xBB, 0x38, 0xA5, 0xEB, 0x45, 0x03, 0xF6,
0xF0, 0x20, 0xB0, 0x82, 0xE3, 0xAC, 0xB4, 0x65, 0xE4, 0x9E, 0x28, 0x4E, 0xB6, 0xEA, 0x2A, 0xA8,
0xA8, 0xA1, 0x21, 0x0A, 0x4D, 0x1E, 0x2A, 0xEA, 0x9B, 0xA6, 0x4E, 0xA5, 0x60, 0xB9, 0x4B, 0xA1,
0xF2, 0x2E, 0x9F, 0xB8, 0x3D, 0x67, 0x19, 0xC6, 0xE6, 0x69, 0x17, 0xAD, 0x2D, 0x65, 0xFC, 0x98,
0xE3, 0xE7, 0xF3, 0x2C, 0xC8, 0xD3, 0xB6, 0x88, 0xB0, 0x6C, 0x6C, 0x23, 0x37, 0xE9, 0x1A, 0xBC,
0xEB, 0x10, 0x26, 0x41, 0x20, 0x11, 0x78, 0x5F, 0x71, 0x93, 0x6D, 0xC3, 0x9E, 0x7E, 0x4D, 0x7C,
0xD3, 0x77, 0xE3, 0x29, 0xDD, 0x5A, 0xCE, 0x1B, 0x37, 0xBB, 0x21, 0x9B, 0xB8, 0xF5, 0x36, 0x54,
0xD3, 0xE6, 0xE2, 0x19, 0xBD, 0xD3, 0xC3, 0x23, 0x2E, 0xAD, 0x91, 0x51, 0xE1, 0xC9, 0x93, 0x53,
0x90, 0xDA, 0xBD, 0xF6, 0x7C, 0x8A, 0x14, 0xA8, 0x66, 0xFB, 0x91, 0x2D, 0x2C, 0x0D, 0xEB, 0xA8,
0xB2, 0xA3, 0x84, 0x69, 0x32, 0xA7, 0xC5, 0x94, 0xD2, 0xD6, 0xC8, 0x2E, 0x10, 0xE5, 0x0B, 0xFB,
0xCB, 0x4F, 0xD4, 0x9E, 0xC0, 0xF1, 0xDA, 0x77, 0x86, 0xFC, 0x9A, 0xFB, 0x37, 0x97, 0xCA, 0x73,
0x65, 0x17, 0xC4, 0xDC, 0x8F, 0x31, 0xD5, 0xF7, 0x96, 0xD9, 0xB6, 0x44, 0x4D, 0xC8, 0x71, 0x56,
0x48, 0x18, 0x78, 0x38, 0x6F, 0x03, 0x82, 0xAC, 0x54, 0x07, 0xC5, 0x1F, 0xA1, 0x3E, 0x24, 0xE2,
0xDD, 0x0D, 0x3A, 0x82, 0xE2, 0x1A, 0xC8, 0xFA, 0x2A, 0x86, 0xCB, 0x55, 0x4B, 0xB7, 0x68, 0xF5,
0xA0, 0xAD, 0x6A, 0xD3, 0x1B, 0xBC, 0xF5, 0x63, 0xC3, 0xB7, 0xD7, 0x20, 0x0F, 0x76, 0xF5, 0xF9,
0x71, 0x66, 0x34, 0xCB, 0x32, 0xEA, 0x61, 0x0B, 0x54, 0xD2, 0x62, 0xC8, 0x59, 0x31, 0x63, 0xD7,
0xC9, 0x88, 0xE8, 0xD9, 0x5C, 0x16, 0xBE, 0x58, 0xCE, 0x87, 0x1A, 0x50, 0x7C, 0x97, 0xD9, 0x6D,
0xC4, 0xF7, 0xFC, 0xB0, 0x13, 0xFF, 0x00, 0x56, 0xA5, 0x16, 0x51, 0x06, 0x77, 0x34, 0xC6, 0x34,
0xC6, 0x34, 0xC6, 0x34, 0xC6, 0x78, 0xBD, 0xC6, 0xCF, 0x71, 0xAD, 0xAD, 0xC0, 0xF3, 0x0D, 0xC7,
0xCC, 0x6C, 0x5B, 0xA8, 0xC5, 0x70, 0x6C, 0x6A, 0xEB, 0x2C, 0xC8, 0xAC, 0xDD, 0x45, 0x20, 0x83,
0x49, 0x41, 0x5E, 0xFD, 0x9D, 0x9C, 0xA5, 0x04, 0xF8, 0x4E, 0x2B, 0x30, 0xE3, 0x3C, 0x60, 0xD0,
0x22, 0xB8, 0xE9, 0xA0, 0xB6, 0x08, 0xA6, 0x48, 0x9A, 0xFC, 0xB3, 0xA6, 0xC6, 0xAD, 0x85, 0x2E,
0xC2, 0x63, 0x88, 0xCC, 0x48, 0x31, 0x9F, 0x97, 0x25, 0xD2, 0xFA, 0x36, 0xC4, 0x76, 0xC9, 0xD7,
0x4D, 0x53, 0xEA, 0xBE, 0x20, 0x04, 0xBD, 0x93, 0xDD, 0x55, 0x3B, 0x27, 0xBA, 0xE7, 0xBD, 0xAA,
0xEB, 0x37, 0x5B, 0xA6, 0xCD, 0xAF, 0x69, 0xFA, 0xE4, 0x23, 0xB1, 0xD8, 0x36, 0x9B, 0xBA, 0xBD,
0x7A, 0x92, 0x03, 0x6A, 0x88, 0x73, 0x2D, 0x6E, 0x66, 0xB1, 0x5F, 0x02, 0x3A, 0x12, 0xFD, 0xD0,
0xF5, 0x65, 0x48, 0x68, 0x14, 0xCB, 0xB0, 0x00, 0xAA, 0x99, 0xAA, 0x08, 0xAA, 0xA6, 0xB4, 0xBE,
0x35, 0x38, 0xB1, 0xCE, 0xF8, 0xD2, 0xE2, 0x1B, 0x38, 0xDE, 0xEC, 0xD2, 0x44, 0xC0, 0x8D, 0x71,
0x60, 0xED, 0x6E, 0x0B, 0x8C, 0x3C, 0xF7, 0x89, 0x1B, 0x0B, 0xC0, 0xE0, 0x3E, 0xEB, 0x78, 0xCE,
0x33, 0x0D, 0xA6, 0xC8, 0xA3, 0x8B, 0xF1, 0xE1, 0x92, 0x4A, 0xB9, 0x93, 0x1C, 0x44, 0x6D, 0x6F,
0xE5, 0xDA, 0x5A, 0x18, 0xA1, 0xCC, 0x51, 0x1A, 0xDD, 0xDD, 0x76, 0xC9, 0xFB, 0xA6, 0xC5, 0x3A,
0xEE, 0x61, 0x1A, 0x03, 0xAE, 0x2B, 0x55, 0xF1, 0x55, 0x7B, 0x8C, 0x2A, 0xF6, 0xC8, 0x92, 0x2C,
0x50, 0x44, 0x55, 0x1F, 0x21, 0x05, 0xF3, 0x7C, 0x87, 0xB2, 0x3B, 0x20, 0xDD, 0x75, 0x53, 0xB9,
0xF6, 0x4E, 0xD5, 0xBA, 0x62, 0xE9, 0xF3, 0x54, 0xE9, 0x93, 0x87, 0x35, 0x7E, 0x31, 0xD7, 0x1A,
0x8A, 0x72, 0xAB, 0xE1, 0xB7, 0x3F, 0x6F, 0xBF, 0x6D, 0xBF, 0x4D, 0xED, 0x9F, 0x6E, 0x96, 0xCB,
0x67, 0x79, 0x79, 0x25, 0xC7, 0x04, 0x5E, 0x56, 0x1C, 0x90, 0x2B, 0x1A, 0xAD, 0x87, 0xD5, 0x56,
0xBE, 0x9A, 0x34, 0x08, 0x08, 0xAA, 0x31, 0xBC, 0x8A, 0xC0, 0x7C, 0xA4, 0x79, 0x59, 0xD6, 0x05,
0x5E, 0x3F, 0xBD, 0x3B, 0xB7, 0x42, 0x13, 0xF3, 0x5B, 0x46, 0xE2, 0xDC, 0x53, 0xC0, 0xB3, 0x63,
0xC4, 0x63, 0x0A, 0xAF, 0x79, 0x11, 0xC8, 0x8D, 0x47, 0x60, 0xC0, 0xC0, 0x72, 0x27, 0xD8, 0x75,
0xB7, 0xEC, 0x26, 0x3A, 0x0A, 0xFD, 0x69, 0xA8, 0x57, 0xC3, 0xF0, 0x1C, 0x66, 0x5B, 0xF3, 0x25,
0x8F, 0x0F, 0xF1, 0x4C, 0x3D, 0x72, 0xBE, 0x26, 0xC5, 0x7B, 0x10, 0x1F, 0xD9, 0x26, 0x36, 0x12,
0x63, 0xB5, 0x20, 0x10, 0xC6, 0x91, 0x97, 0x07, 0xC9, 0x96, 0xDA, 0x02, 0x4E, 0xC3, 0x60, 0x40,
0x42, 0x72, 0x5E, 0x54, 0xF5, 0x23, 0x92, 0xFC, 0xBB, 0x3E, 0x0A, 0x0E, 0x9B, 0xDC, 0xFB, 0x7C,
0x46, 0xBA, 0xFF, 0x00, 0xD9, 0x39, 0x9F, 0x6F, 0xD8, 0x78, 0x6F, 0x8A, 0xAF, 0xE4, 0xD4, 0xF0,
0xB6, 0xB9, 0x32, 0x5D, 0x1D, 0xC4, 0xDA, 0x99, 0x07, 0x1D, 0xEE, 0x4D, 0xB3, 0x88, 0xEA, 0xC7,
0xB1, 0x97, 0x3A, 0x53, 0x26, 0x86, 0xEE, 0xA0, 0xC4, 0x96, 0x9C, 0x8F, 0x4D, 0x58, 0xD9, 0x24,
0x5B, 0x66, 0x44, 0xAD, 0xEC, 0x52, 0x50, 0xC9, 0x81, 0x16, 0xB6, 0xD3, 0x98, 0x96, 0xD7, 0xE2,
0xB8, 0xA4, 0x16, 0x22, 0x41, 0xAB, 0x88, 0x3E, 0x10, 0x0A, 0x77, 0x2B, 0x0C, 0x11, 0x2A, 0xA0,
0x8A, 0x7B, 0x55, 0x59, 0x45, 0xEB, 0xD4, 0x7A, 0xFF, 0x00, 0xDF, 0xC5, 0xBE, 0xF2, 0xA5, 0x33,
0xDC, 0xA5, 0x55, 0x72, 0x0F, 0x67, 0x92, 0x8D, 0xDB, 0xD3, 0xA7, 0x4F, 0x01, 0xAE, 0x9F, 0x8B,
0xB3, 0x4C, 0x67, 0x8C, 0xCA, 0xB6, 0xBF, 0x0C, 0xCB, 0xEB, 0x66, 0x55, 0xDD, 0x51, 0x56, 0x4E,
0x85, 0x3E, 0x33, 0xF1, 0x26, 0x45, 0x95, 0x0A, 0x23, 0xF1, 0xE5, 0x46, 0x92, 0xD9, 0x34, 0xFC,
0x77, 0xD9, 0x75, 0x87, 0x1B, 0x79, 0x87, 0x9A, 0x23, 0x69, 0xD6, 0x5C, 0x02, 0x6D, 0xC6, 0xC8,
0x80, 0xC4, 0x84, 0x95, 0x35, 0xFC, 0x98, 0x03, 0xA0, 0x6D, 0xB8, 0x02, 0xE3, 0x6E, 0x09, 0x03,
0x8D, 0x98, 0xA1, 0x81, 0x81, 0xA2, 0x89, 0x81, 0x89, 0x22, 0x89, 0x09, 0x0A, 0xA8, 0x90, 0x92,
0x2A, 0x12, 0x2A, 0xA2, 0xA2, 0xA2, 0xE7, 0xDF, 0x16, 0x54, 0x98, 0x32, 0x63, 0xCD, 0x85, 0x21,
0xF8, 0x93, 0x22, 0x3E, 0xCC, 0xA8, 0x92, 0xE2, 0xBC, 0xE4, 0x79, 0x31, 0x64, 0xC7, 0x70, 0x5D,
0x62, 0x44, 0x77, 0xDA, 0x20, 0x75, 0x87, 0xD8, 0x74, 0x01, 0xD6, 0x5E, 0x68, 0xC5, 0xC6, 0xDC,
0x11, 0x30, 0x21, 0x21, 0x45, 0x48, 0xBF, 0xC2, 0x79, 0x40, 0xF0, 0xE7, 0xB4, 0xDC, 0x4A, 0x35,
0xC4, 0x66, 0xD6, 0xD3, 0xDA, 0x62, 0x17, 0x3E, 0x4A, 0xC2, 0x1A, 0xE2, 0x35, 0x56, 0x00, 0xD6,
0x06, 0xC3, 0xD6, 0xA8, 0xD8, 0xCE, 0xB5, 0x81, 0x43, 0xEA, 0xD5, 0x91, 0x5B, 0x38, 0xD9, 0x65,
0x63, 0xB7, 0x16, 0xBE, 0xD2, 0x2D, 0x13, 0x41, 0x22, 0x43, 0x81, 0x4E, 0x92, 0x48, 0x1F, 0x6B,
0x02, 0xAA, 0xE3, 0x3D, 0x4E, 0x8F, 0x67, 0x3D, 0xAA, 0xA2, 0x1B, 0xB5, 0xF3, 0x8E, 0x33, 0xF1,
0xD6, 0x1C, 0x77, 0x44, 0x2A, 0xC5, 0x64, 0xF8, 0x23, 0xB2, 0x1A, 0x88, 0xAD, 0xA9, 0x32, 0xF2,
0x80, 0x28, 0x20, 0x32, 0xF3, 0x71, 0x50, 0x4C, 0xC9, 0x23, 0xFA, 0x8A, 0x86, 0x92, 0xD3, 0x7F,
0xEB, 0x87, 0xA8, 0x2E, 0x53, 0xE0, 0xC8, 0xDC, 0x05, 0xC8, 0x9B, 0x1C, 0x1D, 0xBB, 0x57, 0x8B,
0x75, 0x57, 0x70, 0xDE, 0xC7, 0x73, 0x05, 0xE9, 0x1B, 0xDB, 0xA1, 0x4D, 0xF3, 0x07, 0x02, 0xA6,
0x6E, 0xC2, 0x93, 0x41, 0xAB, 0x2A, 0xF6, 0xDF, 0x7D, 0x24, 0x1C, 0x8B, 0x1A, 0xE9, 0x57, 0x8E,
0x39, 0x1E, 0x3B, 0x47, 0x70, 0xB1, 0x40, 0xE3, 0xB9, 0x2E, 0xB5, 0x91, 0x3C, 0x8C, 0x18, 0xD1,
0x3A, 0xF5, 0xF0, 0x19, 0x6D, 0xBE, 0xBE, 0xDF, 0x98, 0x02, 0x1E, 0xFF, 0x00, 0x6F, 0xCD, 0xFF,
0x00, 0xCB, 0xAC, 0xFF, 0x00, 0x22, 0x26, 0x77, 0xB4, 0xC6, 0x34, 0xC6, 0x34, 0xC6, 0x34, 0xC6,
0x41, 0x77, 0xA4, 0x1B, 0xBD, 0x52, 0xF6, 0xC7, 0x80, 0xC9, 0xF8, 0x5D, 0x54, 0xD5, 0x89, 0x65,
0xBD, 0xDB, 0x87, 0x8A, 0xED, 0xD3, 0xC8, 0xCB, 0x9D, 0x92, 0xCB, 0x1E, 0x88, 0x93, 0x73, 0x9B,
0xF2, 0x6F, 0xA2, 0x29, 0x79, 0x59, 0x0D, 0x62, 0x51, 0x69, 0x67, 0xF4, 0x51, 0x13, 0x8D, 0x72,
0x51, 0xCC, 0x94, 0x64, 0x28, 0x16, 0x93, 0xE7, 0xDB, 0x93, 0xAB, 0xD0, 0x5E, 0x88, 0xD1, 0xF8,
0x3B, 0x79, 0x63, 0x0E, 0xB1, 0x7C, 0x57, 0xB1, 0xFC, 0xB8, 0xFA, 0x93, 0xA4, 0x76, 0xFF, 0x00,
0x80, 0x86, 0x18, 0xB0, 0xE7, 0xD1, 0x14, 0x1F, 0x51, 0x5F, 0xC5, 0xD9, 0x6C, 0xFB, 0xE1, 0x1F,
0xC6, 0xB1, 0xF7, 0xBE, 0xAE, 0x2B, 0x76, 0x09, 0xF1, 0x52, 0x44, 0x1E, 0x2E, 0xD3, 0x76, 0x3D,
0xE0, 0x3D, 0x50, 0xF3, 0x8E, 0x97, 0x0E, 0xAC, 0x2D, 0x52, 0x9D, 0x0F, 0xBA, 0xA2, 0x7C, 0xC3,
0x0F, 0x6C, 0x8F, 0x5A, 0x43, 0xEE, 0x84, 0xA2, 0xFD, 0x5A, 0x3C, 0x28, 0x84, 0xCA, 0x10, 0xD3,
0xD7, 0x81, 0x1D, 0xA2, 0x63, 0x7B, 0x38, 0xA5, 0xDA, 0xBC, 0x36, 0x7B, 0x1E, 0x62, 0x9E, 0x35,
0xC1, 0xE4, 0xF7, 0x2C, 0xA8, 0x13, 0x80, 0xF4, 0x3C, 0x69, 0x83, 0xB4, 0x8F, 0x19, 0xD0, 0x15,
0x14, 0x28, 0xF3, 0xAD, 0x9A, 0xAD, 0x81, 0x25, 0x0C, 0xC4, 0x3C, 0xBC, 0xA7, 0x55, 0x51, 0xC5,
0xED, 0x65, 0xC8, 0xB9, 0xC4, 0x9A, 0xFB, 0x7B, 0x1E, 0xFB, 0x47, 0x0E, 0x40, 0x21, 0xC4, 0x88,
0xEB, 0x96, 0xB2, 0xC5, 0x51, 0x48, 0x49, 0xAA, 0xD0, 0x59, 0x0D, 0x36, 0x63, 0xEC, 0x8A, 0xDB,
0xD2, 0xC6, 0x33, 0x0E, 0x21, 0x2A, 0x27, 0xA6, 0xE9, 0x7E, 0x25, 0xEC, 0x05, 0x7C, 0x7F, 0x10,
0xDE, 0x5E, 0x9B, 0xC3, 0x1D, 0x25, 0xF2, 0x9E, 0xC5, 0x4F, 0x21, 0x63, 0x6C, 0x5B, 0x0C, 0x08,
0x9A, 0x0E, 0xBC, 0xF8, 0x98, 0xB6, 0xE3, 0x13, 0x77, 0x39, 0x41, 0x51, 0x3E, 0x5B, 0x0E, 0x12,
0x11, 0x04, 0xAA, 0xED, 0x79, 0xCB, 0xBB, 0x38, 0x64, 0xD8, 0x1B, 0x89, 0x2E, 0x13, 0x1D, 0x95,
0xA1, 0xF2, 0x90, 0xCE, 0xC7, 0x8D, 0x93, 0xC3, 0x21, 0xE2, 0x18, 0x55, 0x4C, 0x48, 0xF1, 0xC1,
0xB3, 0x58, 0x8C, 0x11, 0x12, 0x08, 0xA2, 0xAA, 0x9B, 0x2C, 0x92, 0xFB, 0x91, 0x7E, 0x52, 0x2A,
0xFB, 0xFE, 0x9F, 0x8F, 0x56, 0x1F, 0x9C, 0x6F, 0x67, 0xD8, 0xF4, 0xC6, 0x34, 0xC6, 0x34, 0xC6,
0x34, 0xC6, 0x34, 0xC6, 0x34, 0xC6, 0x34, 0xC6, 0x34, 0xC6, 0x34, 0xC6, 0x55, 0x5F, 0xD2, 0x75,
0xB3, 0x90, 0x18, 0x67, 0x09, 0xF5, 0x02, 0xA3, 0xE5, 0x25, 0x65, 0xBB, 0xA9, 0x60, 0xF0, 0xAA,
0x2F, 0x7A, 0xC8, 0xAE, 0xA4, 0xC2, 0x63, 0xC6, 0x51, 0x54, 0x24, 0x14, 0x14, 0x6E, 0xD6, 0x5A,
0x12, 0x28, 0x11, 0x2A, 0xA8, 0x76, 0x90, 0xA2, 0x10, 0x94, 0x60, 0xEA, 0x61, 0xC2, 0x4A, 0xDD,
0x4D, 0xA4, 0xED, 0xE0, 0x73, 0xAD, 0x5C, 0x2F, 0xAF, 0x7F, 0x26, 0x98, 0x86, 0x21, 0xFA, 0x7B,
0x76, 0xEC, 0xF1, 0xF7, 0xF6, 0x55, 0xFA, 0x76, 0x54, 0xF7, 0xEF, 0x7A, 0x9F, 0x03, 0xE8, 0x6C,
0x9E, 0xE9, 0xD4, 0x15, 0x81, 0x79, 0x7C, 0xC4, 0x5D, 0x5F, 0x41, 0x86, 0xD2, 0xA2, 0xA7, 0x87,
0xA3, 0x3E, 0xDB, 0x65, 0x7D, 0xFF, 0x00, 0x24, 0xF1, 0x52, 0x52, 0xF3, 0xAE, 0x8D, 0xE2, 0xA8,
0x48, 0x88, 0x88, 0x7E, 0x42, 0x4A, 0xA2, 0xA3, 0x13, 0x7C, 0x90, 0xEA, 0x62, 0x58, 0x71, 0x7B,
0x3A, 0x4C, 0x86, 0x85, 0xC7, 0x61, 0x6D, 0xEC, 0xD1, 0x8E, 0xA4, 0x88, 0x48, 0xDA, 0x4A, 0xCA,
0x31, 0x64, 0x78, 0xC5, 0x15, 0x17, 0xB5, 0xC2, 0x16, 0x45, 0xB4, 0x31, 0xE8, 0x48, 0xD9, 0xBA,
0x1D, 0x7B, 0x5C, 0x24, 0x5C, 0x37, 0xA6, 0xE6, 0x80, 0xB7, 0x0B, 0x97, 0x89, 0x3B, 0x9B, 0x5A,
0xE3, 0xC2, 0x0A, 0xBE, 0xFE, 0x28, 0xED, 0x95, 0x6F, 0x9A, 0xA7, 0xFB, 0x09, 0x51, 0xB4, 0x4E,
0xE9, 0xD9, 0x50, 0x54, 0x93, 0xE8, 0x4B, 0x92, 0x5B, 0xE3, 0x59, 0x3E, 0x53, 0x3D, 0x38, 0xF1,
0xB5, 0x73, 0x4E, 0x28, 0x45, 0x9D, 0xCD, 0x15, 0x8F, 0x4A, 0x01, 0x55, 0x15, 0x78, 0xA0, 0xE9,
0x3B, 0xAF, 0xCB, 0x81, 0xAA, 0x2A, 0x21, 0x34, 0x25, 0x28, 0xDD, 0x56, 0xC9, 0x08, 0x55, 0xD0,
0x65, 0xCE, 0xC8, 0x4D, 0x0A, 0xA5, 0xFD, 0x68, 0x5A, 0x16, 0x6A, 0x2B, 0xDB, 0x14, 0x44, 0x44,
0x8B, 0x1F, 0xA7, 0x4F, 0xE8, 0x5B, 0x4F, 0xD5, 0xF8, 0xB5, 0x34, 0x73, 0x99, 0x5C, 0xC1, 0xAE,
0x66, 0x3C, 0x59, 0xE5, 0xBC, 0x15, 0xF0, 0x8B, 0x9F, 0xEF, 0xB6, 0x05, 0x41, 0x45, 0x92, 0x66,
0x94, 0x96, 0x38, 0x8D, 0x2E, 0x39, 0x5F, 0x94, 0xB3, 0x61, 0x27, 0x19, 0x09, 0xB9, 0x2E, 0x55,
0x51, 0x48, 0xF4, 0xDB, 0xC8, 0xD5, 0x36, 0x74, 0xF6, 0x72, 0x61, 0xC3, 0xAF, 0x99, 0x35, 0xF6,
0xA3, 0xC2, 0xB3, 0x82, 0xEB, 0xF3, 0xC6, 0x1B, 0x25, 0x25, 0xA6, 0x4D, 0xD3, 0x1C, 0x1B, 0x91,
0xF6, 0xA9, 0x7A, 0x66, 0xA3, 0x63, 0x7F, 0x06, 0x33, 0x12, 0xA6, 0x47, 0x72, 0x1B, 0x31, 0xDA,
0x94, 0x8E, 0x14, 0x54, 0x39, 0x52, 0xD9, 0x61, 0x4E, 0x40, 0xB2, 0xEB, 0x2E, 0x90, 0x03, 0x66,
0x64, 0x82, 0xDB, 0xAD, 0xA9, 0x39, 0xE0, 0x2A, 0x42, 0x8A, 0xAB, 0x92, 0xAB, 0xA2, 0xDE, 0x03,
0xA0, 0xEA, 0x5F, 0xA8, 0x7D, 0x37, 0x89, 0x76, 0xAB, 0x9B, 0x6A, 0x2D, 0x6E, 0xE6, 0x26, 0xC9,
0x65, 0x73, 0x3A, 0x81, 0xC8, 0x4C, 0xDE, 0xAC, 0x5A, 0x1D, 0x7A, 0xC6, 0xD5, 0xB8, 0xD5, 0x2F,
0x59, 0x40, 0xB3, 0x80, 0xCC, 0xA9, 0x32, 0xE3, 0x46, 0x68, 0xDE, 0x95, 0x02, 0x5B, 0x6C, 0xC4,
0x29, 0x2E, 0x8B, 0x0E, 0x3A, 0x0D, 0x82, 0xD5, 0x78, 0xFD, 0x23, 0xBE, 0x3B, 0x8C, 0x94, 0x93,
0x03, 0xE1, 0x94, 0x3A, 0xAA, 0xAF, 0x68, 0x60, 0xBB, 0x99, 0xDA, 0x9D, 0x7E, 0x8E, 0xED, 0xE3,
0x25, 0xFC, 0x6A, 0xBA, 0x8C, 0x3F, 0xB2, 0x43, 0x78, 0xFE, 0x0A, 0xD5, 0x3F, 0xA0, 0xDB, 0xFF,
0x00, 0x8E, 0xE5, 0xE8, 0xFE, 0x45, 0x6E, 0x96, 0x7F, 0x8F, 0xDC, 0xFF, 0x00, 0xFD, 0x69, 0xE3,
0xAF, 0xF2, 0xAB, 0x3F, 0x8F, 0xAE, 0x39, 0xE3, 0xBF, 0xF8, 0x8D, 0xC3, 0x3F, 0xF7, 0x1B, 0x72,
0xBF, 0xE6, 0x1D, 0x3F, 0x64, 0x86, 0xF1, 0xFC, 0x15, 0xAA, 0x7F, 0x41, 0xB7, 0xFF, 0x00, 0x1D,
0xC7, 0xE4, 0x56, 0xE9, 0x67, 0xF8, 0xFD, 0xCF, 0xFF, 0x00, 0xD6, 0x9E, 0x3A, 0xFF, 0x00, 0x2A,
0xB2, 0x40, 0xB9, 0x6F, 0x73, 0xC0, 0xDF, 0xAE, 0x26, 0xB8, 0x83, 0x89, 0xB3, 0x7B, 0xE1, 0x84,
0x6D, 0x84, 0x08, 0x19, 0x05, 0x1D, 0x9C, 0xFC, 0x7E, 0xF3, 0x6E, 0xAB, 0x32, 0x4A, 0x27, 0xA1,
0xD9, 0xD4, 0x23, 0x32, 0x5D, 0x89, 0x6F, 0x13, 0x24, 0xCA, 0xB2, 0xC0, 0x9D, 0x12, 0x6C, 0x12,
0x94, 0xAC, 0xC8, 0x87, 0x22, 0xBD, 0xE8, 0x92, 0x58, 0x65, 0xB2, 0x66, 0x5B, 0x72, 0x4C, 0xE3,
0x6C, 0xBE, 0x2C, 0xE6, 0x5B, 0xBD, 0xD3, 0x63, 0x2A, 0x1B, 0xBA, 0xDA, 0xA6, 0x11, 0xE8, 0x52,
0x24, 0xC5, 0x91, 0x56, 0xDC, 0xC6, 0x14, 0x1D, 0x8B, 0xE0, 0x66, 0xDB, 0xED, 0xCB, 0x9B, 0x35,
0x1C, 0x07, 0x1A, 0x53, 0x51, 0x30, 0x26, 0xD4, 0x0C, 0x05, 0x14, 0x4D, 0x0D, 0x54, 0x21, 0x17,
0x5E, 0xDF, 0x0D, 0x4E, 0x2E, 0xE9, 0x97, 0x85, 0xDA, 0xE5, 0xAE, 0x30, 0xDD, 0x77, 0xFB, 0x43,
0xAE, 0xD9, 0xE9, 0xE9, 0x2F, 0x69, 0xB7, 0xB9, 0x9A, 0xE5, 0xA0, 0x49, 0x83, 0x78, 0xB2, 0x23,
0xC7, 0x97, 0x55, 0x2F, 0x5F, 0xD6, 0xB5, 0x92, 0x89, 0x26, 0x1C, 0xD6, 0xE3, 0x0B, 0xD1, 0xE5,
0x31, 0x35, 0xB9, 0x51, 0x9F, 0x75, 0xC0, 0x7A, 0x2B, 0x91, 0x85, 0xB9, 0x36, 0x92, 0xAF, 0x96,
0x33, 0xA1, 0xC6, 0x96, 0x3F, 0x13, 0xEC, 0xB6, 0xE2, 0x7C, 0x5F, 0x3C, 0x04, 0xFD, 0xDE, 0xCF,
0x9D, 0xA9, 0x19, 0x94, 0xC3, 0x9D, 0xCD, 0x31, 0x8D, 0x31, 0x8D, 0x31, 0x8D, 0x31, 0x95, 0x93,
0xF4, 0x98, 0xF0, 0x79, 0x76, 0x3B, 0x09, 0xC3, 0xF6, 0xE0, 0xB1, 0x1B, 0xC5, 0x8B, 0x8A, 0xEE,
0xDD, 0xBE, 0x39, 0x39, 0xF1, 0x6C, 0x4C, 0xE2, 0x86, 0x67, 0x88, 0x49, 0x98, 0xCB, 0x86, 0x68,
0xBD, 0xED, 0x46, 0x76, 0x46, 0x1E, 0xDB, 0x2E, 0x17, 0x6F, 0x86, 0x52, 0x1C, 0x86, 0x06, 0x42,
0x64, 0xC0, 0x9C, 0x70, 0xEA, 0x4E, 0x09, 0xBB, 0xAD, 0x50, 0x58, 0x08, 0xF9, 0x0C, 0x3B, 0xA7,
0x23, 0x38, 0x48, 0x9D, 0xD4, 0x12, 0x74, 0x27, 0x4C, 0x55, 0x57, 0xEA, 0x80, 0xA5, 0x08, 0x45,
0x57, 0xE8, 0xA4, 0xA0, 0x8A, 0xBD, 0xD4, 0x7B, 0xDD, 0x37, 0xC1, 0x37, 0x69, 0x8D, 0x03, 0x9B,
0x39, 0x6F, 0x4F, 0x79, 0xFF, 0x00, 0x49, 0xFD, 0x93, 0x8D, 0x21, 0xDD, 0x44, 0x68, 0x9C, 0x51,
0x09, 0x0E, 0x6A, 0xDB, 0x2C, 0x18, 0xCE, 0x00, 0x87, 0x6F, 0x07, 0x24, 0x36, 0xC6, 0xCC, 0xE3,
0xCD, 0xA7, 0x7F, 0x50, 0x58, 0x09, 0x44, 0x02, 0xA0, 0x8E, 0xA8, 0xC0, 0xAF, 0x27, 0xFC, 0xFA,
0x3E, 0x0D, 0xC6, 0xC6, 0x17, 0x1E, 0x5C, 0x96, 0xE3, 0xC7, 0xCC, 0xF1, 0xFC, 0x87, 0x16, 0x45,
0x79, 0xC4, 0x6D, 0xB3, 0x94, 0xDA, 0x42, 0xC9, 0xE3, 0x08, 0xA9, 0x2A, 0x07, 0x8E, 0x65, 0x8E,
0x13, 0x0C, 0x75, 0xEA, 0x64, 0xAF, 0x93, 0x2D, 0xF5, 0x37, 0x90, 0x4B, 0x52, 0x74, 0xFF, 0x00,
0x66, 0x30, 0x39, 0x01, 0xA8, 0xC6, 0x68, 0x03, 0x6F, 0x53, 0x61, 0x5E, 0x28, 0x4B, 0xD9, 0x09,
0xD0, 0xF4, 0x2C, 0x41, 0x13, 0xBA, 0xA2, 0x79, 0xAF, 0xC8, 0x10, 0x87, 0x7F, 0x75, 0xF2, 0x50,
0x1F, 0x73, 0xEC, 0xB6, 0x1D, 0xF1, 0x7A, 0xD1, 0xDF, 0xDB, 0x3A, 0x41, 0x9D, 0x77, 0x1A, 0x33,
0x8F, 0xBB, 0xC7, 0x5C, 0x83, 0xA7, 0xEE, 0x2F, 0x13, 0x2D, 0xF9, 0xB8, 0xDC, 0x19, 0x29, 0x67,
0xA6, 0x4A, 0x23, 0xF1, 0x15, 0x71, 0x23, 0x02, 0xED, 0xAC, 0xC8, 0x91, 0xE3, 0xD8, 0x01, 0x23,
0x83, 0xEE, 0xF6, 0x06, 0x14, 0x87, 0x61, 0xB6, 0x2D, 0x28, 0x26, 0x50, 0xD6, 0xC8, 0x02, 0x42,
0x13, 0x89, 0x1D, 0x51, 0x51, 0x7A, 0xFC, 0x6C, 0x36, 0xA9, 0xF9, 0x17, 0x53, 0xAB, 0x39, 0x4B,
0xCF, 0x1B, 0xBC, 0xDB, 0x3B, 0x80, 0x6F, 0xD6, 0xDD, 0x64, 0x7B, 0x5B, 0xBA, 0x18, 0xCD, 0x5E,
0x61, 0x84, 0x65, 0x31, 0xE3, 0x47, 0xBB, 0xC7, 0x6E, 0x59, 0x57, 0xEB, 0xE7, 0x8C, 0x1B, 0x08,
0x76, 0xD0, 0x49, 0xD0, 0x15, 0x13, 0x17, 0xA0, 0xD9, 0xD7, 0xC2, 0xB0, 0x86, 0xFB, 0x46, 0xDB,
0xF1, 0x66, 0xC4, 0x8F, 0x25, 0x87, 0x1B, 0x79, 0xA6, 0xCC, 0x7F, 0x05, 0x9D, 0x5D, 0x7D, 0xD4,
0x19, 0x15, 0x96, 0xB1, 0x19, 0x9D, 0x02, 0x58, 0x88, 0xC8, 0x8B, 0x20, 0x7C, 0xDA, 0x75, 0x1B,
0x70, 0x1E, 0x6F, 0xC9, 0x3B, 0xA2, 0xA2, 0xB6, 0xEB, 0x6D, 0xB8, 0x04, 0x2A, 0x84, 0x0E, 0x00,
0x98, 0xAA, 0x10, 0xA2, 0xA6, 0x59, 0xA3, 0x6F, 0x5B, 0x7F, 0x1A, 0x6D, 0x74, 0xFB, 0xC6, 0x85,
0xB0, 0xD9, 0x6A, 0xBB, 0x6D, 0x03, 0xAF, 0xBF, 0x4F, 0x7D, 0x50, 0xF7, 0xA1, 0x3E, 0x03, 0x92,
0xA1, 0xC8, 0xAF, 0x95, 0xE9, 0x38, 0xA2, 0x62, 0xAD, 0xCA, 0x81, 0x2E, 0x54, 0x29, 0x2C, 0xB8,
0x06, 0xD4, 0x88, 0xB2, 0x5F, 0x8E, 0xF0, 0x1B, 0x4E, 0x98, 0xAC, 0x5E, 0x4C, 0xE4, 0x97, 0xC1,
0x1B, 0xCF, 0xB8, 0xE3, 0x1B, 0x2D, 0x8C, 0x30, 0xD9, 0x19, 0x28, 0xB4, 0x12, 0xAF, 0x50, 0x40,
0x55, 0x55, 0x50, 0x45, 0x3C, 0xFA, 0xFB, 0x11, 0x15, 0x11, 0x3D, 0xBF, 0x12, 0x26, 0xB0, 0xBF,
0xD6, 0x9F, 0x8E, 0xBF, 0x8A, 0x75, 0x9F, 0xF4, 0x91, 0xFF, 0x00, 0xDF, 0x24, 0xCF, 0xE5, 0x03,
0xEB, 0x33, 0xFD, 0xE0, 0xB7, 0x9F, 0xFB, 0xEA, 0x3F, 0xC2, 0xF2, 0x29, 0x39, 0xC0, 0xF2, 0xDA,
0xE1, 0xBF, 0x85, 0x7E, 0x11, 0xDF, 0xDC, 0xED, 0xAE, 0xDB, 0xCA, 0x6C, 0x6B, 0x28, 0x4D, 0xC3,
0xC3, 0x68, 0x52, 0xCA, 0x13, 0xD6, 0x6E, 0x3E, 0x90, 0x2D, 0x5C, 0x9F, 0xE6, 0x98, 0x41, 0x97,
0x25, 0xE6, 0x90, 0x5E, 0x46, 0x01, 0x09, 0x50, 0x7B, 0xFA, 0x0F, 0x44, 0x24, 0x45, 0x24, 0xD6,
0xA7, 0xE6, 0x8D, 0x0F, 0x50, 0xD7, 0xB4, 0x97, 0x6C, 0x69, 0x68, 0x61, 0x57, 0xCD, 0x4B, 0x3A,
0xF6, 0x52, 0x4B, 0x08, 0xEF, 0xA8, 0x8D, 0x3A, 0x4E, 0xFA, 0x80, 0x9E, 0x6E, 0x9A, 0x76, 0x3F,
0x14, 0xEF, 0xED, 0xDF, 0xDB, 0xEB, 0x96, 0x0B, 0xF0, 0xCD, 0xEA, 0xC3, 0xA8, 0xBE, 0x61, 0xEA,
0x7E, 0x06, 0x9B, 0xC9, 0xBC, 0xB3, 0xB3, 0xEE, 0x3A, 0xC3, 0x9A, 0x3E, 0xDD, 0x64, 0x74, 0xD6,
0xA5, 0x01, 0x62, 0x14, 0xE8, 0x2D, 0x41, 0x58, 0x92, 0x49, 0x23, 0x42, 0x8E, 0xE2, 0xB8, 0xC2,
0xBA, 0xE2, 0x87, 0xE7, 0x3C, 0x7B, 0x92, 0xAA, 0x8A, 0xAA, 0x27, 0x68, 0x85, 0xE5, 0x1E, 0xAA,
0x9C, 0x70, 0x6D, 0xC2, 0xA2, 0xAA, 0x2F, 0xAA, 0x72, 0xAF, 0x6A, 0x7B, 0x17, 0xF7, 0x28, 0xB5,
0xAA, 0xF8, 0x0B, 0xF6, 0xC5, 0x87, 0xFC, 0x99, 0x6B, 0xFD, 0x9D, 0x32, 0x7B, 0xFC, 0x5C, 0xBF,
0x71, 0x9E, 0xC7, 0xFC, 0xF9, 0xD0, 0xBF, 0xBD, 0xCB, 0x36, 0x24, 0xE2, 0xBF, 0x73, 0xF5, 0x5F,
0x81, 0x46, 0xFD, 0x03, 0x7A, 0x9D, 0xF9, 0xC9, 0xF6, 0x7A, 0x1D, 0x31, 0x8D, 0x31, 0x8D, 0x31,
0x8D, 0x31, 0x91, 0xFF, 0x00, 0xCC, 0xE7, 0x86, 0x87, 0xB8, 0xAD, 0xE0, 0xCF, 0x78, 0xF6, 0xAA,
0xA6, 0x1B, 0x72, 0xF2, 0xE7, 0x68, 0x13, 0x26, 0xC0, 0x84, 0x91, 0x11, 0xCF, 0xAB, 0x7C, 0x46,
0x5C, 0x6C, 0x87, 0x1F, 0x88, 0xCB, 0xC4, 0xA8, 0x91, 0xBD, 0x77, 0x22, 0xBC, 0xB1, 0xD9, 0x32,
0x0B, 0xAA, 0x35, 0x06, 0xE2, 0x59, 0x10, 0x92, 0x75, 0x4D, 0x61, 0x3C, 0x89, 0xAD, 0x2E, 0xD9,
0xA7, 0x5D, 0xD3, 0x34, 0x28, 0x52, 0xDD, 0x8D, 0xF3, 0x35, 0xFD, 0xFB, 0x27, 0xFA, 0xC2, 0x19,
0x8C, 0xA8, 0xA0, 0x84, 0xBF, 0x81, 0x1F, 0x71, 0xAF, 0x96, 0x32, 0xF7, 0xEC, 0xDB, 0xC7, 0xEC,
0xB9, 0x27, 0xFA, 0x35, 0xE6, 0xD0, 0xE9, 0xF3, 0xA9, 0x1E, 0x30, 0xE4, 0xB9, 0xCF, 0x9B, 0x1A,
0xEC, 0x1B, 0xBF, 0xB1, 0x77, 0x05, 0x04, 0x52, 0x1F, 0xD4, 0x8E, 0xCA, 0xC3, 0x94, 0x77, 0xB2,
0x0D, 0xA1, 0x45, 0x57, 0xD6, 0xAA, 0x2C, 0xDF, 0xB6, 0xE3, 0xB0, 0x8A, 0x2A, 0xE4, 0xCA, 0xC8,
0xC8, 0x84, 0x2B, 0xD9, 0x53, 0x5C, 0xCE, 0x1F, 0x94, 0x64, 0xBB, 0x5B, 0x9E, 0xE3, 0xD9, 0x75,
0x3F, 0x98, 0xA8, 0xCA, 0xF0, 0x4C, 0x9A, 0x05, 0xC4, 0x46, 0xE5, 0x36, 0xFC, 0x67, 0xE1, 0xDB,
0xD0, 0xD8, 0x03, 0xEB, 0x0E, 0x74, 0x72, 0xF0, 0x9F, 0x6D, 0x11, 0xF8, 0xE7, 0x12, 0x7C, 0x47,
0x10, 0x0D, 0x5B, 0x27, 0xE3, 0xBA, 0x29, 0xD4, 0x87, 0x55, 0xDF, 0x59, 0x61, 0x36, 0x86, 0xDA,
0x15, 0x94, 0x5F, 0x26, 0x27, 0xD5, 0x4E, 0x66, 0x4B, 0x62, 0x68, 0x40, 0x40, 0xFC, 0x57, 0x90,
0xD5, 0xA7, 0x43, 0xEE, 0x92, 0x0A, 0x90, 0x2B, 0x6F, 0x36, 0xBD, 0x95, 0x45, 0x4C, 0x09, 0x3D,
0xD5, 0x33, 0xB2, 0x3D, 0xE3, 0x50, 0xD6, 0x79, 0x63, 0x8F, 0xB6, 0x6D, 0x26, 0xF1, 0x18, 0xB5,
0xD4, 0xF7, 0xED, 0x5E, 0xC6, 0x92, 0x6B, 0xB1, 0x5C, 0x62, 0x43, 0x72, 0x2A, 0xAF, 0x6B, 0xDC,
0x60, 0x67, 0x40, 0x90, 0x88, 0xF3, 0x04, 0xE8, 0x34, 0xF8, 0x4D, 0xAE, 0x96, 0xDF, 0x98, 0x83,
0xE1, 0x1E, 0x4B, 0x44, 0xAA, 0x20, 0x59, 0xB1, 0x63, 0x97, 0x8F, 0x17, 0x18, 0x4F, 0x14, 0xBB,
0x15, 0x89, 0x66, 0xB8, 0xE4, 0xF6, 0xFC, 0x69, 0x30, 0x9B, 0x87, 0x71, 0x50, 0xE3, 0xE0, 0xE4,
0xEC, 0x7F, 0x20, 0x86, 0xC4, 0x46, 0xAD, 0x68, 0xAC, 0x00, 0x3B, 0x95, 0xB9, 0x50, 0x5F, 0x34,
0xEC, 0x22, 0x54, 0x19, 0x50, 0xDD, 0x8B, 0x3D, 0x9E, 0xE8, 0xD2, 0xD8, 0x32, 0xB2, 0x2D, 0x4F,
0x67, 0xAF, 0xDB, 0xE8, 0x60, 0xDE, 0xD6, 0x9A, 0x2B, 0x52, 0x9B, 0x44, 0x7D, 0x85, 0x24, 0x57,
0x21, 0xCC, 0x01, 0x1F, 0x99, 0x86, 0xF2, 0x27, 0xD1, 0xD6, 0x0C, 0xBB, 0x77, 0xFA, 0x38, 0xD9,
0x36, 0xF0, 0x77, 0x6D, 0xC0, 0x25, 0xE2, 0x9B, 0xA8, 0x2E, 0x0D, 0xDC, 0x7A, 0x74, 0xE5, 0x7D,
0xA7, 0x8A, 0xB7, 0x48, 0xC6, 0x13, 0xE8, 0xA6, 0x1B, 0x95, 0x56, 0x62, 0xD3, 0x8D, 0xC2, 0xD9,
0x35, 0xD9, 0x2E, 0xBB, 0xF6, 0x2E, 0xC7, 0x58, 0x46, 0x29, 0xEA, 0x42, 0xB4, 0x8C, 0xDA, 0x92,
0xA2, 0x77, 0x28, 0x93, 0x1B, 0x97, 0x5F, 0x23, 0xC2, 0x5C, 0x39, 0x0D, 0x84, 0x87, 0x22, 0xA2,
0xA7, 0x54, 0xF6, 0xA2, 0xEB, 0x24, 0xCD, 0x2D, 0x8D, 0x31, 0x90, 0x43, 0xE9, 0x10, 0x7F, 0x07,
0xF4, 0x8F, 0xED, 0x83, 0x6E, 0xBF, 0xC7, 0x6D, 0xAD, 0x23, 0xD4, 0x0F, 0xED, 0x78, 0xF7, 0xF2,
0xC5, 0x67, 0xFE, 0x4F, 0x65, 0xA2, 0x7C, 0x20, 0xBF, 0x76, 0x2D, 0x77, 0xFC, 0xB9, 0xDE, 0x7F,
0xF4, 0xD6, 0xE5, 0x5C, 0xF9, 0x47, 0xFE, 0xFD, 0xFD, 0xB8, 0xFE, 0xA9, 0xCA, 0xBF, 0xCA, 0x8B,
0x51, 0xFB, 0x80, 0xBF, 0x6C, 0x58, 0x7F, 0xC9, 0x96, 0xBF, 0xD9, 0xD3, 0x2D, 0xF7, 0xE2, 0xE5,
0xFB, 0x8C, 0xF6, 0x3F, 0xE7, 0xCE, 0x85, 0xFD, 0xEE, 0x59, 0xB1, 0x27, 0x14, 0xFB, 0x9F, 0xAA,
0xFC, 0x0A, 0x37, 0xE8, 0x1B, 0xD4, 0xEF, 0xCE, 0x4F, 0xB3, 0xD0, 0xE9, 0x8C, 0x69, 0x8C, 0x69,
0x8C, 0x69, 0x8C, 0xE2, 0x7D, 0x90, 0x90, 0xD1, 0xB4, 0xE2, 0x21, 0x09, 0xA7, 0x45, 0x45, 0x4E,
0xA8, 0xA9, 0xF1, 0xFE, 0xAD, 0x31, 0x94, 0xE1, 0xE7, 0x53, 0xCA, 0x7F, 0x26, 0xC6, 0xF3, 0x3C,
0x9B, 0x8B, 0x1E, 0x1D, 0x71, 0x69, 0x57, 0x58, 0xC6, 0x48, 0xEC, 0x8B, 0xDD, 0xDF, 0xC0, 0xA8,
0x21, 0x3D, 0x2A, 0xCA, 0x96, 0xF1, 0xC5, 0x72, 0x4D, 0xB6, 0xE1, 0x51, 0x57, 0xC6, 0x68, 0x8E,
0x5D, 0x3D, 0xAA, 0x97, 0x9C, 0xCA, 0xEB, 0xE3, 0x34, 0x72, 0xEB, 0x2C, 0xFC, 0xDE, 0x42, 0x03,
0x22, 0xB6, 0x7D, 0x8F, 0xA9, 0x22, 0x67, 0x34, 0xF1, 0x2C, 0x9F, 0x9A, 0x95, 0xB8, 0xEB, 0x11,
0x09, 0xF6, 0xA4, 0x29, 0x48, 0xBD, 0xAC, 0x8C, 0x0A, 0x6F, 0x34, 0xFA, 0xA9, 0x1B, 0xD6, 0x91,
0x5A, 0x04, 0x55, 0x71, 0x97, 0x93, 0xEF, 0xCD, 0x68, 0x05, 0x5C, 0x69, 0xDF, 0x39, 0x48, 0x86,
0xD3, 0xAE, 0xFC, 0xBF, 0x41, 0xFF, 0x00, 0x0C, 0x7F, 0x88, 0x45, 0x22, 0x51, 0x51, 0x74, 0xDD,
0xCE, 0x7B, 0x03, 0x15, 0x53, 0xEA, 0x05, 0x9A, 0x9E, 0x2A, 0xDE, 0x6E, 0xA5, 0x37, 0x1E, 0xB6,
0x75, 0x48, 0xA3, 0x4C, 0x57, 0x68, 0x77, 0xB3, 0xE4, 0x10, 0xB7, 0x0E, 0xC6, 0xBC, 0xBB, 0xC6,
0xD5, 0xE7, 0xC9, 0x74, 0x62, 0xCF, 0xAF, 0x58, 0xD4, 0x06, 0x51, 0xE7, 0x41, 0xAE, 0xFB, 0x5E,
0x0D, 0x78, 0x4F, 0xE3, 0x27, 0x7B, 0xF8, 0x37, 0xCE, 0xC7, 0x34, 0xDA, 0x2C, 0x81, 0x19, 0x89,
0x35, 0xD8, 0xBF, 0x54, 0xF8, 0x6D, 0xBF, 0x8F, 0x2F, 0x13, 0xCA, 0xE3, 0x46, 0x35, 0x56, 0xDB,
0xB4, 0xAF, 0x6D, 0xF6, 0x0D, 0x99, 0xCC, 0x01, 0x38, 0x30, 0x6E, 0x20, 0xBB, 0x1A, 0xCA, 0x12,
0x38, 0xE3, 0x60, 0xF9, 0xC4, 0x7E, 0x54, 0x49, 0x1A, 0x3B, 0x4B, 0xDF, 0x36, 0x0D, 0x16, 0x72,
0xCB, 0xA6, 0x90, 0x85, 0x1D, 0xF5, 0x0F, 0x9E, 0xAD, 0x93, 0xE4, 0x70, 0x67, 0x00, 0x7D, 0x3D,
0x56, 0x84, 0x85, 0x41, 0xE0, 0x45, 0x54, 0x6A, 0x4B, 0x44, 0x0F, 0x37, 0xDD, 0x47, 0xC8, 0x9B,
0x23, 0x6C, 0xED, 0x47, 0xA9, 0x8E, 0x93, 0x78, 0x87, 0xAA, 0xAD, 0x51, 0xAD, 0x7F, 0x92, 0x69,
0xDC, 0x6A, 0xDE, 0xAD, 0xB9, 0x0B, 0xAB, 0x6E, 0xD4, 0xDE, 0x84, 0x5D, 0xAF, 0x57, 0x91, 0x21,
0x11, 0x5C, 0xF9, 0x09, 0xCE, 0x32, 0xF3, 0x72, 0xAB, 0x64, 0x38, 0x0D, 0x9C, 0xFA, 0x5B, 0x06,
0xA4, 0xD6, 0xCC, 0x56, 0xDB, 0x79, 0x59, 0x6A, 0x6B, 0x11, 0x66, 0x47, 0xB4, 0x9E, 0xC1, 0x7A,
0x46, 0xBC, 0x3A, 0x5E, 0xD3, 0x40, 0x87, 0xBE, 0x38, 0x4E, 0x7F, 0xB6, 0x79, 0x13, 0x6D, 0x00,
0x4F, 0x91, 0x57, 0x02, 0x3E, 0x71, 0x8A, 0x99, 0x0B, 0x2D, 0xF7, 0x3B, 0x0E, 0xC6, 0xA4, 0x62,
0xE4, 0x2A, 0xAE, 0x3C, 0x2E, 0xA7, 0x97, 0x91, 0x8B, 0xB6, 0x8C, 0x89, 0x33, 0xFB, 0x29, 0xFE,
0xE7, 0x09, 0x99, 0x45, 0x49, 0xD4, 0x56, 0xA3, 0x35, 0x90, 0x4B, 0xA8, 0x56, 0x74, 0xB2, 0xBB,
0x27, 0xA9, 0xE0, 0xD2, 0x59, 0x42, 0xEF, 0xE2, 0x9E, 0xED, 0xBF, 0x1F, 0xC2, 0x52, 0xF7, 0x2E,
0xE9, 0xE2, 0x70, 0x47, 0xC5, 0x14, 0x7E, 0xF9, 0x77, 0x2F, 0x1A, 0x1E, 0xE5, 0x0F, 0x83, 0x4F,
0x51, 0x3A, 0xCD, 0x94, 0x93, 0xE3, 0x2D, 0x97, 0x47, 0xE4, 0xDA, 0x05, 0x25, 0x58, 0x4B, 0x26,
0x79, 0xE9, 0x7B, 0x37, 0x8A, 0xBA, 0x48, 0x81, 0x36, 0xAE, 0xD8, 0x64, 0x51, 0x82, 0x83, 0x4A,
0xD9, 0x7A, 0xB1, 0xB6, 0x77, 0xFD, 0x52, 0x47, 0x7F, 0xD1, 0xD9, 0xF1, 0x6C, 0x5D, 0xCB, 0x0C,
0x83, 0x9F, 0xAF, 0x2E, 0x5A, 0x6A, 0xDF, 0x39, 0x5B, 0xBA, 0x79, 0x2E, 0x59, 0x2F, 0xE1, 0x27,
0xAA, 0x71, 0xFD, 0xAD, 0xDC, 0xD8, 0xD3, 0xBD, 0x82, 0xA4, 0x8B, 0xE2, 0xE5, 0x38, 0x8E, 0x33,
0x59, 0xD0, 0x95, 0x3B, 0x07, 0xF6, 0xC1, 0x17, 0xBD, 0x51, 0x49, 0x04, 0x3A, 0x92, 0x64, 0x92,
0x79, 0xD7, 0x8D, 0x18, 0x6F, 0xCD, 0xAB, 0xC9, 0x13, 0x0B, 0xDF, 0xF3, 0x51, 0xA9, 0xED, 0xC1,
0xCF, 0xA7, 0x7F, 0xAC, 0xC8, 0x51, 0x5A, 0xF7, 0xFA, 0x27, 0xE7, 0x7E, 0xBF, 0x5E, 0xC9, 0xEF,
0x9A, 0x56, 0x97, 0xE1, 0x4F, 0xD6, 0xF5, 0xA4, 0xB4, 0x8D, 0x3B, 0x8B, 0x6A, 0x35, 0xB6, 0x55,
0x11, 0x7E, 0x7E, 0xEB, 0x91, 0xB8, 0xF1, 0xF8, 0x88, 0xAA, 0x48, 0x8A, 0x8A, 0x1A, 0xEE, 0xCB,
0x7F, 0x3F, 0xB8, 0xA2, 0xF9, 0x2F, 0x68, 0x4A, 0x9E, 0x28, 0xA8, 0x2A, 0xA5, 0xD8, 0x56, 0x03,
0xF9, 0xA9, 0x73, 0x98, 0xC4, 0xB8, 0xE4, 0xDA, 0xE6, 0xF6, 0x1F, 0x6B, 0x36, 0x9B, 0x22, 0xC6,
0xB0, 0x76, 0xF2, 0xBA, 0x8C, 0xA6, 0x6E, 0x69, 0x9D, 0x59, 0xD6, 0xB1, 0x91, 0x4F, 0x91, 0x45,
0xE6, 0x52, 0x1C, 0x38, 0x18, 0xB5, 0x11, 0xDA, 0x41, 0xAE, 0x8A, 0xE9, 0xC8, 0x37, 0x5D, 0x9B,
0x2F, 0x24, 0x9D, 0x21, 0xE6, 0xBC, 0x36, 0xBD, 0x5D, 0x0D, 0xC4, 0x33, 0x5D, 0x0D, 0xCA, 0x7C,
0xCB, 0x03, 0x76, 0xA9, 0x5D, 0x7E, 0xA2, 0xA2, 0x54, 0x78, 0x2B, 0x2D, 0x89, 0x6E, 0x4F, 0xB0,
0x71, 0xA0, 0x92, 0x65, 0x1B, 0xCF, 0xC1, 0xB6, 0xE1, 0xC7, 0x27, 0x9B, 0x6C, 0x09, 0x49, 0x55,
0x5C, 0x39, 0x46, 0x4A, 0x9D, 0x93, 0xD2, 0x05, 0xEE, 0xB9, 0x6C, 0xFD, 0x05, 0x7C, 0x35, 0xB6,
0xBE, 0x98, 0x79, 0x08, 0x79, 0x7F, 0x91, 0x79, 0x0A, 0x8A, 0xDF, 0x68, 0x1D, 0x7A, 0xD6, 0x82,
0x26, 0xA5, 0xA7, 0xC2, 0x9D, 0x26, 0x96, 0x2B, 0x57, 0x23, 0x1D, 0x24, 0xCB, 0x9B, 0xB1, 0xDB,
0xB3, 0x59, 0x2E, 0x64, 0x86, 0x81, 0x81, 0x6D, 0xB8, 0x91, 0xA8, 0xA2, 0xB2, 0xDB, 0x9E, 0x6E,
0x7C, 0xFC, 0xA0, 0x51, 0x0C, 0xC3, 0xBE, 0x50, 0x95, 0xF3, 0x67, 0xF1, 0xBD, 0x81, 0x1C, 0x48,
0xCF, 0x48, 0x08, 0x54, 0x59, 0x44, 0xA9, 0x86, 0xD3, 0x6A, 0x61, 0x16, 0x39, 0x42, 0x6A, 0x20,
0xBC, 0xF9, 0x27, 0xB1, 0xB6, 0xCA, 0x54, 0xA8, 0xD1, 0xC4, 0x89, 0x51, 0x15, 0xD7, 0xDB, 0x04,
0xF8, 0x44, 0x89, 0xAF, 0x2B, 0xA7, 0xF6, 0xDC, 0x3E, 0x43, 0x8E, 0x60, 0x04, 0x42, 0xCD, 0x4D,
0x9B, 0x8E, 0x92, 0x22, 0xAA, 0x36, 0x04, 0xDB, 0x6D, 0x21, 0x1A, 0xFE, 0xF4, 0x55, 0xC7, 0x1B,
0x04, 0x55, 0xFA, 0x91, 0x8A, 0x7D, 0x57, 0x33, 0xBF, 0x8B, 0xCC, 0xD8, 0x91, 0x7A, 0x39, 0xB6,
0x8F, 0x22, 0x4B, 0x2C, 0xBF, 0x63, 0xC8, 0x3A, 0x34, 0x48, 0x0C, 0xB8, 0xE0, 0x83, 0x93, 0x24,
0xB5, 0x32, 0x5C, 0xF7, 0x18, 0x8E, 0x0A, 0xA8, 0x4E, 0xB8, 0x10, 0xA1, 0xCA, 0x94, 0x62, 0x08,
0xAA, 0x2C, 0xC7, 0x75, 0xC5, 0xEC, 0x20, 0xAB, 0x9B, 0x0F, 0xF1, 0x71, 0x20, 0xA0, 0xAB, 0x12,
0x4E, 0x8A, 0x90, 0xE3, 0x22, 0xA7, 0xF3, 0x30, 0xDE, 0xA7, 0x66, 0x72, 0x91, 0x9F, 0xBF, 0xA6,
0x31, 0xA6, 0x31, 0xA6, 0x31, 0xA6, 0x31, 0xA6, 0x33, 0xF3, 0xAC, 0xEA, 0xE1, 0x5B, 0x46, 0x72,
0x24, 0xD6, 0x1B, 0x79, 0xA7, 0x45, 0x40, 0x84, 0xC0, 0x49, 0x3A, 0x2F, 0xF2, 0x10, 0x92, 0x7E,
0x4D, 0x31, 0x90, 0x7D, 0xC6, 0x3F, 0x23, 0xBE, 0x19, 0xB8, 0x88, 0x9F, 0x69, 0x98, 0x62, 0x35,
0x72, 0x36, 0x8F, 0x3F, 0xB0, 0x37, 0x64, 0xC9, 0xBF, 0xC0, 0x5A, 0x8D, 0x0E, 0xB6, 0xD6, 0x63,
0x88, 0x0A, 0xAF, 0xDE, 0xE2, 0x67, 0x10, 0xA8, 0xA7, 0x38, 0x66, 0x8E, 0x3B, 0x26, 0x5D, 0x7B,
0x54, 0xF6, 0xF3, 0x9E, 0x78, 0xDE, 0x9B, 0x68, 0xF9, 0xF4, 0xE9, 0xA9, 0xB6, 0xFE, 0x19, 0xD3,
0x76, 0xB3, 0x72, 0x5A, 0x46, 0x3A, 0x4B, 0x47, 0x14, 0x88, 0xE7, 0x54, 0xA3, 0x6C, 0x83, 0xEE,
0x2F, 0x6F, 0xBD, 0x2E, 0x11, 0x01, 0x45, 0x79, 0x55, 0x7B, 0x91, 0xB8, 0xD8, 0x47, 0x90, 0xE9,
0x12, 0xAB, 0x92, 0x09, 0x7B, 0x76, 0xB0, 0x8E, 0x9D, 0xBE, 0x25, 0xDD, 0x4A, 0x74, 0xFF, 0x00,
0x16, 0x16, 0xBC, 0x77, 0x71, 0xB9, 0x43, 0x44, 0x86, 0x2D, 0xB3, 0x1F, 0x55, 0xE4, 0x12, 0x97,
0x63, 0x26, 0xB2, 0x28, 0x79, 0x27, 0xA1, 0x41, 0xB4, 0x32, 0xFB, 0x77, 0xD5, 0xAD, 0x80, 0x28,
0x35, 0x1A, 0x1C, 0xC9, 0x16, 0xD4, 0xD0, 0x99, 0x68, 0x1B, 0x89, 0x50, 0xCA, 0x29, 0x77, 0x83,
0xBD, 0xC2, 0xF4, 0x7A, 0xB8, 0x98, 0xC7, 0xE6, 0xCA, 0x6F, 0x07, 0xDC, 0x9C, 0x17, 0x2A, 0x80,
0x1D, 0xEB, 0x15, 0xEC, 0x82, 0x9F, 0x25, 0xC5, 0x64, 0x9A, 0x75, 0x25, 0x00, 0x7D, 0x9A, 0xD8,
0xB9, 0x7B, 0x41, 0xD1, 0x10, 0x50, 0x9D, 0x6D, 0xE3, 0xEB, 0xD4, 0x8D, 0x19, 0x1E, 0x9D, 0x9A,
0xD2, 0xD3, 0xFA, 0x6A, 0xBD, 0x6C, 0xCF, 0xEC, 0xBD, 0x92, 0xA6, 0x53, 0x7E, 0xEA, 0x0B, 0x3E,
0x34, 0xC8, 0x07, 0xFA, 0x7B, 0x21, 0xA4, 0x71, 0xB2, 0x14, 0xED, 0xEC, 0x8A, 0x48, 0xAB, 0xDF,
0xDD, 0x7C, 0x53, 0xE9, 0x96, 0x6B, 0xA9, 0x7C, 0x6E, 0x78, 0xAA, 0x5C, 0x66, 0x17, 0x7B, 0xE1,
0x4E, 0x41, 0xA1, 0x99, 0xF7, 0x06, 0x50, 0xEA, 0x57, 0x5A, 0xE6, 0xDB, 0x19, 0x3F, 0x0A, 0x1B,
0x8C, 0x1D, 0xCB, 0xDA, 0x53, 0xAB, 0xDF, 0xEF, 0x90, 0x32, 0xE0, 0x0F, 0x8F, 0x61, 0x05, 0x90,
0x5D, 0xD5, 0xC4, 0xF9, 0x5C, 0x1E, 0x43, 0x7C, 0x68, 0xBB, 0x27, 0xC2, 0x9F, 0x6B, 0xB5, 0x31,
0x58, 0xE9, 0xF6, 0xE8, 0x96, 0xD9, 0xAC, 0xE7, 0x3B, 0xBB, 0xC5, 0x3A, 0x78, 0x2F, 0x60, 0x95,
0xE3, 0xDB, 0xD9, 0xDE, 0x5D, 0xDE, 0x3F, 0x5E, 0xE1, 0x00, 0xED, 0xE8, 0x64, 0x6D, 0xF9, 0xCD,
0x74, 0xDD, 0xB9, 0xA9, 0xF6, 0x7E, 0xE3, 0x58, 0x6C, 0x3B, 0x7E, 0x26, 0xA4, 0xDA, 0xBC, 0x7D,
0xFB, 0xA7, 0xB7, 0x81, 0xD4, 0x30, 0x9D, 0xBB, 0x77, 0x5E, 0xFE, 0x7F, 0x54, 0x44, 0xED, 0xD9,
0x55, 0x53, 0x31, 0x9F, 0xF1, 0xAD, 0xE9, 0xA9, 0xB6, 0x3C, 0xAB, 0x38, 0xDF, 0x9C, 0xA6, 0x49,
0xF2, 0xED, 0xE8, 0xCF, 0xA4, 0xD0, 0x6B, 0x98, 0xF0, 0xF0, 0x35, 0xF2, 0xF9, 0x88, 0xFC, 0x87,
0x68, 0xE7, 0x97, 0xA8, 0x8D, 0x8F, 0x8F, 0xCA, 0xF6, 0xF0, 0x23, 0x3F, 0x3F, 0x20, 0x16, 0xDC,
0xCB, 0xBD, 0x9E, 0xF4, 0x78, 0xB2, 0x39, 0xB2, 0xA1, 0xCA, 0xDD, 0xAD, 0xCE, 0xB4, 0x94, 0xC2,
0x10, 0x9C, 0xAA, 0x6C, 0x3E, 0x80, 0x69, 0x5B, 0x5E, 0x82, 0xBD, 0x19, 0xF5, 0xE5, 0xB3, 0x97,
0x0F, 0xBC, 0xD2, 0xB9, 0xD1, 0x5D, 0x26, 0xE9, 0xA0, 0xBC, 0xAD, 0x21, 0x36, 0xD9, 0x32, 0xE1,
0x23, 0xCD, 0xE6, 0xB4, 0xBD, 0x35, 0xD7, 0xB4, 0x4D, 0xBB, 0xB0, 0x6C, 0x52, 0xA6, 0x22, 0x2F,
0x73, 0x89, 0x55, 0x15, 0xB8, 0x40, 0xBD, 0x93, 0xF0, 0x2C, 0xB9, 0x27, 0x29, 0xC3, 0x05, 0x2E,
0xDE, 0x4A, 0x31, 0x98, 0x35, 0x1E, 0xE8, 0x2A, 0x04, 0xA8, 0x63, 0x19, 0x39, 0x37, 0xE3, 0x6B,
0xB8, 0xCF, 0x62, 0x54, 0x2E, 0x20, 0xE1, 0xAA, 0x2D, 0x70, 0xC8, 0x55, 0xB8, 0xD7, 0xFB, 0xE5,
0xEC, 0xBD, 0x9A, 0x48, 0xA1, 0x1A, 0x77, 0x7C, 0x75, 0xFA, 0x56, 0x28, 0x22, 0xC6, 0x7C, 0x5A,
0xEE, 0x8D, 0x03, 0xD7, 0x76, 0x6C, 0x0B, 0xCA, 0x2E, 0x3A, 0xDB, 0xED, 0x01, 0x47, 0x72, 0x7E,
0xB8, 0x48, 0xE5, 0xB1, 0xB2, 0x3C, 0x2D, 0x45, 0x65, 0x70, 0x7C, 0x46, 0xB6, 0xA6, 0x6B, 0x88,
0xC1, 0x58, 0x5A, 0xAF, 0x98, 0x9B, 0x79, 0x6A, 0xE3, 0x1D, 0x08, 0x4A, 0xCE, 0xE6, 0xCB, 0xCC,
0x59, 0x4B, 0x01, 0x35, 0x37, 0x1A, 0x8C, 0x72, 0x52, 0x14, 0x53, 0x71, 0xCF, 0x25, 0x1A, 0x30,
0x9A, 0x86, 0xB7, 0xCE, 0xB7, 0xA8, 0x6B, 0x9A, 0x8C, 0x52, 0x8B, 0xAF, 0xD5, 0xC7, 0x80, 0x2E,
0x20, 0xFA, 0xEF, 0x8A, 0x13, 0xB3, 0x25, 0x28, 0xFD, 0x16, 0x4C, 0xC7, 0x89, 0xC9, 0x0F, 0x22,
0x2A, 0xA9, 0x03, 0x64, 0xE7, 0xA4, 0xD2, 0x91, 0x7A, 0x4D, 0xB6, 0x84, 0xA9, 0x95, 0x31, 0xCD,
0x7D, 0x45, 0xF3, 0x47, 0x50, 0xF7, 0x8D, 0xDF, 0x72, 0xEE, 0xF9, 0x71, 0xB6, 0x3B, 0x10, 0x9D,
0x5A, 0xAA, 0xB7, 0x49, 0x98, 0x1A, 0xE5, 0x18, 0xBC, 0xBD, 0x8C, 0x29, 0x35, 0xCA, 0xD6, 0xA2,
0x53, 0x56, 0x99, 0xB6, 0x2D, 0xB5, 0x22, 0x5B, 0x10, 0xD2, 0x7C, 0xD0, 0x65, 0x95, 0xB0, 0x97,
0x2D, 0xC6, 0xC5, 0xCC, 0x93, 0x06, 0x19, 0x08, 0xED, 0x36, 0xCB, 0x69, 0xD0, 0x1B, 0x01, 0x01,
0x44, 0xFA, 0x04, 0x50, 0x53, 0xE8, 0xF7, 0x22, 0x7B, 0xB5, 0x92, 0xE6, 0x93, 0xCE, 0x5D, 0x31,
0x8D, 0x31, 0x8D, 0x31, 0x8D, 0x31, 0x8D, 0x31, 0x8D, 0x31, 0x8D, 0x31, 0x9C, 0x27, 0x1D, 0x83,
0xF9, 0x6C, 0xB4, 0x5F, 0x7C, 0x02, 0xBF, 0x9D, 0x34, 0xC6, 0x70, 0xA5, 0x7C, 0x24, 0x5E, 0xBE,
0x55, 0x8E, 0xBD, 0x7A, 0xFD, 0xA5, 0xBF, 0xF6, 0xE9, 0x8C, 0xE7, 0x06, 0x19, 0x6F, 0xE4, 0x34,
0xD8, 0x7D, 0xE8, 0x0A, 0x7E, 0x64, 0xD3, 0x19, 0xCB, 0xA6, 0x31, 0xA6, 0x31, 0xA6, 0x31, 0xA6,
0x31, 0xA6, 0x31, 0xA6, 0x31, 0xA6, 0x31, 0xA6, 0x31, 0xA6, 0x31, 0xA6, 0x31, 0xA6, 0x31, 0xA6,
0x31, 0xA6, 0x31, 0xA6, 0x31, 0xA6, 0x31, 0xA6, 0x33, 0xFF, 0xD9

#endif

	};
	server.send(200, "image/x-icon", favicon, sizeof(favicon)); // Icon an den Browser senden			 
}